@@ -113,6 +113,21 @@ BOOL CConfigLogging::OnInitDialog()
 	csKeyName.Format(_T( "%s\\%s" ), NTSYSLOG_REGISTRY_KEY, csRegPath);
 	if (RegOpenKeyEx( hKeyRemote, csKeyName, 0, KEY_READ, &hKey) == ERROR_SUCCESS)
 	{
+		// Forward Log Always events
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, LOGALWAYS_ENTRY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS) &&
+			(dwValue == 1))
+		{
+			m_uCurrentState += CHECK_LOGALWAYS;
+		}
+
+		// Forward Log Always priority
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, LOGALWAYS_PRIORITY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS))
+		{
+			m_uLogAlwaysPriority = dwValue;
+		}
+
 		// Forward Information events
 		dwSize = sizeof( DWORD);
 		if ((RegQueryValueEx( hKey, INFORMATION_ENTRY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS) &&
@@ -158,6 +173,36 @@ BOOL CConfigLogging::OnInitDialog()
 			m_uErrorPriority = dwValue;
 		}
 
+		// Forward Critical events
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, CRITICAL_ENTRY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS) &&
+			(dwValue == 1))
+		{
+			m_uCurrentState += CHECK_CRITICAL;
+		}
+
+		// Forward Critical priority
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, CRITICAL_PRIORITY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS))
+		{
+			m_uCriticalPriority = dwValue;
+		}
+
+		// Forward Verbose events
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, VERBOSE_ENTRY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS) &&
+			(dwValue == 1))
+		{
+			m_uCurrentState += CHECK_VERBOSE;
+		}
+
+		// Forward Verbose priority
+		dwSize = sizeof( DWORD);
+		if ((RegQueryValueEx( hKey, VERBOSE_PRIORITY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS))
+		{
+			m_uVerbosePriority = dwValue;
+		}
+
 		// Forward Audit Success events
 		dwSize = sizeof( DWORD);
 		if ((RegQueryValueEx( hKey, AUDIT_SUCCESS_ENTRY, 0, &dwType, (LPBYTE) &dwValue, &dwSize) == ERROR_SUCCESS) &&
@@ -197,15 +242,21 @@ BOOL CConfigLogging::OnInitDialog()
 	RegCloseKey(hKeyRemote);
 
 	// Update the dialog box to match the settings loaded from the registry.
+	CheckDlgButton( IDC_LOGALWAYS_CHECK, (m_uCurrentState & CHECK_LOGALWAYS));
 	CheckDlgButton( IDC_INFORMATION_CHECK, (m_uCurrentState & CHECK_INFORMATION));
 	CheckDlgButton( IDC_WARNING_CHECK, (m_uCurrentState & CHECK_WARNING));
 	CheckDlgButton( IDC_ERROR_CHECK, (m_uCurrentState & CHECK_ERROR));
+	CheckDlgButton( IDC_CRITICAL_CHECK, (m_uCurrentState & CHECK_CRITICAL));
+	CheckDlgButton( IDC_VERBOSE_CHECK, (m_uCurrentState & CHECK_VERBOSE));
 	CheckDlgButton( IDC_AUDIT_SUCCESS_CHECK, (m_uCurrentState & CHECK_AUDIT_SUCCESS));
 	CheckDlgButton( IDC_AUDIT_FAILURE_CHECK, (m_uCurrentState & CHECK_AUDIT_FAILURE));
 
+	SetDialogFromPriority(IDC_LOGALWAYS_FACILITY, IDC_LOGALWAYS_SEVERITY, m_uLogAlwaysPriority);
 	SetDialogFromPriority(IDC_INFO_FACILITY, IDC_INFO_SEVERITY, m_uInfoPriority);
 	SetDialogFromPriority(IDC_WARNING_FACILITY, IDC_WARNING_SEVERITY, m_uWarningPriority);
 	SetDialogFromPriority(IDC_ERROR_FACILITY, IDC_ERROR_SEVERITY, m_uErrorPriority);
+	SetDialogFromPriority(IDC_CRITICAL_FACILITY, IDC_CRITICAL_SEVERITY, m_uCriticalPriority);
+	SetDialogFromPriority(IDC_VERBOSE_FACILITY, IDC_VERBOSE_SEVERITY, m_uVerbosePriority);
 	SetDialogFromPriority(IDC_AUDIT_SUCCESS_FACILITY, IDC_AUDIT_SUCCESS_SEVERITY, m_uAuditSuccessPriority);
 	SetDialogFromPriority(IDC_AUDIT_FAILURE_FACILITY, IDC_AUDIT_FAILURE_SEVERITY, m_uAuditFailurePriority);
 
@@ -280,6 +331,31 @@ void CConfigLogging::OnOK()
 		return;
 	}
 
+	// Write if we have have to forward Log Always events
+	dwValue = (IsDlgButtonChecked( IDC_LOGALWAYS_CHECK) ? 1 : 0);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, LOGALWAYS_ENTRY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+	// Write Log Always event priority
+	dwValue = PriorityFromDialog(IDC_LOGALWAYS_FACILITY, IDC_LOGALWAYS_SEVERITY);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, LOGALWAYS_PRIORITY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+
 	// Write if we have have to forward Information events
 	dwValue = (IsDlgButtonChecked( IDC_INFORMATION_CHECK) ? 1 : 0);
 	dwSize = sizeof (DWORD);
@@ -355,6 +431,56 @@ void CConfigLogging::OnOK()
 		return;
 	}
 
+	// Write if we have have to forward Critical events
+	dwValue = (IsDlgButtonChecked( IDC_CRITICAL_CHECK) ? 1 : 0);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, CRITICAL_ENTRY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+	// Write Critical event priority
+	dwValue = PriorityFromDialog(IDC_CRITICAL_FACILITY, IDC_CRITICAL_SEVERITY);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, CRITICAL_PRIORITY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+
+	// Write if we have have to forward Verbose events
+	dwValue = (IsDlgButtonChecked( IDC_VERBOSE_CHECK) ? 1 : 0);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, VERBOSE_ENTRY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+	// Write Verbose event priority
+	dwValue = PriorityFromDialog(IDC_VERBOSE_FACILITY, IDC_VERBOSE_SEVERITY);
+	dwSize = sizeof (DWORD);
+	if (RegSetValueEx( hKeySection, VERBOSE_PRIORITY, 0, REG_DWORD, (LPBYTE ) &dwValue, dwSize) != ERROR_SUCCESS)
+	{
+		AfxMessageBox( _T( "Error writting new parameters !\n\nPlease retry."), MB_ICONSTOP);
+		RegCloseKey( hKeySection);
+		RegCloseKey( hKeySyslog);
+		RegCloseKey( hKeySoftware);
+		RegCloseKey( hKeyRemote);
+		return;
+	}
+
 	// Write if we have have to forward Audit Success events
 	dwValue = (IsDlgButtonChecked( IDC_AUDIT_SUCCESS_CHECK) ? 1 : 0);
 	dwSize = sizeof (DWORD);
@@ -438,35 +564,50 @@ BOOL CConfigLogging::IsModified()
 	// Start with sensible values.
 	UINT uiFacility = this->GetDefaultFacility();
 	UINT uNewState = CHECK_NOT_ENABLED;
+	UINT logAlwaysPriority = 8*uiFacility + 6;
 	UINT infoPriority = 8*uiFacility + 5;
 	UINT warningPriority = 8*uiFacility + 4;
 	UINT errorPriority = 8*uiFacility + 3;
+	UINT criticalPriority = 8*uiFacility + 2;
+	UINT verbosePriority = 8*uiFacility + 6;
 	UINT auditSuccessPriority = 8*uiFacility + 7;
 	UINT auditFailurePriority = 8*uiFacility + 7;
 
 	// Load values for the checkboxes from the dialog.
+	if (IsDlgButtonChecked( IDC_LOGALWAYS_CHECK))
+		uNewState += CHECK_LOGALWAYS;
 	if (IsDlgButtonChecked( IDC_INFORMATION_CHECK))
 		uNewState += CHECK_INFORMATION;
 	if (IsDlgButtonChecked( IDC_WARNING_CHECK))
 		uNewState += CHECK_WARNING;
 	if (IsDlgButtonChecked( IDC_ERROR_CHECK))
 		uNewState += CHECK_ERROR;
+	if (IsDlgButtonChecked( IDC_CRITICAL_CHECK))
+		uNewState += CHECK_CRITICAL;
+	if (IsDlgButtonChecked( IDC_VERBOSE_CHECK))
+		uNewState += CHECK_VERBOSE;
 	if (IsDlgButtonChecked( IDC_AUDIT_SUCCESS_CHECK))
 		uNewState += CHECK_AUDIT_SUCCESS;
 	if (IsDlgButtonChecked( IDC_AUDIT_FAILURE_CHECK))
 		uNewState += CHECK_AUDIT_FAILURE;
 
 	// Load values for the priorities from the dialog.
+	logAlwaysPriority = PriorityFromDialog(IDC_LOGALWAYS_FACILITY, IDC_LOGALWAYS_SEVERITY);
 	infoPriority = PriorityFromDialog(IDC_INFO_FACILITY, IDC_INFO_SEVERITY);
 	warningPriority = PriorityFromDialog(IDC_WARNING_FACILITY, IDC_WARNING_SEVERITY);
 	errorPriority = PriorityFromDialog(IDC_ERROR_FACILITY, IDC_ERROR_SEVERITY);
+	criticalPriority = PriorityFromDialog(IDC_CRITICAL_FACILITY, IDC_CRITICAL_SEVERITY);
+	verbosePriority = PriorityFromDialog(IDC_VERBOSE_FACILITY, IDC_VERBOSE_SEVERITY);
 	auditSuccessPriority = PriorityFromDialog(IDC_AUDIT_SUCCESS_FACILITY, IDC_AUDIT_SUCCESS_SEVERITY);
 	auditFailurePriority = PriorityFromDialog(IDC_AUDIT_FAILURE_FACILITY, IDC_AUDIT_FAILURE_SEVERITY);
 
 	// Return true or false.
-	return !(infoPriority == m_uInfoPriority &&
+	return !(logAlwaysPriority == m_uLogAlwaysPriority &&
+				infoPriority == m_uInfoPriority &&
 				warningPriority == m_uWarningPriority &&
 				errorPriority == m_uErrorPriority &&
+				criticalPriority == m_uCriticalPriority &&
+				verbosePriority == m_uVerbosePriority &&
 				auditSuccessPriority == m_uAuditSuccessPriority &&
 				auditFailurePriority == m_uAuditFailurePriority &&
 				uNewState == m_uCurrentState);
@@ -573,7 +714,7 @@ UINT CConfigLogging::GetDefaultFacility() const
 	}
     }
 //    return (17);				// Default Facility
-    return (1);				// Default FacilityApplicationƓƂ
+    return (1);				// Default FacilityはApplicationと同列とする
 }
 
 void CConfigLogging::SetDefaultPriorities()
@@ -586,9 +727,12 @@ void CConfigLogging::SetDefaultPriorities()
     m_uAuditSuccessPriority =
 	m_uAuditFailurePriority = 8*uiFacility + 7;
 */
+	m_uLogAlwaysPriority = 9;
 	m_uInfoPriority = 9;
     m_uWarningPriority = 9;
     m_uErrorPriority = 9;
+    m_uCriticalPriority = 9;
+    m_uVerbosePriority = 9;
     m_uAuditSuccessPriority = 9;
 	m_uAuditFailurePriority = 9;
 }
@@ -596,9 +740,12 @@ void CConfigLogging::SetDefaultPriorities()
 void CConfigLogging::OnDefaults() 
 {
 	// Load the checkboxes from the defaults the caller set up.
+	CheckDlgButton( IDC_LOGALWAYS_CHECK, (m_uDefaultChecks & CHECK_LOGALWAYS) ? TRUE : FALSE);
 	CheckDlgButton( IDC_INFORMATION_CHECK, (m_uDefaultChecks & CHECK_INFORMATION) ? TRUE : FALSE);
 	CheckDlgButton( IDC_WARNING_CHECK, (m_uDefaultChecks & CHECK_WARNING) ? TRUE : FALSE);
 	CheckDlgButton( IDC_ERROR_CHECK, (m_uDefaultChecks & CHECK_ERROR) ? TRUE : FALSE);
+	CheckDlgButton( IDC_CRITICAL_CHECK, (m_uDefaultChecks & CHECK_CRITICAL) ? TRUE : FALSE);
+	CheckDlgButton( IDC_VERBOSE_CHECK, (m_uDefaultChecks & CHECK_VERBOSE) ? TRUE : FALSE);
 	CheckDlgButton( IDC_AUDIT_SUCCESS_CHECK, (m_uDefaultChecks & CHECK_AUDIT_SUCCESS) ? TRUE : FALSE);
 	CheckDlgButton( IDC_AUDIT_FAILURE_CHECK, (m_uDefaultChecks & CHECK_AUDIT_FAILURE) ? TRUE : FALSE);
 
@@ -613,9 +760,12 @@ void CConfigLogging::OnDefaults()
 	SetDialogFromPriority(IDC_AUDIT_SUCCESS_FACILITY, IDC_AUDIT_SUCCESS_SEVERITY, 8*uiFacility + 7);
 	SetDialogFromPriority(IDC_AUDIT_FAILURE_FACILITY, IDC_AUDIT_FAILURE_SEVERITY, 8*uiFacility + 7);
 */
+	SetDialogFromPriority(IDC_LOGALWAYS_FACILITY, IDC_LOGALWAYS_SEVERITY, 9);
 	SetDialogFromPriority(IDC_INFO_FACILITY, IDC_INFO_SEVERITY, 9);
 	SetDialogFromPriority(IDC_WARNING_FACILITY, IDC_WARNING_SEVERITY, 9);
 	SetDialogFromPriority(IDC_ERROR_FACILITY, IDC_ERROR_SEVERITY, 9);
+	SetDialogFromPriority(IDC_CRITICAL_FACILITY, IDC_CRITICAL_SEVERITY, 9);
+	SetDialogFromPriority(IDC_VERBOSE_FACILITY, IDC_VERBOSE_SEVERITY, 9);
 	SetDialogFromPriority(IDC_AUDIT_SUCCESS_FACILITY, IDC_AUDIT_SUCCESS_SEVERITY, 9);
 	SetDialogFromPriority(IDC_AUDIT_FAILURE_FACILITY, IDC_AUDIT_FAILURE_SEVERITY, 9);
 }
