@@ -1,5 +1,6 @@
 // NTSyslogCtrlDlg.cpp : implementation file
 //
+//#define _WIN2K	// これを定義するとWindows Eventing 6.0関連のコードをはずす
 
 #include "stdafx.h"
 #include "NTSyslogCtrl.h"
@@ -10,9 +11,11 @@
 #include "SyslogDaemonDlg.h"
 #include "SelectServerDlg.h"
 
+#ifndef _WIN2K
 #include <winevt.h>
 
 #pragma comment(lib, "wevtapi.lib")
+#endif
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -134,7 +137,7 @@ void CNTSyslogCtrlDlg::ReadMachineEventLogSettings(int good_query)
 		osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
 		GetVersionEx (&osvi);
 
-		if (osvi.dwMajorVersion < 6)
+		if (osvi.dwMajorVersion < 6 || oldVersion)
 		{
 			// Connect to the selected computer's registry on HKLM
 			if (RegConnectRegistry( (char*)(LPCTSTR)m_csComputer, HKEY_LOCAL_MACHINE, &hKeyRemote) == ERROR_SUCCESS)
@@ -179,6 +182,7 @@ void CNTSyslogCtrlDlg::ReadMachineEventLogSettings(int good_query)
 		}//end if OS version check
 		else // Windows Vista/2008
 		{
+#ifndef _WIN2K
 			EVT_HANDLE hReadEvent = NULL;
 			DWORD dwBufferSize = 0;
 			DWORD dwBufferUsed = 0;
@@ -240,6 +244,7 @@ void CNTSyslogCtrlDlg::ReadMachineEventLogSettings(int good_query)
 			m_csaEventlogSelectSize --;
 			if (hChannels) EvtClose(hChannels);
 			if (pBuffer) free(pBuffer);
+#endif
 		}
 	}//end if(good_query == TRUE)
 	else
@@ -335,21 +340,22 @@ BOOL CNTSyslogCtrlDlg::OnInitDialog()
 	// Load last computer from the registry
 	m_csComputer = AfxGetApp()->GetProfileString( COMPUTERS_SECTION, LAST_COMPUTER_ENTRY );
 
-	// R2pRg[̏
+	// R2専用コントロールの初期化
 	HKEY	hReg;
 	long	rc, rv;
+	DWORD	dw;
 
 	m_NoFullComputerName = false;
-	rc = RegOpenKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, KEY_READ, &hReg);
+	rc = RegCreateKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, REG_NONE, REG_OPTION_NON_VOLATILE, KEY_WRITE|KEY_READ, NULL, &hReg, &dw);
 	if( rc == ERROR_SUCCESS )
 	{
 		DWORD   typ,size = sizeof(rv);
 
-		// tRs[^o͗}tO
+		// フルコンピュータ名出力抑制フラグ
 		rc = RegQueryValueEx(hReg, "FullComputerName", NULL, &typ, (BYTE*)&rv, &size) ;
 		if (rc == 0 && rv == 1) { m_NoFullComputerName = true; } else { m_NoFullComputerName = false; }
 
-		// tRs[^o͗}tO
+		// デバッグモード有効化フラグ
 		rc = RegQueryValueEx(hReg, "EnableDebugMode", NULL, &typ, (BYTE*)&rv, &size) ;
 		if (rc == 0 && rv == 1) { m_DebugMode = true; } else { m_DebugMode = false; }
 	}
@@ -531,7 +537,7 @@ BOOL CNTSyslogCtrlDlg::DisplayStatus(UINT nIconID, DWORD dwServiceState)
 	switch (nIconID)
 	{
 	case IDI_GREEN_ICON: // Service started
-		SetDlgItemText( IDC_STATUS, _T( "T[rX͓쒆ł"));
+		SetDlgItemText( IDC_STATUS, _T( "Service is running."));
 		GetDlgItem( IDC_START)->EnableWindow( FALSE);
 		GetDlgItem( IDC_STOP)->EnableWindow( TRUE);
 		break;
@@ -539,35 +545,35 @@ BOOL CNTSyslogCtrlDlg::DisplayStatus(UINT nIconID, DWORD dwServiceState)
 		switch (dwServiceState)
 		{
 		case SERVICE_START_PENDING:
-			SetDlgItemText( IDC_STATUS, _T( "T[rX͊Jn܂"));
+			SetDlgItemText( IDC_STATUS, _T( "Service is starting."));
 			break;
 		case SERVICE_STOP_PENDING:
-			SetDlgItemText( IDC_STATUS, _T( "T[rX͒~܂"));
+			SetDlgItemText( IDC_STATUS, _T( "Service is stopping."));
 			break;
 		case SERVICE_CONTINUE_PENDING:
-			SetDlgItemText( IDC_STATUS, _T( "T[rXĊJĂ܂"));
+			SetDlgItemText( IDC_STATUS, _T( "Service is leaving pause."));
 			break;
 		case SERVICE_PAUSE_PENDING:
-			SetDlgItemText( IDC_STATUS, _T( "T[rXꎞ~ł"));
+			SetDlgItemText( IDC_STATUS, _T( "Service is entering in pause."));
 			break;
 		case SERVICE_PAUSED:
-			SetDlgItemText( IDC_STATUS, _T( "T[rX͈ꎞ~܂"));
+			SetDlgItemText( IDC_STATUS, _T( "Service is paused."));
 			break;
 		default:
-			SetDlgItemText( IDC_STATUS, _T( "T[rX͕sȏԂł"));
+			SetDlgItemText( IDC_STATUS, _T( "Unknown state !."));
 			break;
 		}
 		GetDlgItem( IDC_START)->EnableWindow( FALSE);
 		GetDlgItem( IDC_STOP)->EnableWindow( FALSE);
 		break;
 	case IDI_RED_ICON: // Service stoppped
-		SetDlgItemText( IDC_STATUS, _T( "T[rX͒~Ă܂"));
+		SetDlgItemText( IDC_STATUS, _T( "Service is stopped."));
 		GetDlgItem( IDC_START)->EnableWindow( TRUE);
 		GetDlgItem( IDC_STOP)->EnableWindow( FALSE);
 		break;
 	case IDI_ERROR_ICON: // Error
 	default:
-		SetDlgItemText( IDC_STATUS, _T( "T[rX̓CXg[ĂȂG[܂"));
+		SetDlgItemText( IDC_STATUS, _T( "Service is not installed or error encountered !"));
 		GetDlgItem( IDC_START)->EnableWindow( FALSE);
 		GetDlgItem( IDC_STOP)->EnableWindow( FALSE);
 		break;
@@ -634,22 +640,23 @@ void CNTSyslogCtrlDlg::OnStartService()
 
 	HKEY	hReg;
 	long	rc;
+	DWORD	dw;
 
 	UpdateData(true);
-	rc = RegOpenKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, KEY_WRITE, &hReg);
+	rc = RegCreateKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, REG_NONE, REG_OPTION_NON_VOLATILE, KEY_WRITE|KEY_READ, NULL, &hReg, &dw);
 	if( rc == ERROR_SUCCESS )
 	{
 		DWORD   val,size = sizeof(val);
 
-		// tRs[^o͗}tO
+		// フルコンピュータ名出力抑制フラグ
 		val = m_NoFullComputerName;
 	    rc = RegSetValueEx(hReg, "FullComputerName", 0, REG_DWORD, (BYTE*)&val, size);
 
-		// R[h
-		val = 0; // HinemosłUTF-8Œ
+		// 文字コード
+		val = 0; // Hinemos版はUTF-8固定
 	    rc = RegSetValueEx(hReg, "CharCode", 0, REG_DWORD, (BYTE*)&val, size);
 
-		// fobO[h
+		// デバッグモード
 		val = m_DebugMode;
 	    rc = RegSetValueEx(hReg, "EnableDebugMode", 0, REG_DWORD, (BYTE*)&val, size);
 	}
@@ -723,22 +730,23 @@ void CNTSyslogCtrlDlg::OnBnClickedCancel()
 {
 	HKEY	hReg;
 	long	rc;
+	DWORD	dw;
 
 	UpdateData(true);
-	rc = RegOpenKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, KEY_WRITE, &hReg);
+	rc = RegCreateKeyEx(HKEY_LOCAL_MACHINE, NTSYSLOG_REGISTRY_KEY, 0, REG_NONE, REG_OPTION_NON_VOLATILE, KEY_WRITE|KEY_READ, NULL, &hReg, &dw);
 	if( rc == ERROR_SUCCESS )
 	{
 		DWORD   val,size = sizeof(val);
 
-		// tRs[^o͗}tO
+		// フルコンピュータ名出力抑制フラグ
 		val = m_NoFullComputerName;
 	    rc = RegSetValueEx(hReg, "FullComputerName", 0, REG_DWORD, (BYTE*)&val, size);
 
-		// R[h
-		val = 0; // HinemosłUTF-8Œ
+		// 文字コード
+		val = 0; // Hinemos版はUTF-8固定
 	    rc = RegSetValueEx(hReg, "CharCode", 0, REG_DWORD, (BYTE*)&val, size);
 
-		// fobO[h
+		// デバッグモード
 		val = m_DebugMode;
 	    rc = RegSetValueEx(hReg, "EnableDebugMode", 0, REG_DWORD, (BYTE*)&val, size);
 	}
