@@ -22,6 +22,9 @@ import java.util.ResourceBundle;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.eclipse.core.runtime.ILogListener;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
 import org.eclipse.ui.plugin.AbstractUIPlugin;
@@ -139,6 +142,8 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 	private ResourceBundle resourceBundle;
 
 	protected String separator;
+	
+	private ILogListener listener;
 
 	// ----- コンストラクタ ----- //
 
@@ -149,6 +154,10 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 		super();
 		m_log.debug("ClusterControlPlugin()");
 
+		// log4jを使うための登録処理
+		listener = new Listener();
+		Platform.addLogListener(listener);
+		
 		plugin = this;
 		try {
 			resourceBundle = ResourceBundle
@@ -175,7 +184,31 @@ public class ClusterControlPlugin extends AbstractUIPlugin {
 		long startDate = System.currentTimeMillis();
 		m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
 	}
-
+	
+	private class Listener implements ILogListener {  
+		@Override
+		public void logging(final IStatus status, final String plugin) {
+			if (status.getSeverity() == IStatus.INFO) {
+				if (status.getException() == null) {
+					m_log.info(status.getMessage());
+				} else {
+					m_log.info(status.getMessage(), status.getException());
+				}
+			} else if (status.getSeverity() == IStatus.WARNING) {
+				if (status.getException() == null) {
+					m_log.warn(status.getMessage());
+				} else {
+					m_log.warn(status.getMessage(), status.getException());
+				}
+			} else {
+				if (status.getException() == null) {
+					m_log.error(status.getMessage());
+				} else {
+					m_log.error(status.getMessage(), status.getException());
+				}
+			}
+		} 
+	}
 	// ----- instance メソッド ----- //
 
 	/**
