@@ -1,31 +1,25 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.composite;
 
-import java.text.SimpleDateFormat;
 import java.util.ArrayList;
-import java.util.Date;
-
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.viewers.ViewerSorter;
 
-import com.clustercontrol.bean.DayOfWeekConstant;
-import com.clustercontrol.bean.Schedule;
-import com.clustercontrol.bean.ScheduleConstant;
-import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.common.Schedule;
 
 /**
  * CommonTableViewerクラス用のViewerSorterクラス<BR>
@@ -36,13 +30,13 @@ import com.clustercontrol.util.Messages;
 public class CommonTableViewerSorter extends ViewerSorter {
 	/** カラムインデックス */
 	protected int m_columnIndex = 0;
-	
+
 	/** カラムインデックス */
 	protected int m_columnIndex2 = 0;
-	
+
 	/** ソートオーダー */
 	protected int m_order = 1;
-	
+
 	/**
 	 * コンストラクタ
 	 * 
@@ -53,7 +47,7 @@ public class CommonTableViewerSorter extends ViewerSorter {
 	public CommonTableViewerSorter(int columnIndex) {
 		this(columnIndex,-1,1);
 	}
-	
+
 	/**
 	 * コンストラクタ
 	 * 
@@ -75,15 +69,15 @@ public class CommonTableViewerSorter extends ViewerSorter {
 	 */
 	public CommonTableViewerSorter(int columnIndex, int columnIndex2, int order) {
 		super();
-		
+
 		this.m_columnIndex = columnIndex;
 		//セカンドソーターを必要としない場合には-1が入ってる。
 		this.m_columnIndex2 = columnIndex2;
-		
+
 		//昇順・降順の設定　1: 昇順　-1:降順
 		this.m_order = order;
 	}
-	
+
 	/**
 	 * 比較処理
 	 * 
@@ -98,17 +92,17 @@ public class CommonTableViewerSorter extends ViewerSorter {
 		if (e1 instanceof ArrayList && e2 instanceof ArrayList) {
 			Object object1 = ((ArrayList) e1).get(m_columnIndex);
 			Object object2 = ((ArrayList) e2).get(m_columnIndex);
-			
+
 			int rtn = 0;
 			rtn = subCompare(viewer, object1, object2);
-			
+
 			//第1ソートが等価で第２ソートが有効な場合には
 			//第2ソートを行う。
 			if( rtn == 0 && m_columnIndex2 >= 0){
-				
+
 				object1 = ((ArrayList) e1).get(m_columnIndex2);
 				object2 = ((ArrayList) e2).get(m_columnIndex2);
-				
+
 				rtn = subCompare(viewer, object1, object2);
 			}
 			if (m_order == 1) {
@@ -117,9 +111,9 @@ public class CommonTableViewerSorter extends ViewerSorter {
 				return - rtn;
 			}
 		}
-		return 0;	
+		return 0;
 	}
-	
+
 	private int subCompare(Viewer viewer, Object obj1, Object obj2) {
 		int rtn = 0;
 		if (obj1 == null && obj2 != null) {
@@ -129,42 +123,60 @@ public class CommonTableViewerSorter extends ViewerSorter {
 		} else if (obj1 != null && obj2 != null &&
 				obj1 instanceof Comparable && obj2 instanceof Comparable &&
 				obj1.getClass().equals(obj2.getClass())) {
-			rtn = ((Comparable)obj1).compareTo((Comparable)obj2);
+			rtn = ((Comparable)obj1).compareTo(obj2);
 		} else if (obj1 != null && obj2 != null &&
 				obj1 instanceof Schedule && obj2 instanceof Schedule){
-			// TODO メジャーバージョンアップのタイミングでSchedule.javaのcompareToに転記する
 			Schedule schedule1 = (Schedule)obj1;
 			Schedule schedule2 = (Schedule)obj2;
-			rtn = ((Integer)(schedule1.getType())).compareTo((Integer)(schedule2.getType()));
-			if (rtn == 0) {
-				String scheduleString1 = "";
-				String scheduleString2 = "";
-				SimpleDateFormat formatter = null;
-				if (schedule1.getType() == ScheduleConstant.TYPE_EVERY_YEAR) {
-					formatter = new SimpleDateFormat("MM/dd HH:mm");
-				} else if (schedule1.getType() == ScheduleConstant.TYPE_EVERY_MONTH) {
-					formatter = new SimpleDateFormat("dd'" + Messages.getString("monthday") + "' HH:mm");
-				} else if (schedule1.getType() == ScheduleConstant.TYPE_EVERY_DAY) {
-					formatter = new SimpleDateFormat("HH:mm");
-				} else if (schedule1.getType() == ScheduleConstant.TYPE_EVERY_HOUR) {
-					formatter = new SimpleDateFormat("mm'" + Messages.getString("minute") + "'");
-				} else if (schedule1.getType() == ScheduleConstant.TYPE_EVERY_WEEK) {
-					formatter = new SimpleDateFormat(" HH:mm");
-				} else {
-					// 通らないはず。
-					System.out.println("error 154");
-				}
-				scheduleString1 = formatter.format(schedule1.getDate());
-				scheduleString2 = formatter.format(schedule2.getDate());
-				rtn = scheduleString1.compareTo(scheduleString2);
+
+			// month
+			if (schedule1.getMonth() != null && schedule2.getMonth() == null) {
+				return 1;
+			} else if (schedule1.getMonth() == null && schedule2.getMonth() != null){
+				return -1;
+			} else if (schedule1.getMonth() != null && schedule2.getMonth() != null) {
+				return schedule1.getMonth() - schedule2.getMonth();
 			}
+			// day
+			if (schedule1.getDay() != null && schedule2.getDay() == null) {
+				return 1;
+			} else if (schedule1.getDay() == null && schedule2.getDay() != null){
+				return -1;
+			} else if (schedule1.getDay() != null && schedule2.getDay() != null) {
+				return schedule1.getDay() - schedule2.getDay();
+			}
+			// week
+			if (schedule1.getWeek() != null && schedule2.getWeek() == null) {
+				return 1;
+			} else if (schedule1.getWeek() == null && schedule2.getWeek() != null){
+				return -1;
+			} else if (schedule1.getWeek() != null && schedule2.getWeek() != null) {
+				return schedule1.getWeek() - schedule2.getWeek();
+			}
+			// hour
+			if (schedule1.getHour() != null && schedule2.getHour() == null) {
+				return 1;
+			} else if (schedule1.getHour() == null && schedule2.getHour() != null){
+				return -1;
+			} else if (schedule1.getHour() != null && schedule2.getHour() != null) {
+				return schedule1.getHour() - schedule2.getHour();
+			}
+			// minute
+			if (schedule1.getMinute() != null && schedule2.getMinute() == null) {
+				return 1;
+			} else if (schedule1.getMinute() == null && schedule2.getMinute() != null){
+				return -1;
+			} else if (schedule1.getMinute() != null && schedule2.getMinute() != null) {
+				return schedule1.getMinute() - schedule2.getMinute();
+			}
+			return 0;
 		}else {
 			// 文字列で比較。
 			rtn = super.compare(viewer, obj1, obj2);
 		}
 		return rtn;
 	}
-	
+
 	/**
 	 * ソート対象カラムインデックス取得
 	 * 
