@@ -63,7 +63,6 @@ public class EndpointManager {
 	public static int m_httpConnectTimeout = LoginManager.VALUE_HTTP_CONNECT_TIMEOUT;
 	public static int m_httpRequestTimeout = LoginManager.VALUE_HTTP_REQUEST_TIMEOUT;
 
-
 	private static class EndpointList {
 		/*
 		 * endpointListはマネージャ一覧を示す。
@@ -169,6 +168,8 @@ public class EndpointManager {
 			}
 
 			if (endpoint != null) {
+				// set latest timeout
+				setBindingProvider(endpoint, username, password, urlPrefix + key + wsdlSuffix);
 				return endpoint;
 			}
 			String tmpKey = null;
@@ -388,14 +389,14 @@ public class EndpointManager {
 		}
 	}
 
-	public static void init(String user, String pass, String managerAddressList,
+	public static void init(String user, String pass, String managerAddressList, 
 			int httpConnectTimeout, int httpRequestTimeout) throws MalformedURLException {
 		username = user;
 		password = pass;
 		endpointList = new EndpointList();
 		m_httpConnectTimeout = httpConnectTimeout;
 		m_httpRequestTimeout = httpRequestTimeout;
-
+		
 		for (String managerAddress : managerAddressList.split(",")) {
 
 			// TODO ユーザ/パスワードチェックを実装する必要あり。
@@ -433,7 +434,10 @@ public class EndpointManager {
 		// bp.getRequestContext().put(BindingProviderProperties.REQUEST_TIMEOUT, 60*1000);
 		bp.getRequestContext().put("com.sun.xml.internal.ws.connect.timeout", m_httpConnectTimeout * 1000);
 		bp.getRequestContext().put("com.sun.xml.internal.ws.request.timeout", m_httpRequestTimeout * 1000);
-
+		if (m_log.isDebugEnabled()) {
+			m_log.debug("ws timeout updated : connectTimeout = " + m_httpConnectTimeout + ", requestTimeout = " + m_httpRequestTimeout + "");
+		}
+		
 		((SOAPBinding)bp.getBinding()).setMTOMEnabled(true);
 	}
 
