@@ -15,6 +15,10 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.view;
 
+import javax.naming.NamingException;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.action.ActionContributionItem;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IContributionItem;
@@ -24,6 +28,8 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.ui.internal.ViewPluginAction;
 import org.eclipse.ui.part.ViewPart;
 
+import com.clustercontrol.util.LoginManager;
+
 /**
  * 共通ViewPartクラス<BR>
  * 
@@ -33,7 +39,18 @@ import org.eclipse.ui.part.ViewPart;
  * @since 1.0.0
  */
 public class CommonViewPart extends ViewPart {
+	
+	// ログ
+	private static Log m_log = LogFactory.getLog( CommonViewPart.class );
 
+	/**
+	 * コンストラクタ
+	 */
+	public CommonViewPart(){
+		super();
+		login();  // ログインしていない場合は、ビュー表示前に必ずログインダイアログを出すようにする
+	}
+	
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -104,4 +121,14 @@ public class CommonViewPart extends ViewPart {
 		action.selectionChanged(selection);
 	}
 
+	/**
+	 *  ログイン
+	 */
+	private void login() {
+		try {
+			LoginManager.getContextManager().getNamingContext();
+		} catch (NamingException e) {
+			m_log.warn("login(), " + e.getMessage(), e);
+		}
+	}
 }
\ No newline at end of file
