@@ -34,6 +34,7 @@ import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
 import com.clustercontrol.accesscontrol.composite.action.UserDoubleClickListener;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.accesscontrol.util.UserFilterPropertyUtil;
+import com.clustercontrol.accesscontrol.view.UserListView;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.util.Messages;
@@ -63,6 +64,9 @@ public class UserListComposite extends Composite {
 	/** ユーザID */
 	protected String m_uid = null;
 
+	/** 呼び出し元ビュー */
+	private UserListView view = null;
+
 	/**
 	 * コンストラクタ
 	 * 
@@ -73,8 +77,9 @@ public class UserListComposite extends Composite {
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
 	 */
-	public UserListComposite(Composite parent, int style) {
+	public UserListComposite(Composite parent, int style, UserListView view) {
 		super(parent, style);
+		this.view = view;
 		initialize();
 	}
 
@@ -120,7 +125,7 @@ public class UserListComposite extends Composite {
 				GetUserListTableDefine.SORT_ORDER);
 
 		// ダブルクリックリスナの追加
-		m_viewer.addDoubleClickListener(new UserDoubleClickListener(this));
+		m_viewer.addDoubleClickListener(new UserDoubleClickListener(this, this.view));
 	}
 
 	/**
