@@ -41,6 +41,7 @@ import com.clustercontrol.accesscontrol.bean.UserConstant;
 import com.clustercontrol.accesscontrol.bean.UserRoleList;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.accesscontrol.util.UserPropertyUtil;
+import com.clustercontrol.accesscontrol.view.UserListView;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.PropertyTreeItem;
@@ -85,6 +86,9 @@ public class UserDialog extends CommonDialog {
 
 	private final UserRoleList _userRoleList;
 	private boolean permission = false;		// 現在のユーザが変更権限をもつか否か
+	
+	/** 呼び出し元ビュー **/
+	private UserListView view = null;
 
 	/**
 	 * コンストラクタ
@@ -93,11 +97,12 @@ public class UserDialog extends CommonDialog {
 	 * @param uid ユーザID
 	 * @param isModifyDialog 変更用ダイアログとして利用する場合は、true
 	 */
-	public UserDialog(Shell parent, String uid, boolean isModifyDialog) {
+	public UserDialog(Shell parent, String uid, boolean isModifyDialog, UserListView view) {
 		super(parent);
 
 		this.uid = uid;
 		this.isModifyDialog = isModifyDialog;
+		this.view = view;
 
 		_userRoleList = UserPropertyUtil.getRoleList();
 
@@ -619,6 +624,8 @@ public class UserDialog extends CommonDialog {
 			else{
 				this.action();
 			}
+			
+			this.view.update();
 
 		} else {
 			this.displayError(result);
