@@ -312,6 +312,18 @@ public class UserFilterPropertyUtil {
 		Property vmManagementExecute = new Property(RoleConstant.VMMANAGEMENT_EXECUTE,
 				Messages.getString("vm.management.execute", locale),
 				PropertyConstant.EDITOR_BOOL);
+		// クラウド管理参照
+		Property cloudManagementRead = new Property(RoleConstant.CLOUDMANAGEMENT_READ, Messages
+				.getString("cloud.management.read", locale),
+				PropertyConstant.EDITOR_BOOL);
+		// クラウド管理設定
+		Property cloudManagementWrite = new Property(RoleConstant.CLOUDMANAGEMENT_WRITE, Messages
+				.getString("cloud.management.write", locale),
+				PropertyConstant.EDITOR_BOOL);
+		// クラウド管理実行
+		Property cloudManagementExecute = new Property(RoleConstant.CLOUDMANAGEMENT_EXECUTE,
+				Messages.getString("cloud.management.execute", locale),
+				PropertyConstant.EDITOR_BOOL);
 
 		// 値を初期化
 		uid.setValue("");
@@ -345,6 +357,9 @@ public class UserFilterPropertyUtil {
 		vmManagementRead.setValue(Boolean.valueOf(false));
 		vmManagementWrite.setValue(Boolean.valueOf(false));
 		vmManagementExecute.setValue(Boolean.valueOf(false));
+		cloudManagementRead.setValue(Boolean.valueOf(false));
+		cloudManagementWrite.setValue(Boolean.valueOf(false));
+		cloudManagementExecute.setValue(Boolean.valueOf(false));
 
 		// 変更可及びコピー可を設定
 		uid.setModify(PropertyConstant.MODIFY_OK);
@@ -376,7 +391,10 @@ public class UserFilterPropertyUtil {
 		vmManagementRead.setModify(PropertyConstant.MODIFY_OK);
 		vmManagementWrite.setModify(PropertyConstant.MODIFY_OK);
 		vmManagementExecute.setModify(PropertyConstant.MODIFY_OK);
-
+		cloudManagementRead.setModify(PropertyConstant.MODIFY_OK);
+		cloudManagementWrite.setModify(PropertyConstant.MODIFY_OK);
+		cloudManagementExecute.setModify(PropertyConstant.MODIFY_OK);
+		
 		Property property = new Property(null, null, "");
 
 		// 初期表示ツリーを構成。
@@ -417,6 +435,11 @@ public class UserFilterPropertyUtil {
 		access.addChildren(vmManagementWrite);
 		access.addChildren(vmManagementExecute);
 
+		// クラウド管理オプションが適用されている場合
+		access.addChildren(cloudManagementRead);
+		access.addChildren(cloudManagementWrite);
+		access.addChildren(cloudManagementExecute);
+
 		m_log.debug("successful in getting properties of user's filter.");
 		return property;
 	}
