@@ -122,6 +122,15 @@ public class UserPropertyUtil {
 		m_writeRoles.add(RoleConstant.VMMANAGEMENT_WRITE);
 		m_execRoles.add(RoleConstant.VMMANAGEMENT_EXECUTE);
 
+		// CLOUD Option関連
+		m_roles.add(RoleConstant.CLOUDMANAGEMENT_READ);
+		m_roles.add(RoleConstant.CLOUDMANAGEMENT_WRITE);
+		m_roles.add(RoleConstant.CLOUDMANAGEMENT_EXECUTE);
+
+		m_readRoles.add(RoleConstant.CLOUDMANAGEMENT_READ);
+		m_writeRoles.add(RoleConstant.CLOUDMANAGEMENT_WRITE);
+		m_execRoles.add(RoleConstant.CLOUDMANAGEMENT_EXECUTE);
+
 		// HA Option関連
 		// No Necessity
 	}
@@ -350,6 +359,15 @@ public class UserPropertyUtil {
 		//仮想化管理実行
 		Property vmManagementExecute =
 			new Property(RoleConstant.VMMANAGEMENT_EXECUTE, Messages.getString("vm.management.execute", locale), PropertyConstant.EDITOR_BOOL);
+		//クラウド管理参照
+		Property cloudManagementRead =
+			new Property(RoleConstant.CLOUDMANAGEMENT_READ, Messages.getString("cloud.management.read", locale), PropertyConstant.EDITOR_BOOL);
+		//クラウド管理設定
+		Property cloudManagementWrite =
+			new Property(RoleConstant.CLOUDMANAGEMENT_WRITE, Messages.getString("cloud.management.write", locale), PropertyConstant.EDITOR_BOOL);
+		//クラウド管理実行
+		Property cloudManagementExecute =
+			new Property(RoleConstant.CLOUDMANAGEMENT_EXECUTE, Messages.getString("cloud.management.execute", locale), PropertyConstant.EDITOR_BOOL);
 
 		//値を初期化
 		uid.setValue("");
@@ -387,6 +405,9 @@ public class UserPropertyUtil {
 		vmManagementRead.setValue(Boolean.valueOf(false));
 		vmManagementWrite.setValue(Boolean.valueOf(false));
 		vmManagementExecute.setValue(Boolean.valueOf(false));
+		cloudManagementRead.setValue(Boolean.valueOf(false));
+		cloudManagementWrite.setValue(Boolean.valueOf(false));
+		cloudManagementExecute.setValue(Boolean.valueOf(false));
 
 		//モードにより、変更可及びコピー可を設定
 		if(mode == PropertyConstant.MODE_ADD){
@@ -418,6 +439,9 @@ public class UserPropertyUtil {
 			vmManagementRead.setModify(PropertyConstant.MODIFY_OK);
 			vmManagementWrite.setModify(PropertyConstant.MODIFY_OK);
 			vmManagementExecute.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementRead.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementWrite.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementExecute.setModify(PropertyConstant.MODIFY_OK);
 		}
 		else if(mode == PropertyConstant.MODE_MODIFY){
 			name.setModify(PropertyConstant.MODIFY_OK);
@@ -447,6 +471,9 @@ public class UserPropertyUtil {
 			vmManagementRead.setModify(PropertyConstant.MODIFY_OK);
 			vmManagementWrite.setModify(PropertyConstant.MODIFY_OK);
 			vmManagementExecute.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementRead.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementWrite.setModify(PropertyConstant.MODIFY_OK);
+			cloudManagementExecute.setModify(PropertyConstant.MODIFY_OK);
 		}
 
 		Property property = new Property(null, null, "");
@@ -493,6 +520,11 @@ public class UserPropertyUtil {
 		access.addChildren(vmManagementWrite);
 		access.addChildren(vmManagementExecute);
 
+		// クラウド管理オプションが適用されている場合
+		access.addChildren(cloudManagementRead);
+		access.addChildren(cloudManagementWrite);
+		access.addChildren(cloudManagementExecute);
+		
 		return property;
 	}
 
