@@ -77,7 +77,7 @@ public class UserListView extends CommonViewPart {
 		layout.marginHeight = 0;
 		layout.marginWidth = 0;
 
-		m_userList = new UserListComposite(parent, SWT.NONE);
+		m_userList = new UserListComposite(parent, SWT.NONE, this);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
