@@ -139,6 +139,9 @@ public class CalendarIdListComposite extends Composite {
 			// 権限なし
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
+			
+			// カレンダを操作できないようにする
+			setEnabled(false);
 
 		} catch (Exception e) {
 			// 上記以外の例外
@@ -164,6 +167,14 @@ public class CalendarIdListComposite extends Composite {
 	public void setEnabled(boolean enabled) {
 		this.comboCalendarId.setEnabled(enabled);
 	}
+	
+	/* (非 Javadoc)
+	 * @see org.eclipse.swt.widgets.Control#getEnabled()
+	 */
+	@Override
+	public boolean getEnabled() {
+		return this.comboCalendarId.getEnabled();
+	}
 
 	/* (非 Javadoc)
 	 * @see org.eclipse.swt.widgets.Combo#getText()
@@ -178,4 +189,8 @@ public class CalendarIdListComposite extends Composite {
 	public void setText(String string) {
 		this.comboCalendarId.setText(string);
 	}
-}
\ No newline at end of file
+
+	public void addText(String string) {
+		this.comboCalendarId.add(string);
+	}
+} 
\ No newline at end of file
