@@ -35,6 +35,7 @@ import com.clustercontrol.calendar.composite.action.CalendarDoubleClickListener;
 import com.clustercontrol.calendar.composite.action.CalendarSelectionChangedListener;
 import com.clustercontrol.calendar.composite.action.VerticalBarSelectionListener;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
+import com.clustercontrol.calendar.view.CalendarListView;
 import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.calendar.CalendarInfo;
@@ -59,6 +60,9 @@ public class CalendarListComposite extends Composite {
 	protected String m_calendarId = null;
 	protected Date m_base = null;
 
+	/** 呼び出し元ビュー */
+	private CalendarListView view = null;
+	
 	/**
 	 * コンストラクタ
 	 * 
@@ -66,8 +70,9 @@ public class CalendarListComposite extends Composite {
 	 * @param style
 	 * @since 2.0.0
 	 */
-	public CalendarListComposite(Composite parent, int style) {
+	public CalendarListComposite(Composite parent, int style, CalendarListView view) {
 		super(parent, style);
+		this.view = view;
 		initialize();
 	}
 
@@ -110,7 +115,7 @@ public class CalendarListComposite extends Composite {
 		m_viewer.addSelectionChangedListener(new CalendarSelectionChangedListener(this));
 
 		// ダブルクリックリスナの追加
-		m_viewer.addDoubleClickListener(new CalendarDoubleClickListener(this));
+		m_viewer.addDoubleClickListener(new CalendarDoubleClickListener(this, this.view));
 
 		m_viewer.getTable().getVerticalBar().addSelectionListener(
 				new VerticalBarSelectionListener(this));
