@@ -38,6 +38,7 @@ import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.calendar.util.CalendarAddPropertyUtil;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
+import com.clustercontrol.calendar.view.AddInfoListView;
 import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -73,6 +74,10 @@ public class AddInfoDialog extends CommonDialog {
 
 	/** カレンダテーブル */
 	private TableTree table = null;
+	
+	/** 呼び出し元ビュー */
+	private AddInfoListView view = null;
+
 	/**
 	 * 指定した形式のダイアログのインスタンスを取得します。<BR>
 	 * 
@@ -83,13 +88,14 @@ public class AddInfoDialog extends CommonDialog {
 	 * @param mode
 	 *            表示モード
 	 */
-	public AddInfoDialog(Shell parent, String id, Date from, Date to, int mode) {
+	public AddInfoDialog(Shell parent, String id, Date from, Date to, int mode, AddInfoListView view) {
 		super(parent);
 
 		this.id = id;
 		this.from = from;
 		this.to = to;
 		this.mode = mode;
+		this.view = view;
 	}
 
 	/**
@@ -429,6 +435,8 @@ public class AddInfoDialog extends CommonDialog {
 			else{
 				super.okPressed();
 			}
+			
+			this.view.update(this.id);
 
 		} else {
 			this.displayError(result);
