@@ -39,6 +39,7 @@ import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.calendar.bean.CalendarConstant;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
 import com.clustercontrol.calendar.util.CalendarPropertyUtil;
+import com.clustercontrol.calendar.view.CalendarListView;
 import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -70,6 +71,9 @@ public class CalendarDialog extends CommonDialog {
 
 	/** カレンダテーブル */
 	private TableTree table = null;
+	
+	/** 呼び出し元ビュー */
+	private CalendarListView view = null;
 
 	/**
 	 * 指定した形式のダイアログのインスタンスを返します。
@@ -81,11 +85,12 @@ public class CalendarDialog extends CommonDialog {
 	 * @param mode
 	 *            表示モード
 	 */
-	public CalendarDialog(Shell parent, String uid, int mode) {
+	public CalendarDialog(Shell parent, String uid, int mode, CalendarListView view) {
 		super(parent);
 
 		this.id = uid;
 		this.mode = mode;
+		this.view = view;
 	}
 
 	/**
@@ -423,6 +428,8 @@ public class CalendarDialog extends CommonDialog {
 			else{
 				super.okPressed();
 			}
+			
+			this.view.update();
 
 		} else {
 			this.displayError(result);
