@@ -38,6 +38,7 @@ import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
 import com.clustercontrol.calendar.util.WeekdayPropertyUtil;
+import com.clustercontrol.calendar.view.WeekdayInfoListView;
 import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -76,6 +77,9 @@ public class WeekdayInfoDialog extends CommonDialog {
 	/** カレンダテーブル **/
 	private TableTree table = null;
 
+	/** 呼び出し元ビュー */
+	private WeekdayInfoListView view = null;
+
 	/**
 	 * 指定した形式のダイアログのインスタンスを取得します。<BR>
 	 * 
@@ -86,7 +90,7 @@ public class WeekdayInfoDialog extends CommonDialog {
 	 * @param mode
 	 *            表示モード
 	 */
-	public WeekdayInfoDialog(Shell parent, String id, Integer weekday, Date from, Date to, int mode) {
+	public WeekdayInfoDialog(Shell parent, String id, Integer weekday, Date from, Date to, int mode, WeekdayInfoListView view) {
 		super(parent);
 
 		this.id = id;
@@ -94,6 +98,7 @@ public class WeekdayInfoDialog extends CommonDialog {
 		this.from = from;
 		this.to = to;
 		this.mode = mode;
+		this.view = view;
 	}
 
 	/**
@@ -435,6 +440,8 @@ public class WeekdayInfoDialog extends CommonDialog {
 			else{
 				super.okPressed();
 			}
+			
+			this.view.update(this.id);
 
 		} else {
 			this.displayError(result);
