@@ -84,7 +84,7 @@ public class CalendarListView extends CommonViewPart {
 		gridData.horizontalSpan = 1;
 		m_sash.setLayoutData(gridData);
 
-		m_calendarList = new CalendarListComposite(m_sash, SWT.NONE);
+		m_calendarList = new CalendarListComposite(m_sash, SWT.NONE, this);
 
 		Calendar baseCalendar = Calendar.getInstance();
 		baseCalendar.setTime(new Date());
