@@ -16,21 +16,31 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.commons.jmx;
 
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.FileReader;
 import java.io.IOException;
+import java.net.InetSocketAddress;
+import java.net.URL;
+import java.security.KeyStore;
+import java.security.SecureRandom;
 import java.sql.Connection;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.concurrent.Executors;
+import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadFactory;
+import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
 import javax.management.ObjectName;
 import javax.naming.InitialContext;
 import javax.naming.NamingException;
+import javax.net.ssl.KeyManagerFactory;
+import javax.net.ssl.SSLContext;
+import javax.net.ssl.TrustManagerFactory;
 import javax.xml.ws.Endpoint;
 
 import org.apache.commons.logging.Log;
@@ -45,10 +55,12 @@ import com.clustercontrol.commons.util.ConnectionManager;
 import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.QuartzCommonJobSetupUtil;
 import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
+import com.clustercontrol.util.XMLUtil;
 import com.clustercontrol.util.apllog.AplLogger;
 import com.clustercontrol.ws.endpoint.AccessEndpoint;
 import com.clustercontrol.ws.endpoint.AgentEndpoint;
 import com.clustercontrol.ws.endpoint.CalendarEndpoint;
+import com.clustercontrol.ws.endpoint.CloudCommonEndpoint;
 import com.clustercontrol.ws.endpoint.CollectiveRunEndpoint;
 import com.clustercontrol.ws.endpoint.CollectorEndpoint;
 import com.clustercontrol.ws.endpoint.JobEndpoint;
@@ -62,6 +74,8 @@ import com.clustercontrol.ws.endpoint.NodeMapEndpoint;
 import com.clustercontrol.ws.endpoint.NotifyEndpoint;
 import com.clustercontrol.ws.endpoint.PerformanceCollectMasterEndpoint;
 import com.clustercontrol.ws.endpoint.RepositoryEndpoint;
+import com.sun.net.httpserver.HttpsConfigurator;
+import com.sun.net.httpserver.HttpsServer;
 
 /**
  * Hinemosサービスの制御クラス<BR>
@@ -71,7 +85,13 @@ import com.clustercontrol.ws.endpoint.RepositoryEndpoint;
  */
 public class HinemosService extends ServiceMBeanSupport implements HinemosServiceMBean {
 
-	private static Log m_log = LogFactory.getLog( HinemosProperties.class );
+	private static Log m_log = LogFactory.getLog( HinemosService.class );
+
+	/** XML のInvalidな文字を置換する場合の置換文字のキー */
+	private static final String MESSAGE_REPLACE_METHOD_KEY = "common.xml.invalid.char.replace";
+	
+	/** XML のInvalidな文字を置換する場合の置換文字のキー */
+	private static final String MESSAGE_REPLACE_CHAR_KEY = "common.xml.invalid.char.replace.to";
 
 	/** DBMSスケジューラのJNDI名 */
 	private String jndiNameDBMSScheduler = null;
@@ -83,12 +103,65 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 	private int delay = 10;
 
 	private static ScheduledExecutorService scheduler;
+	
+	public static final int _threadPoolSize;
+	public static final int _queueSize;
+	private static final ThreadPoolExecutor _threadPool;
+	
+	public static final int _threadPoolSizeForAgent;
+	public static final int _queueSizeForAgent;
+	private static final ThreadPoolExecutor _threadPoolForAgent;
 
 	/**
 	 * 停止時に利用するEndpointのリスト。
 	 */
 	private static ArrayList<Endpoint> endpointList = new ArrayList<Endpoint>();
+	
+	/**
+	 * HTTPS通信時に利用
+	 */
+	private static HttpsServer httpsServer = null;
 
+	static {
+		_threadPoolSize = Integer.parseInt(HinemosProperties.getProperty("common.ws.threadpool.size" , "4"));
+		_queueSize = Integer.parseInt(HinemosProperties.getProperty("common.ws.queue.size" , "300"));
+		
+		_threadPool = new ThreadPoolExecutor(_threadPoolSize, _threadPoolSize, 0L, TimeUnit.MICROSECONDS, 
+				new LinkedBlockingQueue<Runnable>(_queueSize), 
+				new ThreadFactory() {
+				private volatile int _count = 0;
+					@Override
+					public Thread newThread(Runnable r) {
+						return new Thread(r, "WebServiceWorker-" + _count++);
+					}
+				}, new ThreadPoolExecutor.AbortPolicy());
+		
+		_threadPoolSizeForAgent = Integer.parseInt(HinemosProperties.getProperty("agent.ws.threadpool.size" , "8"));
+		_queueSizeForAgent = Integer.parseInt(HinemosProperties.getProperty("agent.ws.queue.size" , "1200"));
+		
+		_threadPoolForAgent = new ThreadPoolExecutor(_threadPoolSizeForAgent, _threadPoolSizeForAgent, 0L, TimeUnit.MICROSECONDS, 
+				new LinkedBlockingQueue<Runnable>(_queueSizeForAgent), 
+				new ThreadFactory() {
+				private volatile int _count = 0;
+					@Override
+					public Thread newThread(Runnable r) {
+						return new Thread(r, "WebServiceWorkerForAgent-" + _count++);
+					}
+				}, new ThreadPoolExecutor.AbortPolicy());
+		
+		String replaceMethodString = HinemosProperties.getProperty(MESSAGE_REPLACE_METHOD_KEY, "false");
+		if("true".equals(replaceMethodString)){
+			XMLUtil.setReplace(true);
+		} else {
+			XMLUtil.setReplace(false);
+		}
+		
+		String replaceCharString = HinemosProperties.getProperty(MESSAGE_REPLACE_CHAR_KEY, "?");
+		if(replaceCharString != null){
+			XMLUtil.setReplaceChar(replaceCharString);
+		}
+	}
+	
 	/**
 	 * HinemosServiceのコンストラクタ
 	 */
@@ -324,33 +397,57 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 		AplLogger apllog = new AplLogger("MNG", "mng");
 		String[] args = {"start"};
 		apllog.put("SYS", "001", args);
+		
+		String preAddress = HinemosProperties.getProperty("common.ws.address" , "http://0.0.0.0:8080");
+		String preAgentAddress = preAddress;
+		
+		URL url = new URL(preAddress);
+
+		if("https".equals(url.getProtocol())){
+			preAgentAddress = HinemosProperties.getProperty("common.ws.agent.address" , "http://0.0.0.0:8080");
+			
+			String protocol = HinemosProperties.getProperty("common.ws.https.protocol", "TLS");
+			String keystorePath = HinemosProperties.getProperty("common.ws.https.keystore.path", "/root/keystore");
+			String keystorePassword = HinemosProperties.getProperty("common.ws.https.keystore.password", "hinemos");
+			String keystoreType = HinemosProperties.getProperty("common.ws.https.keystore.type", "PKCS12");
+			
+			log.info("Starting HTTPS Server...");
+			log.info("SSLContext: " + protocol + ", KeyStore: " + keystoreType);
+			
+			createHttpsServer(url.getHost(), url.getPort(), protocol, keystorePath, keystorePassword, keystoreType);
+		}
 
 		/** Webサービスの起動処理 */
-		publish("/HinemosWS/AgentEndpoint", new AgentEndpoint());
-		publish("/HinemosWS/CalendarEndpoint", new CalendarEndpoint());
-		publish("/HinemosWS/CollectiveRunEndpoint", new CollectiveRunEndpoint());
-		publish("/HinemosWS/CollectorEndpoint", new CollectorEndpoint());
-		publish("/HinemosWS/JobEndpoint", new JobEndpoint());
-		publish("/HinemosWS/MailTemplateEndpoint", new MailTemplateEndpoint());
-		publish("/HinemosWS/MaintenanceEndpoint", new MaintenanceEndpoint());
-		publish("/HinemosWS/MonitorEndpoint", new MonitorEndpoint());
-		publish("/HinemosWS/MonitorSettingEndpoint", new MonitorSettingEndpoint());
-		publish("/HinemosWS/MonitorSnmpTrapEndpoint", new MonitorSnmpTrapEndpoint());
-		publish("/HinemosWS/NotifyEndpoint", new NotifyEndpoint());
-		publish("/HinemosWS/RepositoryEndpoint", new RepositoryEndpoint());
-		publish("/HinemosWS/PerformanceCollectMasterEndpoint", new PerformanceCollectMasterEndpoint());
+		publish(preAgentAddress, "/HinemosWS/AgentEndpoint", new AgentEndpoint(), _threadPoolForAgent);
+		publish(preAddress, "/HinemosWS/CalendarEndpoint", new CalendarEndpoint(), _threadPool);
+		publish(preAgentAddress, "/HinemosWS/CloudCommonEndpoint", new CloudCommonEndpoint(), _threadPoolForAgent);
+		publish(preAddress, "/HinemosWS/CollectiveRunEndpoint", new CollectiveRunEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/CollectorEndpoint", new CollectorEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/JobEndpoint", new JobEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/MailTemplateEndpoint", new MailTemplateEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/MaintenanceEndpoint", new MaintenanceEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/MonitorEndpoint", new MonitorEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/MonitorSettingEndpoint", new MonitorSettingEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/MonitorSnmpTrapEndpoint", new MonitorSnmpTrapEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/NotifyEndpoint", new NotifyEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/RepositoryEndpoint", new RepositoryEndpoint(), _threadPool);
+		publish(preAddress, "/HinemosWS/PerformanceCollectMasterEndpoint", new PerformanceCollectMasterEndpoint(), _threadPool);
 
 		if (isNodeMap()) {
-			publish("/HinemosWS/NodeMapEndpoint", new NodeMapEndpoint());
+			publish(preAddress, "/HinemosWS/NodeMapEndpoint", new NodeMapEndpoint(), _threadPool);
 		}
 
 		if (isJobMap()) {
-			publish("/HinemosWS/JobMapEndpoint", new JobMapEndpoint());
+			publish(preAddress, "/HinemosWS/JobMapEndpoint", new JobMapEndpoint(), _threadPool);
 		}
 
 		// ログインは最後にpublishする。
-		publish("/HinemosWS/AccessEndpoint", new AccessEndpoint());
+		publish(preAddress, "/HinemosWS/AccessEndpoint", new AccessEndpoint(), _threadPool);
 
+		if(httpsServer != null){
+			httpsServer.start();
+		}
+	
 		log.info("successful in starting a MBean of HinemosService...");
 	}
 
@@ -395,20 +492,45 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 		return ret;
 	}
 
-	private void publish (String postAddress, Object endpointInstance) {
-		// String preAddress = "http://0.0.0.0:8080";
-		// String preAddress = "http://192.168.0.1:8080";
-		// String preAddress = "http://[fe80::250:56ff:fe9d:0]:8080";
-		String preAddress = HinemosProperties.getProperty("common.ws.address" , "http://0.0.0.0:8080");
-
+	private void publish (String preAddress, String postAddress, Object endpointInstance, ThreadPoolExecutor threadPool) {
 		try {
 			String address = preAddress + postAddress;
 			log.info("publish " + address);
-			endpointList.add(Endpoint.publish(address, endpointInstance));
+
+			Endpoint endpoint = Endpoint.create(endpointInstance);
+			endpoint.setExecutor(threadPool);
+			if(httpsServer == null || endpointInstance instanceof AgentEndpoint || endpointInstance instanceof CloudCommonEndpoint){
+				endpoint.publish(address);
+			}
+			else {
+				endpoint.publish(httpsServer.createContext(postAddress));
+			}
+			endpointList.add(endpoint);
 		} catch (Exception e) {
 			log.error("publish " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
+	
+	private void createHttpsServer(String managerIP, int port, String protocol, String keyStorePath, String keyStorePassword, String keyStoreType) throws Exception{
+		SSLContext ssl = SSLContext.getInstance(protocol);
+		KeyManagerFactory keyFactory = KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
+		KeyStore store = KeyStore.getInstance(keyStoreType);
+		store.load(new FileInputStream(keyStorePath), keyStorePassword.toCharArray());
+
+		keyFactory.init(store, keyStorePassword.toCharArray());
+
+		TrustManagerFactory trustFactory = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
+
+		trustFactory.init(store);
+
+		ssl.init(keyFactory.getKeyManagers(),
+		trustFactory.getTrustManagers(), new SecureRandom());
+
+		HttpsConfigurator configurator = new HttpsConfigurator(ssl);
+
+		httpsServer = HttpsServer.create(new InetSocketAddress(managerIP, port), 0);
+		httpsServer.setHttpsConfigurator(configurator);
+	}
 
 	/**
 	 * MBeanの停止処理
@@ -417,6 +539,7 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 	public void stopService() throws Exception {
 		/** メイン処理 */
 		log.info("stopping a MBean of HinemosService...");
+		_threadPool.shutdownNow();
 		shutdownScheduler();
 
 		/**
@@ -440,6 +563,10 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 				log.warn("stop endpoint : " + e.getMessage());
 			}
 		}
+		
+		if(httpsServer != null){
+			httpsServer.stop(0);
+		}
 
 		AplLogger apllog = new AplLogger("MNG", "mng");
 		String[] args = {"shutdown"};
@@ -690,4 +817,12 @@ public class HinemosService extends ServiceMBeanSupport implements HinemosServic
 		}
 		return ret;
 	}
+	
+	public static HttpsServer getHttpsServer(){
+		return httpsServer;
+	}
+	
+	public static ThreadPoolExecutor getThreadPool(){
+		return _threadPool;
+	}
 }
