@@ -17,9 +17,11 @@ package com.clustercontrol.util.apllog;
 
 
 import java.text.MessageFormat;
+import java.text.SimpleDateFormat;
 import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -200,10 +202,10 @@ public class AplLogger {
 				isFile = false;
 			}
 			// ログファイル出力レベル
-			eventOutPutInfo.setPriority(PRIORITY_CRITICAL, HinemosProperties.getProperty("common.internal.file.priority.critical"));
-			eventOutPutInfo.setPriority(PRIORITY_WARNING, HinemosProperties.getProperty("common.internal.file.priority.warning"));
-			eventOutPutInfo.setPriority(PRIORITY_INFO, HinemosProperties.getProperty("common.internal.file.priority.info"));
-			eventOutPutInfo.setPriority(PRIORITY_UNKNOWN, HinemosProperties.getProperty("common.internal.file.priority.unknown"));
+			fileOutPutInfo.setPriority(PRIORITY_CRITICAL, HinemosProperties.getProperty("common.internal.file.priority.critical"));
+			fileOutPutInfo.setPriority(PRIORITY_WARNING, HinemosProperties.getProperty("common.internal.file.priority.warning"));
+			fileOutPutInfo.setPriority(PRIORITY_INFO, HinemosProperties.getProperty("common.internal.file.priority.info"));
+			fileOutPutInfo.setPriority(PRIORITY_UNKNOWN, HinemosProperties.getProperty("common.internal.file.priority.unknown"));
 
 		} catch (Exception e) {
 			log.error("initialParameter()",e);
@@ -441,6 +443,16 @@ public class AplLogger {
 		Object[] args ={m_pluginID, m_aplName, monitorId, msgId, priority, msg, detailMsg};
 		String logmsg = syslogfmt.format(args);
 
+		// 送信時刻をセット
+		SimpleDateFormat sdf = new SimpleDateFormat(SendSyslog.HEADER_DATE_FORMAT, Locale.US);
+		String timeStamp = sdf.format(new Date());
+		if(log.isDebugEnabled()){
+			log.debug("putSyslog() monitorId = " + monitorId +
+					", msgId = " + msgId + ", priority = " + priority +
+					", msg = " + msg + ", detailMsg = " + detailMsg +
+					", timeStamp = " + timeStamp);
+		}
+		
 		// メッセージをsyslog送信
 		if(syslogHost != null && syslogHost.length > 0){
 			for (int i = 0; i < syslogHost.length; i++) {
@@ -451,7 +463,7 @@ public class AplLogger {
 				}
 
 				// syslog送信
-				sendSyslog.sendAfterConvertHostname(syslogHost[i], syslogPort, syslogFacility, syslogSeverity, INTERNAL_SCOPE, logmsg);
+				sendSyslog.sendAfterConvertHostname(syslogHost[i], syslogPort, syslogFacility, syslogSeverity, INTERNAL_SCOPE, logmsg, timeStamp);
 			}
 		}
 	}
