@@ -97,7 +97,7 @@ public class GetJobDetailTableDefine {
 		tableDefine.add(SCOPE,
 				new TableColumnInfo(Messages.getString("scope", locale), TableColumnInfo.FACILITY, 150, SWT.LEFT));
 		tableDefine.add(WAIT_RULE_TIME,
-				new TableColumnInfo(Messages.getString("wait.rule.time", locale), TableColumnInfo.NONE, 120, SWT.LEFT));
+				new TableColumnInfo(Messages.getString("wait.rule.time", locale), TableColumnInfo.WAIT_RULE_VALUE, 120, SWT.LEFT));
 		tableDefine.add(START_RERUN_TIME,
 				new TableColumnInfo(Messages.getString("start.rerun.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
 		tableDefine.add(END_SUSPEND_TIME,
