@@ -17,6 +17,7 @@ package com.clustercontrol.jobmanagement.composite;
 
 import java.util.List;
 
+import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
@@ -41,7 +42,9 @@ import com.clustercontrol.composite.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetCalendarIdList;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
+import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
@@ -71,6 +74,9 @@ public class ControlComposite extends Composite {
 	protected JobWaitRuleInfo m_waitRule = null;
 	/** シェル */
 	protected Shell m_shell = null;
+	
+	/* カレンダー参照権限 */
+	private boolean m_calendarReadable = true;
 
 	/**
 	 * コンストラクタ
@@ -119,7 +125,7 @@ public class ControlComposite extends Composite {
 				Button check = (Button) e.getSource();
 				if (check.getSelection()) {
 					m_calendarConditionGroup.setEnabled(true);
-					m_calendarId.setEnabled(true);
+					m_calendarId.setEnabled(true & m_calendarReadable);
 					m_calendarEndValue.setEnabled(true);
 				} else {
 					m_calendarConditionGroup.setEnabled(false);
@@ -155,8 +161,25 @@ public class ControlComposite extends Composite {
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		m_calendarId = new Combo(composite, SWT.LEFT | SWT.READ_ONLY);
 		m_calendarId.setLayoutData(new RowData(100, SizeConstant.SIZE_COMBO_HEIGHT));
-		List<String> idList = new GetCalendarIdList().getCalendarIdList();
+		List<String> idList = null;
+		try {
+			idList = JobEndpointWrapper.getCalendarIdList();
+		} catch (InvalidRole_Exception e) {
+			// アクセス権なしの場合、エラーダイアログを表示する
+			MessageDialog.openInformation(
+					null,
+					Messages.getString("message"),
+					Messages.getString("message.accesscontrol.16"));
+			m_calendarReadable = false;
+			m_calendarId.setEnabled(false);
+		} catch (Exception e) {
+			MessageDialog.openError(
+					null,
+					Messages.getString("failed"),
+					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
 		if(idList != null){
+			m_calendarId.add("");
 			for(int i = 0; i < idList.size(); i++){
 				m_calendarId.add(idList.get(i));
 			}
@@ -322,6 +345,10 @@ public class ControlComposite extends Composite {
 			//カレンダID
 			if (m_waitRule.getCalendarId() != null &&
 					m_waitRule.getCalendarId().length() > 0) {
+				if (!m_calendarReadable) {
+					//カレンダー参照権限がない場合
+					m_calendarId.add(m_waitRule.getCalendarId());
+				}
 				m_calendarId.select(0);
 				for (int i = 0; i < m_calendarId.getItemCount(); i++) {
 					if (m_waitRule.getCalendarId().equals(m_calendarId.getItem(i))) {
@@ -347,7 +374,7 @@ public class ControlComposite extends Composite {
 		//カレンダ
 		if (m_calendarCondition.getSelection()) {
 			m_calendarConditionGroup.setEnabled(true);
-			m_calendarId.setEnabled(true);
+			m_calendarId.setEnabled(true & m_calendarReadable);
 			m_calendarEndValue.setEnabled(true);
 		} else {
 			m_calendarConditionGroup.setEnabled(false);
@@ -442,6 +469,9 @@ public class ControlComposite extends Composite {
 				.getSelection()));
 
 		//カレンダID
+		if (m_calendarId.getText().length() == 0){
+			m_waitRule.setCalendarId(null);
+		}
 		if (m_calendarId.getText().length() > 0) {
 			m_waitRule.setCalendarId(m_calendarId.getText());
 		}
