@@ -103,16 +103,16 @@ public class EndDelayComposite extends Composite {
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
 	 */
-	public EndDelayComposite(Composite parent, int style) {
+	public EndDelayComposite(Composite parent, int style, boolean isFileJob) {
 		super(parent, style);
-		initialize();
+		initialize(isFileJob);
 		m_shell = this.getShell();
 	}
 
 	/**
 	 * コンポジットを配置します。
 	 */
-	private void initialize() {
+	private void initialize(boolean isFileJob) {
 		RowLayout layout = new RowLayout();
 		layout.type = SWT.VERTICAL;
 		layout.spacing = 1;
@@ -424,7 +424,9 @@ public class EndDelayComposite extends Composite {
 		m_operationType = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
 		m_operationType.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
-		m_operationType.add(OperationConstant.STRING_STOP_AT_ONCE);
+		if(!isFileJob){
+			m_operationType.add(OperationConstant.STRING_STOP_AT_ONCE);
+		}
 		m_operationType.add(OperationConstant.STRING_STOP_SUSPEND);
 		m_operationType.add(OperationConstant.STRING_STOP_SET_END_VALUE);
 		m_operationType.addSelectionListener(new SelectionListener() {
