@@ -1,22 +1,24 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.jobmanagement.composite;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.RowData;
@@ -30,22 +32,23 @@ import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.bean.FacilityConstant;
-import com.clustercontrol.bean.FacilityPath;
-import com.clustercontrol.bean.FacilityTreeItem;
-import com.clustercontrol.bean.ProcessingMethodConstant;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.jobmanagement.bean.JobFileInfo;
+import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
+import com.clustercontrol.repository.FacilityPath;
+import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.jobmanagement.JobFileInfo;
+import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * ファイル転送タブ用のコンポジットクラスです。
  * 
- * @version 2.0.0
+ * @version 4.0.0
  * @since 2.0.0
  */
 public class FileComposite extends Composite {
@@ -53,14 +56,12 @@ public class FileComposite extends Composite {
 	protected Text m_srcScope = null;
 	/** 転送ファイル */
 	protected Text m_srcFile = null;
-	
-//	protected Text m_srcWorkDir = null;
+
 	/** 受信スコープ */
 	protected Text m_destScope = null;
 	/** 受信ディレクトリ */
 	protected Text m_destDirectory = null;
-	
-//	protected Text m_destWorkDir = null;
+
 	/** 実効ユーザ */
 	protected Text m_user = null;
 	/** 転送スコープ参照ボタン */
@@ -87,23 +88,23 @@ public class FileComposite extends Composite {
 	protected JobFileInfo m_jobFileInfo = null;
 	/** シェル */
 	protected Shell m_shell = null;
-	
+
 	/**
 	 * コンストラクタ
 	 * 
-     * @param parent 親コンポジット
-     * @param style スタイル
-     * 
-     * @see org.eclipse.swt.SWT
-     * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
-     * @see #initialize()
+	 * @param parent 親コンポジット
+	 * @param style スタイル
+	 * 
+	 * @see org.eclipse.swt.SWT
+	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
+	 * @see #initialize()
 	 */
 	public FileComposite(Composite parent, int style) {
 		super(parent, style);
 		initialize();
 		m_shell = this.getShell();
 	}
-	
+
 	/**
 	 * コンポジットを配置します。
 	 */
@@ -115,10 +116,10 @@ public class FileComposite extends Composite {
 		layout.marginHeight = 10;
 		layout.fill = true;
 		this.setLayout(layout);
-		
+
 		Composite composite = null;
 		RowLayout rowLayout = null;
-		
+
 		//転送元用グループ
 		Group group = new Group(this, SWT.NONE);
 		group.setText(Messages.getString("forward.source"));
@@ -127,23 +128,29 @@ public class FileComposite extends Composite {
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		group.setLayout(rowLayout);
-		
+
 		//転送元スコープ用コンポジット
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		
+
 		Label srcScopeTitle = new Label(composite, SWT.NONE);
 		srcScopeTitle.setText(Messages.getString("scope") + " : ");
 		srcScopeTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		
-		m_srcScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
-		m_srcScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_srcScope.setText("");
-		
+
+		this.m_srcScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		this.m_srcScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_srcScope.setText("");
+		this.m_srcScope.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
 		m_srcScopeSelect = new Button(composite, SWT.NONE);
 		m_srcScopeSelect.setText(Messages.getString("refer"));
 		m_srcScopeSelect.setLayoutData(new RowData(80,
@@ -154,7 +161,7 @@ public class FileComposite extends Composite {
 				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE || 
+					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE ||
 							selectItem.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
 						m_srcFacilityPath = "";
 						m_srcFacilityId = "";
@@ -165,46 +172,36 @@ public class FileComposite extends Composite {
 						m_srcFacilityPath = path.getPath(selectItem);
 						m_srcFacilityId = selectItem.getData().getFacilityId();
 					}
-					
+
 					m_srcScope.setText(m_srcFacilityPath);
 				}
 			}
 		});
-		
+
 		//転送ファイル用コンポジット
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		
+
 		Label fileTitle = new Label(composite, SWT.NONE);
 		fileTitle.setText(Messages.getString("file") + " : ");
 		fileTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		
-		m_srcFile = new Text(composite, SWT.BORDER);
-		m_srcFile.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_srcFile.addVerifyListener(
-        		new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
-		m_srcFile.setText("");
-		
-		//転送元作業ディレクトリ用コンポジット
-//		composite = new Composite(group, SWT.NONE);
-//		rowLayout = new RowLayout();
-//		rowLayout.type = SWT.HORIZONTAL;
-//		rowLayout.spacing = 10;
-//		composite.setLayout(rowLayout);
-//		
-//		Label srcWorkDirTitle = new Label(composite, SWT.NONE);
-//		srcWorkDirTitle.setText(Messages.getString("work.directory") + " : ");
-//		srcWorkDirTitle.setLayoutData(new RowData(100,
-//				SizeConstant.SIZE_LABEL_HEIGHT));
-//		
-//		m_srcWorkDir = new Text(composite, SWT.BORDER);
-//		m_srcWorkDir.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-//		m_srcWorkDir.setText("");
-		
+
+		this.m_srcFile = new Text(composite, SWT.BORDER);
+		this.m_srcFile.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_srcFile.addVerifyListener(
+				new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
+		this.m_srcFile.setText("");
+		this.m_srcFile.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
 		//転送先用グループ
 		group = new Group(this, SWT.NONE);
 		group.setText(Messages.getString("forward.destination"));
@@ -213,23 +210,29 @@ public class FileComposite extends Composite {
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		group.setLayout(rowLayout);
-		
+
 		//転送先スコープ用コンポジット
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		
+
 		Label destScopeTitle = new Label(composite, SWT.NONE);
 		destScopeTitle.setText(Messages.getString("scope") + " : ");
 		destScopeTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		
-		m_destScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
-		m_destScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_destScope.setText("");
-		
+
+		this.m_destScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		this.m_destScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_destScope.setText("");
+		this.m_destScope.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
 		m_destScopeSelect = new Button(composite, SWT.NONE);
 		m_destScopeSelect.setText(Messages.getString("refer"));
 		m_destScopeSelect.setLayoutData(new RowData(80,
@@ -250,12 +253,12 @@ public class FileComposite extends Composite {
 						m_destFacilityPath = path.getPath(selectItem);
 						m_destFacilityId = selectItem.getData().getFacilityId();
 					}
-					
+
 					m_destScope.setText(m_destFacilityPath);
 				}
 			}
 		});
-		
+
 		//処理方式グループ
 		Group methodGroup = new Group(group, SWT.NONE);
 		methodGroup.setText(Messages.getString("process.method"));
@@ -264,7 +267,7 @@ public class FileComposite extends Composite {
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		methodGroup.setLayout(rowLayout);
-		
+
 		m_allNode = new Button(methodGroup, SWT.RADIO);
 		m_allNode.setText(Messages.getString("forward.all.nodes"));
 		m_allNode.setLayoutData(
@@ -273,88 +276,130 @@ public class FileComposite extends Composite {
 		m_oneNode.setText(Messages.getString("forward.one.node"));
 		m_oneNode.setLayoutData(
 				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
-		
+
 		//転送先ディレクトリ用コンポジット
 		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		
+
 		Label forwardDirTitle = new Label(composite, SWT.NONE);
 		forwardDirTitle.setText(Messages.getString("directory") + " : ");
 		forwardDirTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		
-		m_destDirectory = new Text(composite, SWT.BORDER);
-		m_destDirectory.setLayoutData(new RowData(200,
+
+		this.m_destDirectory = new Text(composite, SWT.BORDER);
+		this.m_destDirectory.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_TEXT_HEIGHT));
-		m_destDirectory.addVerifyListener(
-        		new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
-		
-		//転送元作業ディレクトリ用コンポジット
-//		composite = new Composite(group, SWT.NONE);
-//		rowLayout = new RowLayout();
-//		rowLayout.type = SWT.HORIZONTAL;
-//		rowLayout.spacing = 10;
-//		composite.setLayout(rowLayout);
-//		
-//		Label destWorkDirTitle = new Label(composite, SWT.NONE);
-//		destWorkDirTitle.setText(Messages.getString("work.directory") + " : ");
-//		destWorkDirTitle.setLayoutData(new RowData(100,
-//				SizeConstant.SIZE_LABEL_HEIGHT));
-//		
-//		m_destWorkDir = new Text(composite, SWT.BORDER);
-//		m_destWorkDir.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-//		m_destWorkDir.setText("");
-		
+		this.m_destDirectory.addVerifyListener(
+				new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
+		this.m_destDirectory.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
 		//ファイル圧縮用コンポジット
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		composite.setLayout(rowLayout);
-		
+
 		m_compressionCondition = new Button(composite, SWT.CHECK);
 		m_compressionCondition.setText(Messages.getString("forward.compression.file"));
 		m_compressionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		
+
 		//ファイル整合性チェック用コンポジット
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		composite.setLayout(rowLayout);
-		
+
 		m_checkFileCondition = new Button(composite, SWT.CHECK);
 		m_checkFileCondition.setText(Messages.getString("forward.file.check"));
 		m_checkFileCondition.setLayoutData(new RowData(250,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
-		
+
 		//実効ユーザ用コンポジット
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		
+
 		Label userTitle = new Label(composite, SWT.NONE);
 		userTitle.setText(Messages.getString("effective.user") + " : ");
 		userTitle
 		.setLayoutData(new RowData(100, SizeConstant.SIZE_LABEL_HEIGHT));
-		
-		m_user = new Text(composite, SWT.BORDER);
-		m_user.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_user.addVerifyListener(
-        		new StringVerifyListener(DataRangeConstant.VARCHAR_64));
+
+		this.m_user = new Text(composite, SWT.BORDER);
+		this.m_user.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_user.addVerifyListener(
+				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
+		this.m_user.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 	}
-	
+
+	/**
+	 * 更新処理
+	 * 
+	 */
+	@Override
+	public void update(){
+		// 必須項目を明示
+		if("".equals(this.m_srcScope.getText())){
+			this.m_srcScope.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_srcScope.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if("".equals(this.m_srcFile.getText())){
+			this.m_srcFile.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_srcFile.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if("".equals(this.m_user.getText())){
+			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if("".equals(this.m_destScope.getText())){
+			this.m_destScope.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_destScope.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+		if("".equals(this.m_destDirectory.getText()) || !m_destDirectory.getText().endsWith("/")){
+			this.m_destDirectory.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_destDirectory.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+
+	}
+
 	/**
 	 * ジョブファイル転送情報をコンポジットに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobFileInfo
 	 */
 	public void reflectFileInfo() {
-		if (m_jobFileInfo instanceof JobFileInfo) {
+
+		// 初期値
+		m_srcScope.setText("");
+		m_srcFile.setText("");
+		m_destScope.setText("");
+		m_destDirectory.setText("");
+		m_allNode.setSelection(true);
+		m_compressionCondition.setSelection(false);
+		m_checkFileCondition.setSelection(false);
+		m_user.setText("");
+
+		if (m_jobFileInfo != null) {
 			//転送元スコープ設定
 			m_srcFacilityPath = m_jobFileInfo.getSrcScope();
 			m_srcFacilityId = m_jobFileInfo.getSrcFacilityID();
@@ -366,11 +411,6 @@ public class FileComposite extends Composite {
 					&& m_jobFileInfo.getSrcFile().length() > 0) {
 				m_srcFile.setText(m_jobFileInfo.getSrcFile());
 			}
-			//転送元作業ディレクトリ設定
-//			if (m_jobFileInfo.getSrcWorkDir() != null
-//					&& m_jobFileInfo.getSrcWorkDir().length() > 0) {
-//				m_srcWorkDir.setText(m_jobFileInfo.getSrcWorkDir());
-//			}
 			//転送先スコープ設定
 			m_destFacilityPath = m_jobFileInfo.getDestScope();
 			m_destFacilityId = m_jobFileInfo.getDestFacilityID();
@@ -382,15 +422,12 @@ public class FileComposite extends Composite {
 					&& m_jobFileInfo.getDestDirectory().length() > 0) {
 				m_destDirectory.setText(m_jobFileInfo.getDestDirectory());
 			}
-			//転送先作業ディレクトリ設定
-//			if (m_jobFileInfo.getDestWorkDir() != null
-//					&& m_jobFileInfo.getDestWorkDir().length() > 0) {
-//				m_destWorkDir.setText(m_jobFileInfo.getDestWorkDir());
-//			}
 			//処理方法設定
 			if (m_jobFileInfo.getProcessingMethod() == ProcessingMethodConstant.TYPE_ALL_NODE) {
 				m_allNode.setSelection(true);
+				m_oneNode.setSelection(false);
 			} else {
+				m_allNode.setSelection(false);
 				m_oneNode.setSelection(true);
 			}
 			//ファイル圧縮
@@ -403,20 +440,9 @@ public class FileComposite extends Composite {
 			if (m_jobFileInfo.getUser() != null && m_jobFileInfo.getUser().length() > 0) {
 				m_user.setText(m_jobFileInfo.getUser());
 			}
-		} else {
-			m_srcScope.setText("");
-			m_srcFile.setText("");
-//			m_srcWorkDir.setText("");
-			m_destScope.setText("");
-			m_destDirectory.setText("");
-//			m_destWorkDir.setText("");
-			m_allNode.setSelection(true);
-			m_compressionCondition.setSelection(false);
-			m_checkFileCondition.setSelection(false);
-			m_user.setText("");
 		}
 	}
-	
+
 	/**
 	 * ジョブファイル転送情報を設定します。
 	 * 
@@ -425,7 +451,7 @@ public class FileComposite extends Composite {
 	public void setFileInfo(JobFileInfo jobFileInfo) {
 		m_jobFileInfo = jobFileInfo;
 	}
-	
+
 	/**
 	 * ジョブファイル転送情報を返します。
 	 * 
@@ -434,7 +460,7 @@ public class FileComposite extends Composite {
 	public JobFileInfo getFileInfo() {
 		return m_jobFileInfo;
 	}
-	
+
 	/**
 	 * コンポジットの情報から、ジョブファイル転送情報を作成する。
 	 * 
@@ -444,10 +470,10 @@ public class FileComposite extends Composite {
 	 */
 	public ValidateResult createFileInfo() {
 		ValidateResult result = null;
-		
+
 		//ファイル転送情報クラスのインスタンスを作成・取得
 		m_jobFileInfo = new JobFileInfo();
-		
+
 		//転送元スコープ取得
 		if (m_srcFacilityId != null && m_srcFacilityId.length() > 0) {
 			m_jobFileInfo.setSrcFacilityID(m_srcFacilityId);
@@ -456,11 +482,11 @@ public class FileComposite extends Composite {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.source") + 
+			result.setMessage(Messages.getString("forward.source") +
 					Messages.getString("message.hinemos.3"));
 			return result;
 		}
-		
+
 		//転送元ファイル
 		if (m_srcFile.getText().length() > 0) {
 			m_jobFileInfo.setSrcFile(m_srcFile.getText());
@@ -468,24 +494,14 @@ public class FileComposite extends Composite {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.source") + 
+			result.setMessage(Messages.getString("forward.source") +
 					Messages.getString("message.job.45"));
 			return result;
 		}
-		
+
 		//転送元作業ディレクトリ
 		m_jobFileInfo.setSrcWorkDir("");
-//		if (m_srcWorkDir.getText().length() > 0) {
-//			m_jobFileInfo.setSrcWorkDir(m_srcWorkDir.getText());
-//		} else {
-//			result = new ValidateResult();
-//			result.setValid(false);
-//			result.setID(Messages.getString("message.hinemos.1"));
-//			result.setMessage(Messages.getString("forward.source") + 
-//					Messages.getString("message.job.47"));
-//			return result;
-//		}
-		
+
 		//転送先スコープ取得
 		if (m_destFacilityId != null && m_destFacilityId.length() > 0) {
 			m_jobFileInfo.setDestFacilityID(m_destFacilityId);
@@ -494,49 +510,39 @@ public class FileComposite extends Composite {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.destination") + 
+			result.setMessage(Messages.getString("forward.destination") +
 					Messages.getString("message.hinemos.3"));
 			return result;
 		}
-		
+
 		//転送先ディレクトリ
 		if (m_destDirectory.getText().length() > 0 && m_destDirectory.getText().endsWith("/")) {
 			m_jobFileInfo.setDestDirectory(m_destDirectory.getText());
-			
-		// 転送先ディレクトリが指定されていない場合
+
+			// 転送先ディレクトリが指定されていない場合
 		} else if (m_destDirectory.getText().length() <= 0) {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.destination") + 
+			result.setMessage(Messages.getString("forward.destination") +
 					Messages.getString("message.job.46"));
 			return result;
-			
-		// 転送先ディレクトリ指定文字列の末尾が / でない場合
+
+			// 転送先ディレクトリ指定文字列の末尾が / でない場合
 		} else if (!m_destDirectory.getText().endsWith("/")) {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.destination") + 
+			result.setMessage(Messages.getString("forward.destination") +
 					Messages.getString("message.job.62"));
 			return result;
-			
+
 		}
 
-		
+
 		//転送先作業ディレクトリ
 		m_jobFileInfo.setDestWorkDir("");
-//		if (m_destWorkDir.getText().length() > 0) {
-//			m_jobFileInfo.setDestWorkDir(m_destWorkDir.getText());
-//		} else {
-//			result = new ValidateResult();
-//			result.setValid(false);
-//			result.setID(Messages.getString("message.hinemos.1"));
-//			result.setMessage(Messages.getString("forward.destination") + 
-//					Messages.getString("message.job.47"));
-//			return result;
-//		}
-		
+
 		//処理方法取得
 		if (m_allNode.getSelection()) {
 			m_jobFileInfo.setProcessingMethod(
@@ -545,15 +551,15 @@ public class FileComposite extends Composite {
 			m_jobFileInfo.setProcessingMethod(
 					ProcessingMethodConstant.TYPE_RETRY);
 		}
-		
+
 		//ファイル圧縮
 		m_jobFileInfo.setCompressionFlg(
 				YesNoConstant.booleanToType(m_compressionCondition.getSelection()));
-		
+
 		//整合性チェック
 		m_jobFileInfo.setCheckFlg(
 				YesNoConstant.booleanToType(m_checkFileCondition.getSelection()));
-		
+
 		//ユーザー取得
 		if (m_user.getText().length() > 0) {
 			m_jobFileInfo.setUser(m_user.getText());
@@ -564,7 +570,7 @@ public class FileComposite extends Composite {
 			result.setMessage(Messages.getString("message.job.5"));
 			return result;
 		}
-		
+
 		return null;
 	}
 }
\ No newline at end of file
