@@ -40,6 +40,7 @@ import com.clustercontrol.jobmanagement.composite.action.SessionJobDoubleClickLi
 import com.clustercontrol.jobmanagement.preference.JobManagementPreferencePage;
 import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
+import com.clustercontrol.jobmanagement.view.JobHistoryView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobHistory;
@@ -70,6 +71,8 @@ public class HistoryComposite extends Composite {
 	/** ジョブID */
 	protected String m_jobId = null;
 
+	public JobHistoryView m_view = null;
+	
 	/**
 	 * コンストラクタ
 	 * 
@@ -85,6 +88,14 @@ public class HistoryComposite extends Composite {
 		initialize();
 	}
 
+	public void setView(JobHistoryView view) {
+		m_view = view;
+	}
+	
+	public JobHistoryView getView() {
+		return m_view;
+	}
+	
 	/**
 	 * コンポジットを配置します。
 	 */
