@@ -31,6 +31,7 @@ import org.eclipse.ui.internal.ErrorViewPart;
 import com.clustercontrol.jobmanagement.action.GetHistoryTableDefine;
 import com.clustercontrol.jobmanagement.composite.HistoryComposite;
 import com.clustercontrol.jobmanagement.view.JobDetailView;
+import com.clustercontrol.jobmanagement.view.JobHistoryView;
 import com.clustercontrol.jobmanagement.view.JobMapViewIF;
 
 /**
@@ -92,27 +93,32 @@ public class HistorySelectionChangedListener implements ISelectionChangedListene
 			m_composite.setJobunitId(jobunitId);
 		}
 
+		String viewClass = m_composite.getView().getClass().getSimpleName();
 		//アクティブページを手に入れる
 		IWorkbenchPage page = PlatformUI.getWorkbench()
 		.getActiveWorkbenchWindow().getActivePage();
-		//ジョブ[詳細]ビューを更新する
-		IViewPart viewPartDetail = page.findView(JobDetailView.ID);
-		if (viewPartDetail != null) {
-			JobDetailView view = (JobDetailView) viewPartDetail
-			.getAdapter(JobDetailView.class);
-			view.update(sessionId, jobunitId);
-		}
-
-		//ジョブマップ[履歴]ビューを更新する
-		IViewReference viewReference = page.findViewReference("com.clustercontrol.jobmap.view.JobMapHistoryView");
-		if (viewReference == null){
-			return;
-		}
-		IViewPart viewPart = viewReference.getView(false);
-		if (viewPart != null && !(viewPart instanceof ErrorViewPart)) {
-			m_log.debug("viewPart " + viewPart.getClass().getName());
-			JobMapViewIF view = (JobMapViewIF) viewPart;
-			view.update(sessionId, null);
+		if (JobHistoryView.class.getSimpleName().equals(viewClass)) {
+			//ジョブ[詳細]ビューを更新する
+			m_log.debug("selectionChanged() : job detail update");
+			IViewPart viewPartDetail = page.findView(JobDetailView.ID);
+			if (viewPartDetail != null) {
+				JobDetailView view = (JobDetailView) viewPartDetail
+				.getAdapter(JobDetailView.class);
+				view.update(sessionId, jobunitId);
+			}
+		} else {
+			//ジョブマップ[履歴]ビューを更新する
+			m_log.debug("selectionChanged() : jobmap detail update");
+			IViewReference viewReference = page.findViewReference("com.clustercontrol.jobmap.view.JobMapHistoryView");
+			if (viewReference == null){
+				return;
+			}
+			IViewPart viewPart = viewReference.getView(false);
+			if (viewPart != null && !(viewPart instanceof ErrorViewPart)) {
+				m_log.debug("viewPart " + viewPart.getClass().getName());
+				JobMapViewIF view = (JobMapViewIF) viewPart;
+				view.update(sessionId, null);
+			}
 		}
 	}
 }
