@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -33,8 +33,8 @@ import javax.ejb.RemoveException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.JobConstant;
 import com.clustercontrol.commons.util.ConnectionManager;
+import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean;
 import com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK;
 
@@ -48,40 +48,42 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO
  */
 public class JobFileInfoDAOImpl implements JobFileInfoDAO {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobFileInfoDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobFileInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
 	 */
+	@Override
 	public void load(JobFileInfoPK pk, JobFileInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_file_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setCheck_flg(res.getInt("check_flg"));
@@ -124,21 +126,22 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
 	 */
+	@Override
 	public void store(JobFileInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -157,10 +160,10 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			sql.append("WHERE session_id = ? AND ");
 			sql.append("job_id = ? AND ");
 			sql.append("jobunit_id = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setInt(1, ejb.getProcess_mode());
 			stmt.setString(2, ejb.getSrc_facility_id());
 			stmt.setString(3, ejb.getDest_facility_id());
@@ -174,20 +177,20 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			stmt.setString(11, ejb.getSession_id());
 			stmt.setString(12, ejb.getJob_id());
 			stmt.setString(13, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id()
+					+ ", jobId=" + ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -200,8 +203,8 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -209,41 +212,42 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
 	 */
+	@Override
 	public void remove(JobFileInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_file_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(2, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -259,18 +263,19 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean)
 	 */
+	@Override
 	public JobFileInfoPK create(JobFileInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobFileInfoPK pk;
@@ -293,10 +298,10 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			sql.append("effective_user, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setInt(3, ejb.getProcess_mode());
@@ -310,25 +315,25 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			stmt.setInt(11, ejb.getCheck_flg());
 			stmt.setString(12, ejb.getEffective_user());
 			stmt.setString(13, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobFileInfoPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -342,8 +347,8 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -352,7 +357,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				+ ", jobId=" + ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -360,22 +365,23 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobFileInfoPK> ret = new ArrayList<JobFileInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_file_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobFileInfoPK pk= new JobFileInfoPK(
 						res.getString("session_id"),
@@ -384,7 +390,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -405,7 +411,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -413,26 +419,27 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobFileInfoPK)
 	 */
+	@Override
 	public JobFileInfoPK findByPrimaryKey(JobFileInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_file_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -458,7 +465,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * ジョブファイル転送情報をジョブファイル転送マスタから作成します。
 	 * 
@@ -470,19 +477,19 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 	 */
 	public Collection makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
+
 		ArrayList<Hashtable> fileJobs = new ArrayList<Hashtable>();
-		
-		Connection conn=null; 
+
+		Connection conn=null;
 		Connection connMaster = null;
 		PreparedStatement stmt=null;
 		PreparedStatement stmtMaster= null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_file_info (");
@@ -500,12 +507,12 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			sql.append("effective_user, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQLのセット(INSERT)
-			stmt = conn.prepareStatement(sql.toString());		
+			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
 			stmt.setString(13, jobunitId);
-			
+
 			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT ");
@@ -524,24 +531,27 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			sqlMaster.append("FROM cc_job_mst, cc_job_file_mst ");
 			sqlMaster.append("WHERE ");
 			sqlMaster.append("(cc_job_mst.job_id=cc_job_file_mst.job_id ");
+			sqlMaster.append("AND cc_job_mst.jobunit_id=cc_job_file_mst.jobunit_id ");
 			sqlMaster.append("AND cc_job_mst.job_id = ? " );
 			sqlMaster.append("AND cc_job_mst.jobunit_id = ? ");
 			sqlMaster.append(")");
-			
+
+			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
+
 			//SQLのセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL実行(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					if(resMaster.getInt("job_type") == JobConstant.TYPE_FILEJOB){
 						//ファイル転送ジョブの場合、INSERTを実行
@@ -556,7 +566,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 						stmt.setInt(10, resMaster.getInt("compression_flg"));
 						stmt.setInt(11, resMaster.getInt("check_flg"));
 						stmt.setString(12, resMaster.getString("effective_user"));
-						
+
 						int row =	stmt.executeUpdate();
 						if (row != 1) {
 							String msg = "result row is not 1";
@@ -574,8 +584,8 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("makeSession() error : sessionId="
-									+ sessionId + ", jobunitId=" + jobunitId
-									+ ", jobId=" + jobId+ " SQLException" + "DuplicateKeyException ");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId+ " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -595,13 +605,13 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("makeSession() error : sessionId="
-									+ sessionId + ", jobunitId=" + jobunitId
-									+ ", jobId=" + jobId + " SQLException");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
 		m_log.debug("makeSession() end : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
+
 		return fileJobs;
 	}
 }
