@@ -239,7 +239,7 @@ public class JobDialog extends CommonDialog {
 				tabItem3.setControl(m_startDelayComposite);
 
 				//終了遅延
-				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE);
+				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE, false);
 				TabItem tabItem4 = new TabItem(m_tabFolder, SWT.NONE);
 				tabItem4.setText(Messages.getString("end.delay"));
 				tabItem4.setControl(m_endDelayComposite);
@@ -270,7 +270,7 @@ public class JobDialog extends CommonDialog {
 				tabItem4.setControl(m_startDelayComposite);
 
 				//終了遅延
-				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE);
+				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE, false);
 				TabItem tabItem5 = new TabItem(m_tabFolder, SWT.NONE);
 				tabItem5.setText(Messages.getString("end.delay"));
 				tabItem5.setControl(m_endDelayComposite);
@@ -301,7 +301,7 @@ public class JobDialog extends CommonDialog {
 				tabItem4.setControl(m_startDelayComposite);
 
 				//終了遅延
-				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE);
+				m_endDelayComposite = new EndDelayComposite(m_tabFolder, SWT.NONE, true);
 				TabItem tabItem5 = new TabItem(m_tabFolder, SWT.NONE);
 				tabItem5.setText(Messages.getString("end.delay"));
 				tabItem5.setControl(m_endDelayComposite);
