@@ -264,7 +264,25 @@ public class ScheduleDialog extends CommonDialog {
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		m_calendarId = new Combo(composite, SWT.LEFT | SWT.READ_ONLY);
 		m_calendarId.setLayoutData(new RowData(150, SizeConstant.SIZE_COMBO_HEIGHT));
-		List<String> idList = new GetCalendarIdList().getCalendarIdList();
+		List<String> idList = null;
+		try {
+			idList = JobEndpointWrapper.getCalendarIdList();
+		} catch (InvalidRole_Exception e) {
+			// アクセス権なしの場合、エラーダイアログを表示する
+			MessageDialog.openInformation(
+					null,
+					Messages.getString("message"),
+					Messages.getString("message.accesscontrol.16"));
+			m_calendarId.setEnabled(false);
+			
+		} catch (Exception e) {
+			m_log.warn("getCalendarIdList(), " + e.getMessage(), e);
+			MessageDialog.openError(
+					null,
+					Messages.getString("failed"),
+					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
+
 		if(idList != null){
 			m_calendarId.add("");
 			for(int i = 0; i < idList.size(); i++){
@@ -671,6 +689,10 @@ public class ScheduleDialog extends CommonDialog {
 			String calendarId = (String) m_schedule.get(GetScheduleTableDefine.CALENDAR_ID);
 			if (calendarId != null && calendarId.length() > 0) {
 				m_calendarId.select(0);
+				if (!m_calendarId.getEnabled()) {
+					// カレンダー参照権限がない場合
+					m_calendarId.add(calendarId);
+				}
 				for (int i = 0; i < m_calendarId.getItemCount(); i++) {
 					if (calendarId.equals(m_calendarId.getItem(i))) {
 						m_calendarId.select(i);
