@@ -262,6 +262,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * 
 	 * @ejb.interface-method
 	 * 
+	 * トランザクション開始はユーザが制御する。
+	 * (replaceJobunitおよびregisterJobunitをRequiredにより別トランザクションで実行するため)
+	 * また、追加実装により、トランザクションの入れ子が予期せず生じることを避けるため、Neverを採用する。
+	 * @ejb.transaction type="Never"
+	 * 
 	 * @param item ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}の階層オブジェクト
 	 * @throws HinemosUnknown
 	 * @throws JobMasterNotFound
@@ -920,12 +925,15 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	throws FacilityNotFound, HinemosUnknown, JobInfoNotFound, JobMasterNotFound {
 		m_log.debug("runJob() : jobId=" + jobId);
 
+		// ユーザ名の取得
+		Principal pri = m_context.getCallerPrincipal();
+		String loginUser = pri.getName();
+		
 		if (info == null) {
 			// triggerInfo の実行契機種別が「TRIGGER_MANUAL」の場合、ユーザ名を登録
 			if (triggerInfo.getTrigger_type() == JobTriggerTypeConstant.TYPE_MANUAL) {
-				Principal pri = m_context.getCallerPrincipal();
-				m_log.info("runJob() : pri.getName()=" + pri.getName());
-				triggerInfo.setTrigger_info(pri.getName());
+				m_log.info("runJob() : pri.getName()=" + loginUser);
+				triggerInfo.setTrigger_info(loginUser);
 			}
 		}
 
@@ -1105,6 +1113,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 		}
 	}
 
+	 private static Object lockObject = new Object();
+
 	/**
 	 * ジョブの実行用情報を作成します。<BR>
 	 * 
@@ -1128,7 +1138,9 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 		m_log.debug("createJobInfo() : jobId=" + jobId);
 
 		try {
-			return JobSessionUtil.getLocalHome().makeSession(jobunitId, jobId, info, triggerInfo);
+			synchronized(lockObject) { 
+				return JobSessionUtil.getLocalHome().makeSession(jobunitId, jobId, info, triggerInfo); 
+			} 
 		} catch (FacilityNotFound e) {
 			m_log.warn("createJobInfo() : " + e.getClass().getSimpleName() +
 					", " + e.getMessage());
@@ -1474,9 +1486,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 				bean.setReg_date(new Date(info.getCreateTime()));
 			}
 			bean.setReg_user(info.getCreateUser());
-			if (info.getUpdateTime() != null) {
-				bean.setUpdate_date(new Date(info.getUpdateTime()));
-			}
+			// 最新更新時刻はDTOの更新時刻に依存せず、強制的にマネージャ側の今の時刻とする
+			bean.setUpdate_date(new Date());
 			bean.setUpdate_user(info.getUpdateUser());
 		} catch (FinderException e) {
 			AplLogger apllog = new AplLogger("JOB", "job");
