@@ -117,9 +117,6 @@ public class JobListView extends CommonViewPart {
 		//ポップアップメニュー作成
 		createContextMenu();
 
-		//ビューを更新
-		this.update();
-
 		//ツリーを開く
 		m_jobTree.getTreeViewer().expandToLevel(2);
 	}
