@@ -992,6 +992,10 @@ public class MaintenanceDialog extends CommonDialog {
 			}
 
 			if (info.getCalendarId() != null) {
+				if (!m_calendarId.getEnabled()) {
+					// カレンダー参照権限がない場合
+					m_calendarId.addText(info.getCalendarId());
+				}
 				this.m_calendarId.setText(info.getCalendarId());
 			}
 
