@@ -199,7 +199,7 @@ public class ScopeListComposite extends Composite {
 		super.update();
 
 		ArrayList infoList = null;
-		if(facilityId != null && !"".equals(facilityId)){
+		if(facilityId != null){
 			try {
 				List<ScopeDataInfo> records = null;
 				System.out.println("faciiltyID=" + facilityId);
