@@ -82,7 +82,7 @@ public class SelectEvent {
 	private static final Integer MAX_REPORT_EVENT_COUNT_DEFAULT = 2000;
 	private static String SEPARATOR = ",";
 	private static boolean UTF8_BOM = true; // UTF-8のBOMありなし。
-	private String DATE_FORMAT;
+	private static String DATE_FORMAT;
 
 	/**
 	 * コンストラクタ
@@ -646,6 +646,7 @@ public class SelectEvent {
 					Messages.getString("plugin.id") + SEPARATOR +
 					Messages.getString("application") + SEPARATOR +
 					Messages.getString("confirmed") + SEPARATOR +
+					Messages.getString("confirm.time") + SEPARATOR +
 					Messages.getString("confirm.user") + SEPARATOR +
 					Messages.getString("comment") + SEPARATOR +
 					Messages.getString("comment.date") + SEPARATOR +
@@ -813,51 +814,57 @@ public class SelectEvent {
 	private void collectionToFile(Collection<EventLogLocal> ct, FileWriter filewriter) throws IOException {
 
 		int n = 0;
-		SimpleDateFormat sdf = new SimpleDateFormat(DATE_FORMAT);
-		String outputDate;
-		String generationDate;
-		String commentDate;
 		for (EventLogLocal event : ct) {
 			n ++;
-			if (event.getOutputDate() != null) {
-				outputDate = sdf.format(new Date(event.getOutputDate().getTime()));
-			} else {
-				outputDate = "";
-			}
-			if (event.getGenerationDate() != null) {
-				generationDate = sdf.format(new Date(event.getGenerationDate().getTime()));
-			} else {
-				generationDate = "";
-			}
-			if (event.getCommentDate() != null) {
-				commentDate = sdf.format(new Date(event.getCommentDate().getTime()));
-			} else {
-				commentDate = "";
-			}
 			filewriter.write(
-					n + SEPARATOR +
-					PriorityConstant.typeToString(event.getPriority()) + SEPARATOR +
-					outputDate + SEPARATOR +
-					generationDate + SEPARATOR +
-					event.getFacilityId() + SEPARATOR +
-					event.getScopeText() + SEPARATOR +
-					event.getMonitorId() + SEPARATOR +
-					event.getMonitorDetailId() + SEPARATOR +
-					event.getMessageId() + SEPARATOR +
-					event.getPluginId() + SEPARATOR +
-					event.getApplication() + SEPARATOR +
-					ConfirmConstant.typeToString(event.getConfirmFlg()) + SEPARATOR +
-					event.getConfirmDate() + SEPARATOR +
-					event.getConfirmUser() + SEPARATOR +
-					event.getComment() + SEPARATOR +
-					commentDate + SEPARATOR +
-					event.getCommentUser() + SEPARATOR +
-					event.getMessage() + SEPARATOR +
-					event.getMessageOrg() +
+					getDoubleQuote(String.valueOf(n)) + SEPARATOR +
+					getDoubleQuote(PriorityConstant.typeToString(event.getPriority())) + SEPARATOR +
+					getDoubleQuote(t2s(event.getOutputDate())) + SEPARATOR +
+					getDoubleQuote(t2s(event.getGenerationDate())) + SEPARATOR +
+					getDoubleQuote(event.getFacilityId()) + SEPARATOR +
+					getDoubleQuote(event.getScopeText()) + SEPARATOR +
+					getDoubleQuote(event.getMonitorId()) + SEPARATOR +
+					getDoubleQuote(event.getMonitorDetailId()) + SEPARATOR +
+					getDoubleQuote(event.getMessageId()) + SEPARATOR +
+					getDoubleQuote(event.getPluginId()) + SEPARATOR +
+					getDoubleQuote(event.getApplication()) + SEPARATOR +
+					getDoubleQuote(ConfirmConstant.typeToString(event.getConfirmFlg())) + SEPARATOR +
+					getDoubleQuote(t2s(event.getConfirmDate())) + SEPARATOR +
+					getDoubleQuote(event.getConfirmUser()) + SEPARATOR +
+					getDoubleQuote(event.getComment()) + SEPARATOR +
+					getDoubleQuote(t2s(event.getCommentDate())) + SEPARATOR +
+					getDoubleQuote(event.getCommentUser()) + SEPARATOR +
+					getDoubleQuote(event.getMessage()) + SEPARATOR +
+					getDoubleQuote(event.getMessageOrg()) +
 			"\n");
 		}
 	}
-
+	
+	/**
+	 * Timestampを整形する。
+	 * @param t
+	 * @return
+	 */
+	private String t2s(Timestamp t) {
+		if (t == null) {
+			return "";
+		}
+		SimpleDateFormat sdf = new SimpleDateFormat(DATE_FORMAT);
+		return sdf.format(new Date(t.getTime()));
+	}
+	
+	/**
+	 * メッセージやオリジナルメッセージに改行が含まれている場合や、
+	 * 「"」が含まれている場合はMS Excelで読もうとするとおかしくなる。
+	 * 改行等が含まれる可能性のある箇所は下記を利用すること。
+	 */
+	private String getDoubleQuote(String in) {
+		if (in == null) {
+			return "";
+		}
+		return "\"" + in.replace("\"", "\"\"") + "\"";
+	}
+	
 	/**
 	 * アプリケーションログにログを出力
 	 * 
