@@ -1,24 +1,23 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.monitor.factory;
 
 import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Date;
 import java.util.Iterator;
 
 import javax.ejb.CreateException;
@@ -28,19 +27,18 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.FacilityNotFoundException;
-import com.clustercontrol.bean.FacilityTargetConstant;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.bean.Property;
-import com.clustercontrol.monitor.bean.StatusFilterConstant;
-import com.clustercontrol.monitor.bean.StatusInfoData;
+import com.clustercontrol.monitor.bean.StatusDataInfo;
+import com.clustercontrol.monitor.bean.StatusFilterInfo;
+import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
 import com.clustercontrol.notify.monitor.ejb.entity.StatusInfoLocal;
 import com.clustercontrol.notify.monitor.ejb.entity.StatusInfoUtil;
-import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
+import com.clustercontrol.repository.bean.FacilityTargetConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
-import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -50,114 +48,10 @@ import com.clustercontrol.util.apllog.AplLogger;
  * @since 1.0.0
  */
 public class SelectStatus {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog( SelectStatus.class );
+	private static Log m_log = LogFactory.getLog( SelectStatus.class );
 
-	/**
-	 * ステータス情報一覧を返します。
-	 * <p>
-	 * <ol>
-	 * <li>引数で指定されたファシリティ配下のファシリティを、指定されたファシリティのターゲットで取得します。</li>
-	 * <li>取得したファシリティに属するステータス情報を取得します。</li>
-	 * <li>１ステータス情報をStatusInfoDataとして、ステータス情報一覧を保持するリスト（{@link ArrayList}）に格納し返します。<BR>
-	 * </li>
-	 * </ol>
-	 * 
-	 * @param facilityId 取得対象の親ファシリティID
-	 * @param level 取得対象のファシリティのターゲット（配下全て／直下のみ）
-	 * @return ステータス情報一覧（StatusInfoDataが格納されたList）
-	 * @throws CreateException
-	 * @throws NamingException
-	 * @throws FacilityNotFoundException 
-	 * 
-	 * @see com.clustercontrol.monitor.bean.StatusInfoData
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#ALL
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#ONE_LEVEL
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#getFacilityIdList(String, int)
-	 * @see com.clustercontrol.monitor.ejb.entity.StatusInfoBean#ejbFindStatus(String[], Integer, Timestamp, Timestamp, Timestamp, Timestamp, String, String)
-	 * @see com.clustercontrol.monitor.bean.StatusTabelDefine
-	 */
-	public ArrayList<StatusInfoData> getStatusList(String facilityId, int level)
-			throws CreateException, NamingException, FacilityNotFoundException {
-
-		ArrayList<StatusInfoData> list = null;
-		try 
-		{
-			String[] facilityIds = null;
-			if(level == MonitorControllerBean.ONLY){
-				if(facilityId != null && !"".equals(facilityId)){
-					facilityIds = new String[1];
-					facilityIds[0] = facilityId;	
-				}
-				else{
-					return null;
-				}
-			}
-			else{
-				if(facilityId == null || facilityId.equals("")){
-					facilityIds = new String[0];
-				}
-				else{
-					// 直下 または 配下すべてのファシリティIDを取得
-					ArrayList facilityIdList = RepositoryControllerUtil.getLocalHome().create().getFacilityIdList(facilityId, level);
-					
-					if(facilityIdList != null && facilityIdList.size() > 0){
-						// スコープの場合
-						facilityIds = new String[facilityIdList.size()];
-						facilityIdList.toArray(facilityIds);
-					}
-					else{
-						if(facilityId != null){
-							// ノードの場合
-							facilityIds = new String[1];
-							facilityIds[0] = facilityId;
-						}
-						else{
-							// リポジトリが1件も登録されていない場合
-							return null;
-						}
-					}
-				}
-			}
-	
-			// ステータス情報一覧を取得
-			Collection ct = StatusInfoUtil.getLocalHome().findStatus(
-					facilityIds,
-					null,
-					null,
-					null,
-					null,
-					null,
-					null,
-					null
-			);
-			
-			// 2次元配列に変換
-			list = this.collectionToArray(facilityId, ct);
-			
-		} catch (CreateException e) {
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId, null, null, null, null, null, null, null, null};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
-			throw e;
-		} catch (FinderException e) {
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId, null, null, null, null, null, null, null, null};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
-			throw new FacilityNotFoundException(e.getMessage(), e);
-		} catch (NamingException e) {
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId, null, null, null, null, null, null, null, null};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
-			throw e;
-		}
-		return list;
-	}
-	
 	/**
 	 * 引数で指定された条件に一致するステータス一覧情報を返します。
 	 * <p>
@@ -174,7 +68,7 @@ public class SelectStatus {
 	 * @return ステータス情報一覧（StatusInfoDataが格納されたList）
 	 * @throws CreateException
 	 * @throws NamingException
-	 * @throws FacilityNotFoundException 
+	 * @throws MonitorNotFound
 	 * 
 	 * @see com.clustercontrol.monitor.bean.StatusInfoData
 	 * @see com.clustercontrol.util.PropertyUtil#getPropertyValue(com.clustercontrol.bean.Property, java.lang.String)
@@ -182,11 +76,11 @@ public class SelectStatus {
 	 * @see com.clustercontrol.monitor.ejb.entity.StatusInfoBean#ejbFindStatus(String[], Integer, Timestamp, Timestamp, Timestamp, Timestamp, String, String)
 	 * @see com.clustercontrol.monitor.bean.StatusTabelDefine
 	 */
-	public ArrayList getStatusList(String facilityId, Property property)
-			throws CreateException, NamingException, FacilityNotFoundException {
+	public ArrayList<StatusDataInfo> getStatusList(String facilityId, StatusFilterInfo filter)
+	throws CreateException, NamingException, MonitorNotFound {
+
+		ArrayList<StatusDataInfo> list = null;
 
-		ArrayList list = null;
-		
 		Integer priority = null;
 		Timestamp outputFromDate = null;
 		Timestamp outputToDate = null;
@@ -194,68 +88,59 @@ public class SelectStatus {
 		Timestamp generationToDate = null;
 		String facilityType = null;
 		String application = null;
-		String message = null;;
+		String message = null;
 
-		try 
+		String[] facilityIds = null;
+
+		Collection<StatusInfoLocal> ct = null;
+		try
 		{
-			ArrayList values = null;
-			
-			//重要度取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.PRIORITY);
-			if(!"".equals(values.get(0))){
-				int priorityType = PriorityConstant.stringToType((String)values.get(0));
-				if(priorityType != -1){
-					priority = new Integer(priorityType);
+			if(filter != null){
+				//重要度取得
+				if(!"".equals(filter.getPriority()) && filter.getPriority() != null){
+					priority = filter.getPriority();
+				}
+
+				//更新日時（自）取得
+				if(filter.getOutputDateFrom() instanceof Long){
+					outputFromDate = new Timestamp(filter.getOutputDateFrom());
+					outputFromDate.setNanos(0);
+				}
+
+				//更新日時（至）取得
+				if(filter.getOutputDateTo() instanceof Long){
+					outputToDate = new Timestamp(filter.getOutputDateTo());
+					outputToDate.setNanos(999999999);
+				}
+
+				//出力日時（自）取得
+				if(filter.getGenerationDateFrom() instanceof Long){
+					generationFromDate = new Timestamp(filter.getGenerationDateFrom());
+					generationFromDate.setNanos(0);
+				}
+
+				//出力日時（至）取得
+				if(filter.getGenerationDateTo() instanceof Long){
+					generationToDate = new Timestamp(filter.getGenerationDateTo());
+					generationToDate.setNanos(999999999);
+				}
+
+				//対象ファシリティ種別取得
+				if(!"".equals(filter.getFacilityType())){
+					facilityType = filter.getFacilityType();
+				}
+
+				//アプリケーション取得
+				if(!"".equals(filter.getApplication())){
+					application = filter.getApplication();
+				}
+
+				//メッセージ取得
+				if(!"".equals(filter.getMessage())){
+					message = filter.getMessage();
 				}
 			}
-			
-			//更新日時（自）取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.OUTPUT_FROM_DATE);
-			if(values.get(0) instanceof Date){
-				outputFromDate = new Timestamp(((Date)values.get(0)).getTime());
-				outputFromDate.setNanos(0);
-			}
-			
-			//更新日時（至）取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.OUTPUT_TO_DATE);
-			if(values.get(0) instanceof Date){
-				outputToDate = new Timestamp(((Date)values.get(0)).getTime());
-				outputToDate.setNanos(999999999);
-			}
-			
-			//出力日時（自）取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.GENERATION_FROM_DATE);
-			if(values.get(0) instanceof Date){
-				generationFromDate = new Timestamp(((Date)values.get(0)).getTime());
-				generationFromDate.setNanos(0);
-			}
-			
-			//出力日時（至）取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.GENERATION_TO_DATE);
-			if(values.get(0) instanceof Date){
-				generationToDate = new Timestamp(((Date)values.get(0)).getTime());
-				generationToDate.setNanos(999999999);
-			}
-			
-			//対象ファシリティ種別取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.FACILITY_TYPE);
-			if(!"".equals(values.get(0))){
-				facilityType = (String)values.get(0);
-			}
-			
-			//アプリケーション取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.APPLICATION);
-			if(!"".equals(values.get(0))){
-				application = (String)values.get(0);
-			}
-			
-			//メッセージ取得
-			values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.MESSAGE);
-			if(!"".equals(values.get(0))){
-				message = (String)values.get(0);
-			}
 
-			String[] facilityIds = null;
 			if(facilityId == null || facilityId.equals("")){
 				facilityIds = new String[0];
 			}
@@ -265,7 +150,7 @@ public class SelectStatus {
 				if(FacilityTargetConstant.STRING_BENEATH.equals(facilityType)){
 					level = RepositoryControllerBean.ONE_LEVEL;
 				}
-				ArrayList facilityIdList = RepositoryControllerUtil.getLocalHome().create().getFacilityIdList(facilityId, level);
+				ArrayList<String> facilityIdList = RepositoryControllerUtil.getLocalHome().create().getFacilityIdList(facilityId, level);
 
 				if(facilityIdList != null && facilityIdList.size() > 0){
 					// スコープの場合
@@ -273,20 +158,14 @@ public class SelectStatus {
 					facilityIdList.toArray(facilityIds);
 				}
 				else{
-					if(facilityId != null){
-						// ノードの場合
-						facilityIds = new String[1];
-						facilityIds[0] = facilityId;
-					}
-					else{
-						// リポジトリが1件も登録されていない場合
-						return null;
-					}
+					// ノードの場合
+					facilityIds = new String[1];
+					facilityIds[0] = facilityId;
 				}
 			}
-			
+
 			// ステータス情報一覧を、検索条件を指定して取得
-			Collection ct = StatusInfoUtil.getLocalHome().findStatus(
+			ct = StatusInfoUtil.getLocalHome().findStatus(
 					facilityIds,
 					priority,
 					outputFromDate,
@@ -306,7 +185,7 @@ public class SelectStatus {
 			String outputToDateString = null;
 			String generationFromDateString = null;
 			String generationToDateString = null;
-			
+
 			if(priority != null)
 				priorityInt = priority.intValue();
 			if(outputFromDate != null)
@@ -317,11 +196,11 @@ public class SelectStatus {
 				generationFromDateString = generationFromDate.toString();
 			if(generationToDate != null)
 				generationToDateString = generationToDate.toString();
-			
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
+
+			AplLogger apllog = new AplLogger("MON", "mon");
+			String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
+			apllog.put("SYS", "002", args);
+			m_log.debug("getStatusList():" + e.getMessage());
 			throw e;
 		} catch (FinderException e) {
 			int priorityInt = -1;
@@ -329,7 +208,7 @@ public class SelectStatus {
 			String outputToDateString = null;
 			String generationFromDateString = null;
 			String generationToDateString = null;
-			
+
 			if(priority != null)
 				priorityInt = priority.intValue();
 			if(outputFromDate != null)
@@ -340,19 +219,19 @@ public class SelectStatus {
 				generationFromDateString = generationFromDate.toString();
 			if(generationToDate != null)
 				generationToDateString = generationToDate.toString();
-			
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
-			throw new FacilityNotFoundException(e.getMessage(), e);
+
+			AplLogger apllog = new AplLogger("MON", "mon");
+			String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
+			apllog.put("SYS", "002", args);
+			m_log.debug("getStatusList():" + e.getMessage());
+			throw new MonitorNotFound(e.getMessage(), e);
 		} catch (NamingException e) {
 			int priorityInt = -1;
 			String outputFromDateString = null;
 			String outputToDateString = null;
 			String generationFromDateString = null;
 			String generationToDateString = null;
-			
+
 			if(priority != null)
 				priorityInt = priority.intValue();
 			if(outputFromDate != null)
@@ -363,42 +242,17 @@ public class SelectStatus {
 				generationFromDateString = generationFromDate.toString();
 			if(generationToDate != null)
 				generationToDateString = generationToDate.toString();
-			
-            AplLogger apllog = new AplLogger("MON", "mon");
-            String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
-            apllog.put("SYS", "002", args);
-            m_log.debug("getStatusList():" + e.getMessage());
+
+			AplLogger apllog = new AplLogger("MON", "mon");
+			String[] args = {facilityId,PriorityConstant.typeToString(priorityInt),outputFromDateString,outputToDateString,generationFromDateString,generationToDateString,facilityType,application,message};
+			apllog.put("SYS", "002", args);
+			m_log.debug("getStatusList():" + e.getMessage());
 			throw e;
 		}
 		return list;
 	}
-	
-	/**
-	 * 重要度が最高で受信日時が最新のステータス情報を返します。
-	 * <p>
-	 * <ol>
-	 * <li>引数で指定されたファシリティ配下のファシリティを、指定されたファシリティのターゲットで取得します。</li>
-	 * <li>取得したファシリティに属する重要度が最高 かつ 受信日時が最新のステータス情報を取得し返します。</li>
-	 * </ol>
-	 * 
-	 * @param facilityId 取得対象の親ファシリティID
-	 * @param level 取得対象のファシリティのターゲット（配下全て／直下のみ）
-	 * @return ステータス情報のローカルコンポーネントインターフェース
-	 * @throws CreateException
-	 * @throws FinderException
-	 * @throws NamingException
-	 * 
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#getFacilityIdList(String, int)
-	 * @see com.clustercontrol.monitor.ejb.entity.StatusInfoBean#ejbFindHighPriorityStatus(String[], Timestamp, Timestamp, Timestamp, Timestamp, String, String)
-	 */
-	public StatusInfoLocal getHighPriorityStatus(String facilityId, int level)
-			throws CreateException, NamingException, FacilityNotFoundException {
-		return getHighPriorityStatus(facilityId, level, true);
-	}
-	
-	
-	
-	
+
+
 	/**
 	 * 重要度が最高で受信日時が最新のステータス情報を返します。
 	 * <p>
@@ -413,21 +267,21 @@ public class SelectStatus {
 	 * @return ステータス情報のローカルコンポーネントインターフェース
 	 * @throws CreateException
 	 * @throws NamingException
-	 * @throws FacilityNotFoundException 
+	 * @throws FacilityNotFound
 	 * 
 	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#getFacilityIdList(String, int)
 	 * @see com.clustercontrol.monitor.ejb.entity.StatusInfoBean#ejbFindHighPriorityStatus(String[], Timestamp, Timestamp, Timestamp, Timestamp, String, String)
 	 */
-	public StatusInfoLocal getHighPriorityStatus(String facilityId, int level, boolean orderFlg)
-			throws CreateException, NamingException, FacilityNotFoundException {
+	protected StatusInfoLocal getHighPriorityStatus(String facilityId, int level, boolean orderFlg)
+	throws CreateException, NamingException, FacilityNotFound {
 		StatusInfoLocal status = null;
-		try 
+		try
 		{
 			String[] facilityIds = null;
 			if(level == MonitorControllerBean.ONLY){
 				if(facilityId != null && !"".equals(facilityId)){
 					facilityIds = new String[1];
-					facilityIds[0] = facilityId;	
+					facilityIds[0] = facilityId;
 				}
 				else{
 					return null;
@@ -435,8 +289,8 @@ public class SelectStatus {
 			}
 			else{
 				// 直下 または 配下すべてのファシリティIDを取得
-				ArrayList facilityIdList = RepositoryControllerUtil.getLocalHome().create().getFacilityIdList(facilityId, level);
-				
+				ArrayList<String> facilityIdList = RepositoryControllerUtil.getLocalHome().create().getFacilityIdList(facilityId, level);
+
 				if(facilityIdList != null && facilityIdList.size() > 0){
 					// スコープの場合
 					if(facilityId != null){
@@ -457,7 +311,7 @@ public class SelectStatus {
 					}
 				}
 			}
-	
+
 			// ステータス情報一覧を取得
 			Collection ct = StatusInfoUtil.getLocalHome().findHighPriorityStatus(
 					facilityIds,
@@ -468,79 +322,68 @@ public class SelectStatus {
 					null,
 					null,
 					orderFlg);
-			
+
 			Iterator itr = ct.iterator();
 			if(itr.hasNext()){
 				status = (StatusInfoLocal)itr.next();
 			}
-			
+
 		} catch (CreateException e) {
 			m_log.debug("getHighPriorityStatus():" + e.getMessage());
 			throw e;
 		} catch (FinderException e) {
 			m_log.debug("getHighPriorityStatus():" + e.getMessage());
-			throw new FacilityNotFoundException(e.getMessage(), e);
+			throw new FacilityNotFound(e.getMessage(), e);
 		} catch (NamingException e) {
 			m_log.debug("getHighPriorityStatus():" + e.getMessage());
 			throw e;
 		}
 		return status;
 	}
-	
+
 	/**
-	 * DBより取得したステータス情報のリストをを返します。
+	 * DBより取得したステータス情報のリストを返します。
 	 * １ステータス情報をStatusInfoDataインスタンスとし、ステータス情報一覧を保持するリスト（{@link ArrayList}）に格納します。<BR>
 	 * 
 	 * 
 	 * @param parentFacilityId ルートファシリティID
 	 * @param ct ステータス情報取得結果
-	 * @return ステータス情報一覧（StatusInfoDataが格納されたList）
+	 * @return ステータス情報一覧（StatusDataInfoが格納されたList）
 	 *
 	 * @see com.clustercontrol.monitor.bean.StatusInfoData
 	 * @see com.clustercontrol.monitor.bean.StatusTabelDefine
 	 */
 	@SuppressWarnings("unchecked")
-	private ArrayList<StatusInfoData> collectionToArray(String parentFacilityId, Collection ct)
-			throws CreateException, NamingException{
-		
+	private ArrayList<StatusDataInfo> collectionToArray(String parentFacilityId, Collection<StatusInfoLocal> ct)
+	throws CreateException, NamingException{
+
 		RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
 
-		ArrayList<StatusInfoData> list = new ArrayList();
-		Iterator itr = ct.iterator();
-		while(itr.hasNext())
-		{
-			StatusInfoLocal status = (StatusInfoLocal)itr.next();
-			
+		ArrayList<StatusDataInfo> list = new ArrayList<StatusDataInfo>();
+		for(StatusInfoLocal status : ct){
+
 			// スコープの取得
 			String facilityPath = repository.getFacilityPath(status.getFacilityId(), parentFacilityId);
-			
-//			ArrayList info = new ArrayList();
-//			info.add(status.getPriority());
-//			info.add(status.getPluginId());
-//			info.add(status.getMonitorId());
-//			info.add(status.getFacilityId());
-//			info.add(facilityPath);
-//			info.add(status.getApplication());
-//			info.add(new Date(status.getOutputDate().getTime()));
-//			info.add(new Date(status.getGenerationDate().getTime()));
-//			info.add(status.getMessageId());
-//			info.add(status.getMessage());
-//			list.add(info);
-			
-			StatusInfoData statusInfoData = new StatusInfoData();
-			statusInfoData.setPriority(status.getPriority());
-			statusInfoData.setPluginId(status.getPluginId());
-			statusInfoData.setMonitorId(status.getMonitorId());
-			statusInfoData.setFacilityId(status.getFacilityId());
-			statusInfoData.setFacilityPath(facilityPath);
-			statusInfoData.setApplication(status.getApplication());
-			statusInfoData.setOutputDate(status.getOutputDate());
-			statusInfoData.setGenerationDate(status.getGenerationDate());
-			statusInfoData.setMessageId(status.getMessageId());
-			statusInfoData.setMessage(status.getMessage());
-			
-			list.add(statusInfoData);
-			
+
+			StatusDataInfo info = new StatusDataInfo();
+			info.setPriority(status.getPriority());
+			info.setPluginId(status.getPluginId());
+			info.setMonitorId(status.getMonitorId());
+			info.setMonitorDetailId(status.getMonitorDetailId());
+			info.setFacilityId(status.getFacilityId());
+			info.setFacilityPath(facilityPath);
+			info.setApplication(status.getApplication());
+			if (status.getOutputDate() != null) {
+				info.setOutputDate(status.getOutputDate().getTime());
+			}
+			if (status.getGenerationDate() != null) {
+				info.setGenerationDate(status.getGenerationDate().getTime());
+			}
+			info.setMessageId(status.getMessageId());
+			info.setMessage(status.getMessage());
+
+			list.add(info);
+
 		}
 		return list;
 	}
