@@ -17,6 +17,7 @@ package com.clustercontrol.monitor.run.factory;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
@@ -45,6 +46,7 @@ import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoLocal;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoLocal;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorTrapValueInfoLocal;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorTruthValueInfoLocal;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
 import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
@@ -125,7 +127,7 @@ public class SelectMonitor {
 			String facilityPath = repository.getFacilityPath(m_monitor.getFacilityId(), null);
 
 			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
-			Collection notifyId = nc.getNotifyRelation(m_monitor.getNotifyGroupId());
+			Collection<NotifyRelationInfo> notifyId = nc.getNotifyRelation(m_monitor.getNotifyGroupId());
 
 			bean = new MonitorInfo(
 					m_monitor.getApplication(),
@@ -232,6 +234,9 @@ public class SelectMonitor {
 			);
 			valueList.add(value);
 		}
+		
+		// orderNoでソート
+		Collections.sort(valueList, new MonitorStringValueInfoComparator());
 		return valueList;
 	}
 
@@ -493,8 +498,7 @@ public class SelectMonitor {
 	 * <li>１監視情報をテーブルのカラム順（{@link com.clustercontrol.monitor.run.bean.MonitorTabelDefine}）に、リスト（{@link ArrayList}）にセットします。</li>
 	 * <li>この１監視情報を保持するリストを、監視情報一覧を保持するリスト（{@link ArrayList}）に格納し返します。<BR>
 	 *  <dl>
-	 *  <dt>監視情報一覧（Objectの2次元配列）</dt>
-	 *  <dd>{ 監視情報1 {カラム1の値, カラム2の値, … }, 監視情報2{カラム1の値, カラム2の値, …}, … }</dd>
+	 *  性能向上のためMonitorInfoの一部のメンバ変数はnullとなっているので、利用する際は注意すること。
 	 *  </dl>
 	 * </li>
 	 * </ol>
@@ -515,12 +519,57 @@ public class SelectMonitor {
 		try
 		{
 			// 監視情報一覧を取得
-			Collection<MonitorInfoLocal> ct =
-				MonitorInfoUtil.getLocalHome().findAll();
+			Collection<MonitorInfoLocal> ct = MonitorInfoUtil.getLocalHome().findAll();
 
 			for (MonitorInfoLocal info : ct) {
-				list.add(getMonitor(info.getMonitorTypeId(), info.getMonitorId()));
-
+				m_monitor = info;
+				m_monitorTypeId = info.getMonitorTypeId();
+				m_monitorId = info.getMonitorId();
+				
+				// スコープの取得
+				RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
+				String facilityPath = repository.getFacilityPath(info.getFacilityId(), null);
+//				String facilityPath = "";
+				MonitorInfo bean = new MonitorInfo(
+						info.getApplication(),
+						info.getCalendarId(),
+						info.getDescription(),
+						facilityPath,
+						info.getFacilityId(),
+						info.getFailurePriority(),
+						info.getMonitorId(),
+						info.getMonitorTypeId(),
+						info.getMonitorType(),
+						info.getRegDate()==null?null:info.getRegDate().getTime(),
+						info.getRegUser(),
+						info.getRunInterval(),
+						info.getNotifyGroupId(),
+						null, // 通知は空のリストとする。
+						info.getUpdateDate()==null?null:info.getUpdateDate().getTime(),
+						info.getUpdateUser(),
+						info.getMonitorFlg(),
+						info.getCollectorFlg(),
+						info.getItemName(),
+						info.getMeasure(),
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null,
+						null
+				);
+				
+				list.add(bean);
+				
 				// for debug
 				if(m_log.isDebugEnabled()){
 					m_log.debug("getMonitorList() : " +
@@ -551,12 +600,6 @@ public class SelectMonitor {
 		} catch (NamingException e) {
 			outputLog(e, "getMonitorList()", "011");
 			throw e;
-		} catch (HinemosUnknown e) {
-			outputLog(e, "getMonitorList()", "011");
-			throw e;
-		} catch (NotifyNotFound e) {
-			outputLog(e, "getMonitorList()", "011");
-			throw e;
 		}
 
 		m_log.debug("getMonitorList() : end");
@@ -736,3 +779,19 @@ public class SelectMonitor {
 		m_log.debug(method + ":" + e.getMessage());
 	}
 }
+
+/**
+ * 文字列監視用のフィルタ条件のリストのOrderNo順のソート処理用
+ * 
+ * @author hinemos
+ *
+ */
+class MonitorStringValueInfoComparator implements java.util.Comparator<MonitorStringValueInfo>{
+	/**
+	 * orderNoの昇順でソート
+	 */
+	@Override
+	public int compare(MonitorStringValueInfo o1, MonitorStringValueInfo o2) {
+		return (o1.getOrderNo() - o2.getOrderNo());
+	}
+}
\ No newline at end of file
