@@ -93,8 +93,6 @@ public class StatusView extends ScopeListBaseView {
 		//ポップアップメニュー作成
 		createContextMenu();
 
-		this.update();
-
 		// 設定情報反映
 		IPreferenceStore store = ClusterControlPlugin.getDefault()
 		.getPreferenceStore();
@@ -122,18 +120,6 @@ public class StatusView extends ScopeListBaseView {
 	 */
 	@Override
 	protected void doSelectTreeItem(FacilityTreeItem item) {
-		// 検索トグルボタンを元に戻す。
-		//        if (this.condition != null) {
-		//            IToolBarManager toolbar = this.getViewSite().getActionBars()
-		//                    .getToolBarManager();
-		//            String id = "com.clustercontrol.monitor.view.action.StatusFilterAction";
-		//            ActionContributionItem actionItem = (ActionContributionItem) toolbar
-		//                    .find(id);
-		//
-		//            actionItem.getAction().setChecked(false);
-		//            this.condition = null;
-		//        }
-
 		this.update();
 	}
 
