@@ -1,24 +1,27 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Color;
@@ -32,32 +35,28 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.PriorityColorConstant;
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.composite.StringVerifyListener;
-import com.clustercontrol.composite.StyledTextComposite;
+import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.action.AddNotify;
 import com.clustercontrol.notify.action.GetNotify;
 import com.clustercontrol.notify.action.ModifyNotify;
-import com.clustercontrol.notify.bean.NotifyInfo;
-import com.clustercontrol.notify.bean.NotifyInfoDetail;
-import com.clustercontrol.notify.bean.NotifyCommandInfo;
-import com.clustercontrol.notify.bean.NotifySubstitutionParameterConstant;
-import com.clustercontrol.notify.ejb.entity.NotifyCommandInfoData;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.ws.notify.NotifyInfo;
+import com.clustercontrol.ws.notify.NotifyCommandInfo;
 
 /**
  * 通知（コマンド）作成・変更ダイアログクラス<BR>
  * 
- * @version 3.0.0
+ * @version 4.0.0
  * @since 3.0.0
  */
 public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	// これらのカラム数の合計は、15でないといけない。
-	
+
 	/** カラム数（重要度）。 */
 	private static final int WIDTH_PRIORITY = 1;
 
@@ -66,7 +65,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（ユーザ入力欄）。 */
 	private static final int WIDTH_COMMAND_USER = 2;
-	
+
 	/** カラム数（コマンド入力欄）。 */
 	private static final int WIDTH_COMMAND_TEXT = 10;
 
@@ -107,13 +106,13 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	private Text m_textUserUnknown = null;
 
 	/** 実行コマンド（重要度：通知） テキスト。 */
-	private StyledTextComposite m_textCommandInfo = null;
+	private TextWithParameterComposite m_textCommandInfo = null;
 	/** 実行コマンド（重要度：警告） テキスト。 */
-	private StyledTextComposite m_textCommandWarning = null;
+	private TextWithParameterComposite m_textCommandWarning = null;
 	/** 実行コマンド（重要度：危険） テキスト。 */
-	private StyledTextComposite m_textCommandCritical = null;
+	private TextWithParameterComposite m_textCommandCritical = null;
 	/** 実行コマンド（重要度：不明） テキスト。 */
-	private StyledTextComposite m_textCommandUnknown = null;
+	private TextWithParameterComposite m_textCommandUnknown = null;
 
 	// ----- コンストラクタ ----- //
 
@@ -126,7 +125,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	public NotifyCommandCreateDialog(Shell parent) {
 		super(parent);
 	}
-	
+
 	public NotifyCommandCreateDialog(Shell parent, int notifyIdType) {
 		super(parent, notifyIdType);
 	}
@@ -204,17 +203,6 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		/*
 		 * コマンド実行
 		 */
-		label = new Label(parent, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 15;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-		label.setText(Messages.getString("notifies.command") + " : ");
-
-		/*
-		 * 大グループ
-		 */
 		// コマンド設定グループ
 		Group groupComamnd = new Group(parent, SWT.NONE);
 		layout = new GridLayout(1, true);
@@ -227,6 +215,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupComamnd.setLayoutData(gridData);
+		groupComamnd.setText(Messages.getString("notifies.command"));
 
 		/*
 		 * 重要度 ごとの設定
@@ -257,7 +246,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("effective.user"));
-		
+
 		// ラベル（コマンド入力欄）
 		label = new Label(groupComamnd, SWT.NONE);
 		gridData = new GridData();
@@ -281,12 +270,12 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		this.m_checkExecInfo = this.getCheckBox(groupComamnd);
 		this.m_textUserInfo = this.getTextUser(groupComamnd);
 		this.m_textCommandInfo = this.getTextCommand(groupComamnd);
-
 		this.m_checkExecInfo.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				setEnabled(m_checkExecInfo.getSelection(),
 						m_textUserInfo, m_textCommandInfo);
+				update();
 			}
 		});
 		// ラベル（空欄）
@@ -303,12 +292,12 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		this.m_checkExecWarning = this.getCheckBox(groupComamnd);
 		this.m_textUserWarning = this.getTextUser(groupComamnd);
 		this.m_textCommandWarning = this.getTextCommand(groupComamnd);
-
 		this.m_checkExecWarning.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				setEnabled(m_checkExecWarning.getSelection(),
 						m_textUserWarning, m_textCommandWarning);
+				update();
 			}
 		});
 
@@ -326,15 +315,15 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		this.m_checkExecCritical = this.getCheckBox(groupComamnd);
 		this.m_textUserCritical = this.getTextUser(groupComamnd);
 		this.m_textCommandCritical = this.getTextCommand(groupComamnd);
-
 		this.m_checkExecCritical
-				.addSelectionListener(new SelectionAdapter() {
-					@Override
-					public void widgetSelected(SelectionEvent e) {
-						setEnabled(m_checkExecCritical.getSelection(),
-								m_textUserCritical, m_textCommandCritical);
-					}
-				});
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkExecCritical.getSelection(),
+						m_textUserCritical, m_textCommandCritical);
+				update();
+			}
+		});
 		// ラベル（空欄）
 		label = new Label(groupComamnd, SWT.NONE);
 		gridData = new GridData();
@@ -349,16 +338,16 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		this.m_checkExecUnknown = this.getCheckBox(groupComamnd);
 		this.m_textUserUnknown = this.getTextUser(groupComamnd);
 		this.m_textCommandUnknown = this.getTextCommand(groupComamnd);
-
 		this.m_checkExecUnknown
-				.addSelectionListener(new SelectionAdapter() {
-					@Override
-					public void widgetSelected(SelectionEvent e) {
-						setEnabled(m_checkExecUnknown.getSelection(),
-								m_textUserUnknown, m_textCommandUnknown);
-					}
-				});
-		
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkExecUnknown.getSelection(),
+						m_textUserUnknown, m_textCommandUnknown);
+				update();
+			}
+		});
+
 		// ラベル（空欄）
 		label = new Label(groupComamnd, SWT.NONE);
 		gridData = new GridData();
@@ -369,6 +358,87 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 	}
 
+	/**
+	 * 更新処理
+	 * 
+	 */
+	public void update(){
+		// 必須項目を明示
+
+		// 情報
+		if(this.m_checkExecInfo.getSelection()){
+			// ユーザ
+			if("".equals(this.m_textUserInfo.getText())){
+				this.m_textUserInfo.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textUserInfo.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+			// コマンド
+			if("".equals(this.m_textCommandInfo.getText())){
+				this.m_textCommandInfo.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textCommandInfo.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}else{
+			// コマンドの背景色はsetEnabledで別途変更されるため、ここで変える必要はない
+			this.m_textUserInfo.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+
+		// 警告
+		if(this.m_checkExecWarning.getSelection()){
+			// ユーザ
+			if("".equals(this.m_textUserWarning.getText())){
+				this.m_textUserWarning.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textUserWarning.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+			// コマンド
+			if("".equals(this.m_textCommandWarning.getText())){
+				this.m_textCommandWarning.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textCommandWarning.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}else{
+			this.m_textUserWarning.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+
+		// 危険
+		if(this.m_checkExecCritical.getSelection()){
+			// ユーザ
+			if("".equals(this.m_textUserCritical.getText())){
+				this.m_textUserCritical.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textUserCritical.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+			// コマンド
+			if("".equals(this.m_textCommandCritical.getText())){
+				this.m_textCommandCritical.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textCommandCritical.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}else{
+			this.m_textUserCritical.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+
+		// 不明
+		if(m_checkExecUnknown.getSelection()){
+			// ユーザ
+			if("".equals(this.m_textUserUnknown.getText())){
+				this.m_textUserUnknown.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textUserUnknown.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+			// コマンド
+			if("".equals(this.m_textCommandUnknown.getText())){
+				this.m_textCommandUnknown.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				this.m_textCommandUnknown.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}else{
+			this.m_textUserUnknown.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+	}
+
 	/**
 	 * 入力値を保持した通知情報を返します。
 	 * 
@@ -395,54 +465,50 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
-		
+
 		// 抑制情報
 		super.m_notifyInhibition.setInputData(notify);
 
 		// コマンド情報
-		if (notify.getNotifyType() != null
-				&& notify.getNotifyType().intValue() == TYPE_COMMAND
-				&& notify.getNotifyInfoDetail() != null) {
-			ArrayList<NotifyInfoDetail> list = notify.getNotifyInfoDetail();
-			if (list != null) {
-				for (int index = 0; index < list.size(); index++) {
-					NotifyCommandInfo info = (NotifyCommandInfo) list.get(index);
-					if (info != null) {
-						// 通知の場合
-						if (PriorityConstant.TYPE_INFO == info.getPriority()) {
-							this.setInputDataDetail(
-									info,
-									this.m_checkExecInfo,
-									this.m_textUserInfo,
-									this.m_textCommandInfo);
-						}
-						// 警告の場合
-						else if (PriorityConstant.TYPE_WARNING == info
-								.getPriority()) {
-							this.setInputDataDetail(
-									info,
-									this.m_checkExecWarning,
-									this.m_textUserWarning,
-									this.m_textCommandWarning);
-						}
-						// 危険の場合
-						else if (PriorityConstant.TYPE_CRITICAL == info
-								.getPriority()) {
-							this.setInputDataDetail(
-									info,
-									this.m_checkExecCritical,
-									this.m_textUserCritical,
-									this.m_textCommandCritical);
-						}
-						// 不明の場合
-						else if (PriorityConstant.TYPE_UNKNOWN == info
-								.getPriority()) {
-							this.setInputDataDetail(
-									info,
-									this.m_checkExecUnknown,
-									this.m_textUserUnknown,
-									this.m_textCommandUnknown);
-						}
+		List<NotifyCommandInfo> list = notify.getNotifyCommandInfo();
+		if (list != null && list.size() > 0) {
+			for (int index = 0; index < list.size(); index++) {
+				NotifyCommandInfo info = list.get(index);
+				if (info != null) {
+					// 通知の場合
+					if (PriorityConstant.TYPE_INFO == info.getPriority()) {
+						this.setInputDataDetail(
+								info,
+								this.m_checkExecInfo,
+								this.m_textUserInfo,
+								this.m_textCommandInfo);
+					}
+					// 警告の場合
+					else if (PriorityConstant.TYPE_WARNING == info
+							.getPriority()) {
+						this.setInputDataDetail(
+								info,
+								this.m_checkExecWarning,
+								this.m_textUserWarning,
+								this.m_textCommandWarning);
+					}
+					// 危険の場合
+					else if (PriorityConstant.TYPE_CRITICAL == info
+							.getPriority()) {
+						this.setInputDataDetail(
+								info,
+								this.m_checkExecCritical,
+								this.m_textUserCritical,
+								this.m_textCommandCritical);
+					}
+					// 不明の場合
+					else if (PriorityConstant.TYPE_UNKNOWN == info
+							.getPriority()) {
+						this.setInputDataDetail(
+								info,
+								this.m_checkExecUnknown,
+								this.m_textUserUnknown,
+								this.m_textCommandUnknown);
 					}
 				}
 			}
@@ -462,6 +528,9 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		} else {
 			this.setEnabled(true);
 		}
+
+		// 必須項目を可視化
+		this.update();
 	}
 
 	/**
@@ -480,7 +549,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 			NotifyCommandInfo info,
 			Button checkBox,
 			Text textUser,
-			StyledTextComposite textCommand) {
+			TextWithParameterComposite textCommand) {
 		// コマンド通知
 		if (info.getValidFlg() != null
 				&& info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
@@ -503,7 +572,6 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知情報
 	 * 
 	 * @see #createInputData(ArrayList, int, Button, Text, Button)
-	 * @see #setValidateResult(String, String)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
@@ -518,7 +586,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		if (validateResult != null) {
 			return null;
 		}
-		
+
 		// 初回通知情報
 		validateResult = super.m_notifyInitial.createInputData(info);
 		if(validateResult != null){
@@ -532,17 +600,8 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		}
 
 		// コマンド情報
-		// 各重要度で１つも通知が選択されていない場合はエラー
-		if (!this.m_checkExecInfo.getSelection()
-				&& !this.m_checkExecWarning.getSelection()
-				&& !this.m_checkExecCritical.getSelection()
-				&& !this.m_checkExecUnknown.getSelection()) {
-			this.setValidateResult(Messages.getString("message.hinemos.1"),
-					Messages.getString("message.notify.13"));
-			return null;
-		}
 
-		ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
+		List<NotifyCommandInfo> list = new ArrayList<NotifyCommandInfo>();
 
 		list = this.createInputData(
 				list,
@@ -552,31 +611,33 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 				this.m_textUserInfo,
 				this.m_textCommandInfo);
 		list = this.createInputData(
-				list, 
+				list,
 				info.getNotifyId(),
 				PriorityConstant.TYPE_WARNING,
-				this.m_checkExecWarning, 
+				this.m_checkExecWarning,
 				this.m_textUserWarning,
 				this.m_textCommandWarning);
 		list = this.createInputData(
-				list, 
+				list,
 				info.getNotifyId(),
 				PriorityConstant.TYPE_CRITICAL,
 				this.m_checkExecCritical,
 				this.m_textUserCritical,
 				this.m_textCommandCritical);
 		list = this.createInputData(
-				list, 
+				list,
 				info.getNotifyId(),
 				PriorityConstant.TYPE_UNKNOWN,
-				this.m_checkExecUnknown, 
+				this.m_checkExecUnknown,
 				this.m_textUserUnknown,
 				this.m_textCommandUnknown);
 
 		if (list == null) {
 			return null;
 		}
-		info.setNotifyInfoDetail(list);
+		List<NotifyCommandInfo> notifyCommandInfo = info.getNotifyCommandInfo();
+		notifyCommandInfo.clear();
+		notifyCommandInfo.addAll(list);
 
 		// 有効/無効
 		if (this.m_confirmValid.getSelection()) {
@@ -594,26 +655,25 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @return 通知コマンド情報
 	 * 
-	 * @see #setValidateResult(String, String)
 	 */
-	protected ArrayList<NotifyInfoDetail> createInputData(
-			ArrayList<NotifyInfoDetail> list,
+	protected List<NotifyCommandInfo> createInputData(
+			List<NotifyCommandInfo> list,
 			String notifyId,
 			int priority,
 			Button checkBox,
 			Text textUser,
-			StyledTextComposite textCommand) {
+			TextWithParameterComposite textCommand) {
 
 		if (list == null)
 			return null;
 
-		NotifyCommandInfoData command = new NotifyCommandInfoData();
+		NotifyCommandInfo command = new NotifyCommandInfo();
 		// 環境変数を読み込むか否かのフラグ。デフォルトは有効とする。
 		command.setSetEnvironment(ValidConstant.TYPE_VALID);
 
 		// 通知IDを設定
 		command.setNotifyId(notifyId);
-		
+
 		// 重要度
 		command.setPriority(priority);
 		// 実行チェックボックス
@@ -626,27 +686,15 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		if (textUser.getText() != null
 				&& !"".equals((textUser.getText()).trim())) {
 			command.setEffectiveUser(textUser.getText());
-		} else {
-			if (checkBox.getSelection()) {
-				this.setValidateResult(Messages.getString("message.hinemos.1"),
-						Messages.getString("message.notify.31"));
-				return null;
-			}
 		}
-		
+
 		// タイムアウト値を設定（GUI上からは設定できない）
 		command.setTimeout(15000l);
-		
+
 		// 実行コマンド
 		if (textCommand.getText() != null
 				&& !"".equals((textCommand.getText()).trim())) {
 			command.setCommand(textCommand.getText());
-		} else {
-			if (checkBox.getSelection()) {
-				this.setValidateResult(Messages.getString("message.hinemos.1"),
-						Messages.getString("message.notify.32"));
-				return null;
-			}
 		}
 
 		list.add(command);
@@ -764,7 +812,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            抑制チェックボックス
 	 */
 	private void setEnabledDetail(boolean enable, Button checkBox,
-			Text textUser, StyledTextComposite textCommand) {
+			Text textUser, TextWithParameterComposite textCommand) {
 
 		if (enable) {
 			checkBox.setEnabled(true);
@@ -792,7 +840,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            設定対象の抑制チェックボックス
 	 */
 	public void setEnabled(boolean enabled, Text textUser,
-			StyledTextComposite textCommand) {
+			TextWithParameterComposite textCommand) {
 		textUser.setEnabled(enabled);
 		textCommand.setEnabled(enabled);
 	}
@@ -891,15 +939,19 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 */
 	protected Text getTextUser(Composite parent) {
 
-		// テキスト（送信先（セミコロン区切り））
+		// テキスト
 		Text text = new Text(parent, SWT.BORDER);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_USER;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		text.setLayoutData(gridData);
-		text.addVerifyListener(new StringVerifyListener(
-				DataRangeConstant.VARCHAR_64));
+		text.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 
 		return text;
 	}
@@ -911,43 +963,25 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
-	protected StyledTextComposite getTextCommand(Composite parent) {
+	protected TextWithParameterComposite getTextCommand(Composite parent) {
 
-		// テキスト（送信先（セミコロン区切り））
-		StyledTextComposite text = new StyledTextComposite(parent, SWT.BORDER);
+		// テキスト
+		TextWithParameterComposite text = new TextWithParameterComposite(parent, SWT.BORDER | SWT.SINGLE);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_COMMAND_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		text.setLayoutData(gridData);
 
+		text.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		text.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
-		text
-				.setKeywords(NotifySubstitutionParameterConstant
-						.getParameterList());
-		text.setInputUpper(DataRangeConstant.VARCHAR_1024);
+		text.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 
 		return text;
 	}
-
-//	/**
-//	 * コマンド実行の抑制のチェックボックスを返します。
-//	 * 
-//	 * @param parent
-//	 *            親のコンポジット
-//	 * @return 生成されたチェックボックス
-//	 */
-//	protected Button getCheckExecInhibition(Composite parent) {
-//
-//		// チェックボックス（抑制する）
-//		Button button = new Button(parent, SWT.CHECK);
-//		GridData gridData = new GridData();
-//		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-//		gridData.horizontalAlignment = GridData.CENTER;
-//		gridData.grabExcessHorizontalSpace = true;
-//		button.setLayoutData(gridData);
-//
-//		return button;
-//	}
-
 }
\ No newline at end of file
