@@ -83,10 +83,28 @@ public class SendMail implements Notifier {
 	static private String ERRORS_TO_ADDRESS = null;
 	/** 再送回数。 */
 	static private int RETRY_COUNT = 0;
+	/** 再送スリープ */
+	static private int RETRY_SLEEP = 10000; // デフォルトは10秒。
 	/** ロケール情報。 */
 	private Locale m_local = Locale.getDefault();
 
+	/** アドレスロケール */
+	public static final String _CHARSET_ADDRESS;
+	public static final String _CHARSET_ADDRESS_DEFAULT = "UTF-8";
+	
+	/** メール件名ロケール */
+	public static final String _CHARSET_SUBJECT;
+	public static final String _CHARSET_SUBJECT_DEFAULT = "UTF-8";
+	
+	/**`メール本文ロケール */
+	public static final String _CHARSET_CONTENT;
+	public static final String _CHARSET_CONTENT_DEFAULT = "UTF-8";
+	
 	static {
+		String charsetAddress = _CHARSET_ADDRESS_DEFAULT;
+		String charsetSubject = _CHARSET_SUBJECT_DEFAULT;
+		String charsetContent = _CHARSET_CONTENT_DEFAULT;
+		
 		/**
 		 * メールの設定をプロパティファイルから取得
 		 */
@@ -104,9 +122,28 @@ public class SendMail implements Notifier {
 			.getProperty("common.mail.errors.to.address");
 			RETRY_COUNT = Integer.parseInt(HinemosProperties
 					.getProperty("common.mail.retry.count"));
+			RETRY_SLEEP = Integer.parseInt(HinemosProperties
+					.getProperty("common.mail.retry.sleep"));
+			
+			charsetAddress = HinemosProperties.getProperty("common.mail.charset.address", _CHARSET_ADDRESS_DEFAULT);
+			charsetSubject = HinemosProperties.getProperty("common.mail.charset.subject", _CHARSET_SUBJECT_DEFAULT);
+			charsetContent = HinemosProperties.getProperty("common.mail.charset.content", _CHARSET_CONTENT_DEFAULT);
+			
 		} catch (Exception e) {
 			m_log.warn(e.getMessage(), e);
 		}
+		
+		_CHARSET_ADDRESS = charsetAddress;
+		_CHARSET_SUBJECT = charsetSubject;
+		_CHARSET_CONTENT = charsetContent;
+		
+		m_log.info("initialized mail sender : from_address = " + FROM_ADDRESS 
+				+ ", From = " + FROM_PERSONAL_NAME + " <" + REPLY_TO_ADDRESS + ">"
+				+ ", Reply-To = " + REPLY_TO_PERSONAL_NAME + " <" + REPLY_TO_ADDRESS + ">"
+				+ ", Errors-To = " + ERRORS_TO_ADDRESS
+				+ ", retries = " + RETRY_COUNT
+				+ ", retry-sleep = " + RETRY_SLEEP
+				+ ", Charset [address:subject:content] = [" + _CHARSET_ADDRESS + ":" + _CHARSET_SUBJECT + ":" + _CHARSET_CONTENT + "]");
 	}
 
 	/**
@@ -180,12 +217,12 @@ public class SendMail implements Notifier {
 				m_log.error("sendMail():" + detailMsg);
 				internalErrorNotify(notifyId, "007", detailMsg);
 			} catch (MessagingException e) {
-				String detailMsg = e.getMessage() + "\nCause : " + e.getCause().getMessage();
+				String detailMsg = e.getCause() != null ? e.getMessage() + "\nCause : " + e.getCause().getMessage() : e.getMessage();
 				m_log.error("sendMail():" + e.getMessage(), e);
 				internalErrorNotify(notifyId, "007", detailMsg);
 			}
 		} catch (Exception e1) {
-			String detailMsg = e1.getMessage() + "\nCause : " + e1.getCause().getMessage();
+			String detailMsg = e1.getCause() != null ? e1.getMessage() + "\nCause : " + e1.getCause().getMessage() : e1.getMessage();
 			m_log.error("sendMail():" + e1.getMessage(), e1);
 			internalErrorNotify(notifyId, "007", detailMsg);
 		}
@@ -237,15 +274,13 @@ public class SendMail implements Notifier {
 
 		// 送信元メールアドレスと送信者名を指定
 		if (FROM_ADDRESS != null && FROM_PERSONAL_NAME != null) {
-			mes.setFrom(new InternetAddress(FROM_ADDRESS, FROM_PERSONAL_NAME,
-			"iso-2022-jp"));
+			mes.setFrom(new InternetAddress(FROM_ADDRESS, FROM_PERSONAL_NAME, _CHARSET_ADDRESS));
 		} else if (FROM_ADDRESS != null && FROM_PERSONAL_NAME == null) {
 			mes.setFrom(new InternetAddress(FROM_ADDRESS));
 		}
 		// REPLY-TOを指定
 		if (REPLY_TO_ADDRESS != null && REPLY_TO_PERSONAL_NAME != null) {
-			InternetAddress reply[] = { new InternetAddress(REPLY_TO_ADDRESS,
-					REPLY_TO_PERSONAL_NAME, "iso-2022-jp") };
+			InternetAddress reply[] = { new InternetAddress(REPLY_TO_ADDRESS, REPLY_TO_PERSONAL_NAME, _CHARSET_ADDRESS) };
 			mes.setReplyTo(reply);
 			mes.reply(true);
 		} else if (REPLY_TO_ADDRESS != null && REPLY_TO_PERSONAL_NAME == null) {
@@ -268,10 +303,10 @@ public class SendMail implements Notifier {
 		mes.setRecipients(javax.mail.Message.RecipientType.TO, toAddress);
 
 		// メールの件名を指定
-		mes.setSubject(MimeUtility.encodeText(subject, "iso-2022-jp", "B"));
+		mes.setSubject(MimeUtility.encodeText(subject, _CHARSET_SUBJECT, "B"));
 
 		// メールの内容を指定
-		mes.setContent(content, "text/plain; charset=iso-2022-jp");
+		mes.setContent(content, "text/plain; charset=" + _CHARSET_CONTENT);
 
 		// 送信日付を指定
 		mes.setSentDate(new Date());
@@ -295,6 +330,14 @@ public class SendMail implements Notifier {
 					throw me;
 				}
 			}
+			if (retryFlg) {
+				try {
+					m_log.debug("sendMail() : resend sleep (" + RETRY_SLEEP + ")");
+					Thread.sleep(RETRY_SLEEP);
+				} catch (InterruptedException e) {
+					m_log.warn("InterruptedException " + e.getMessage());
+				}
+			}
 		}
 	}
 
@@ -413,7 +456,13 @@ public class SendMail implements Notifier {
 			// 例外発生時のメール本文
 			return "An error occurred creating message.";
 		}
-		return buf.toString();
+		
+		// 改行コードをLFからCRLFに変更する。
+		// 本来はJavaMailが変換するはずだが、変換されないこともあるので、
+		// 予め変更しておく。
+		String ret = buf.toString().replaceAll("\r\n", "\n").replaceAll("\n", "\r\n");
+		
+		return ret;
 	}
 
 	/**
