@@ -252,13 +252,24 @@ public class PerformanceGraphComposite extends Composite {
 				m_log.debug("displayTypeCombo : select " + selectedDisplayType);
 
 				if(STRING_DISPLAY_DEVICE.equals(selectedDisplayType)){
+					displayItem.setEnabled(true);
 					displayItem.removeAll();
 					for (CollectorItemParentInfo itemCodeInfo : itemCodeListByDisplayDevice){
 						displayItem.add(getFullItemName(itemCodeInfo));
 					}
 					displayItem.select(0);
 				}
+				else if(STRING_DISPLAY_ITEMCODE.equals(selectedDisplayType)){
+					displayItem.removeAll();
+					for (CollectorItemParentInfo itemCodeInfo : performanceDataSettings.getItemCodeList()){
+						displayItem.add(getFullItemName(itemCodeInfo));
+					}
+					displayItem.select(0);
+					displayItem.setEnabled(false);
+					
+				}
 				else{
+					displayItem.setEnabled(true);
 					displayItem.removeAll();
 					for (CollectorItemParentInfo itemCodeInfo : performanceDataSettings.getItemCodeList()){
 						displayItem.add(getFullItemName(itemCodeInfo));
