@@ -54,6 +54,7 @@ import com.clustercontrol.performance.action.RecordDataWriter;
 import com.clustercontrol.performance.util.Messages;
 import com.clustercontrol.repository.FacilityPath;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
+import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
@@ -160,7 +161,11 @@ public class ExportDialog extends Dialog {
 			MonitorInfo monitorInfo = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, this.monitorTypeId);
 			this.facilityId = monitorInfo.getFacilityId();
 			this.treeItem = RepositoryEndpointWrapper.getExecTargetFacilityTreeByFacilityId(this.facilityId);
-		} catch (Exception e) {
+		}catch (InvalidRole_Exception e) {
+			m_log.warn("createTree() getMonitor, " + e.getMessage(), e);
+			MessageDialog.openInformation(null, com.clustercontrol.util.Messages.getString("message"),
+					com.clustercontrol.util.Messages.getString("message.accesscontrol.16"));
+		}catch (Exception e) {
 			m_log.warn("createTree() getMonitor, " + e.getMessage(), e);
 		}
 
