@@ -173,6 +173,10 @@ public class CollectorItemComboComposite extends Composite {
 		// 現在設定されている項目を全て消去
 		m_comboCollectorItem.removeAll();
 
+		// 空の項目を一つ追加。
+		m_comboCollectorItem.add("");
+		m_comboCollectorItem.setData("", null);
+		
 		Iterator<CollectorItemInfo> itr = itemInfoList.iterator();
 		while(itr.hasNext()){
 			CollectorItemInfo itemInfo = itr.next();
@@ -236,7 +240,9 @@ public class CollectorItemComboComposite extends Composite {
 		}
 
 		Iterator<CollectorItemInfo> itr = itemInfoList.iterator();
-		int i=0;
+		// getAvailableCollectorItemListはCPU使用率から始まるが、
+		// 実際のコンボボックスは空行から始まるので、i=1からスタートさせる。
+		int i=1;
 		while(itr.hasNext()){
 			CollectorItemInfo itemInfo = itr.next();
 
