@@ -270,7 +270,11 @@ public class CollectorItemCodeTable {
 				m_log.debug("getEnableCodeSet() target node  = " + nodeId);
 				NodeInfo node = bean.getNode(nodeId);
 
-				platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), node.getVirtualizationSolution()));
+				if ("controller".equals(node.getVirtualizationNodeType())) {
+					platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), ""));
+				} else {
+					platformSet.add(new PlatformIdAndSubPlatformId(node.getPlatformFamily(), node.getVirtualizationSolution()));
+				}
 			}
 
 			////
