@@ -39,6 +39,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.poller.NotInitializedException;
@@ -101,6 +103,21 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 	// collectメソッドがスレッドセーフではないため、同期をとるために使用
 	private static Object m_syncObj = new Object();
 
+	// Hinemos4.0.2以降で利用可能。Hinemos4.1では利用不可。
+	private static boolean retryPollerFlag = false;
+	static {
+		String key = "poller.process.retry";
+		try {
+			String str = HinemosProperties.getProperty(key);
+			if (str != null && !"".equals(str)) {
+				retryPollerFlag = Boolean.parseBoolean(str);
+			}
+		} catch (Exception e) {
+			m_log.warn(key + " is not available. " + e.getMessage());
+		}
+		m_log.info(key + "=" + retryPollerFlag);
+	}
+	
 	/**
 	 * コンストラクタ
 	 * 
@@ -319,25 +336,27 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 								+ "valueSetName(Set) or valueSetParam(Set) or valueSetPath(Set) is null , SNMP Polling failed");
 					}
 
-					// ポーリングを行い再度プロセス数のカウントを行う
-					if (retryCount < MAX_RETRY_COUNT) {
-						m_log.warn("collect() retry polling. FacilityID : " + facilityId);
-
-						// タイムアウト3秒でポーリングを実行
-						// 実際にポーリングに応答できないノードの場合はこのリトライとなる。
-						// ノードへのポーリングはシーケンシャルに実行されるため、
-						// 複数ノードが同時に通信不通となったときのことを考慮し、タイムアウト値を短くする。
-						try {
-							table = retryPolling(facilityId, collectMethod, pollingTargets);
-						} catch (NotInitializedException e) {
-							m_log.error(e.getMessage(), e);
-						} catch (DataTableNotFoundException e) {
-							m_log.error(e.getMessage(), e);
-						} catch (NamingException e) {
-							m_log.error(e.getMessage(), e);
+					if (retryPollerFlag) {
+						// ポーリングを行い再度プロセス数のカウントを行う
+						if (retryCount < MAX_RETRY_COUNT) {
+							m_log.warn("collect() retry polling. FacilityID : " + facilityId);
+	
+							// タイムアウト3秒でポーリングを実行
+							// 実際にポーリングに応答できないノードの場合はこのリトライとなる。
+							// ノードへのポーリングはシーケンシャルに実行されるため、
+							// 複数ノードが同時に通信不通となったときのことを考慮し、タイムアウト値を短くする。
+							try {
+								table = retryPolling(facilityId, collectMethod, pollingTargets);
+							} catch (NotInitializedException e) {
+								m_log.error(e.getMessage(), e);
+							} catch (DataTableNotFoundException e) {
+								m_log.error(e.getMessage(), e);
+							} catch (NamingException e) {
+								m_log.error(e.getMessage(), e);
+							}
+	
+							continue;  // for文の初めからやり直す
 						}
-
-						continue;  // for文の初めからやり直す
 					}
 
 					// 「値を取得できませんでした」メッセージでイベント通知
@@ -927,4 +946,17 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		// SNMP収集値の共有テーブルをルックアップ
 		m_sst = PollingProcConnectionManager.getSharedTable();
 	}
+	
+	@Override
+	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws NamingException, CreateException, FinderException, HinemosUnknown{
+		boolean ret = super.setMonitorInfo(monitorTypeId, monitorId);
+		
+		if(!m_isInCalendarTerm && m_isInNextCalendarTerm){
+			// 次回が稼働日の場合はスケジュールを再作成する
+			m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId = " + m_facilityId);
+			new ModifyPollingSchedule().addSchedule(m_monitorTypeId, m_monitorId, m_facilityId, m_runInterval);
+		}
+		
+		return ret;
+	}
 }
