@@ -92,6 +92,10 @@ public class FacilitySelector {
 	// <ホスト名, ファシリティIDのセット>（監視対象外となっているものは含まない。）
 	private static HashMap<String, HashSet<String>> hostnameFacilityIdMap;
 	private static final Object hostnameFacilityIdMapLock = new Object();
+	
+	// containsFacilityIdメソッドのためのキャッシュ
+	private static ConcurrentHashMap<String, Boolean> containsFacilityIdMap;
+	private static final Object containsFacilityIdMapLock = new Object();
 
 	static {
 		initCacheFacilityTree();
@@ -120,6 +124,9 @@ public class FacilitySelector {
 		synchronized (hostnameFacilityIdMapLock) {
 			hostnameFacilityIdMap = null;
 		}
+		synchronized (containsFacilityIdMapLock) {
+			containsFacilityIdMap = null;
+		}
 	}
 
 	/**
@@ -933,34 +940,39 @@ public class FacilitySelector {
 	private static String getNodeScopePathRecursive(FacilityLocal facility, FacilityLocal parentFacility) {
 		/** ローカル変数 */
 		String path = null;
-
+		String facilityId = facility.getFacilityId();
+		String parentFacilityId = null;
+		if (parentFacility != null) {
+			parentFacilityId = parentFacility.getFacilityId();
+		}
+		
 		/** メイン処理 */
 		if (facility.isNode()) {
 			// ノードの場合、ファシリティ名を返す
 			return facility.getFacilityName();
 		}
 
-		if (parentFacility != null && facility.getFacilityId().compareTo(parentFacility.getFacilityId()) == 0) {
+		if (parentFacility != null && facilityId.equals(parentFacilityId)) {
 			// 起点となるファシリティと一致していた場合、区切り文字だけ返す
 			return "";
 		}
 
-		if (facility.getFacilityRelationAsChild() == null || facility.getFacilityRelationAsChild().size() == 0) {
+		Collection<FacilityRelationLocal> list = (Collection<FacilityRelationLocal>)facility.getFacilityRelationAsChild();
+		if (list == null || list.size() == 0) {
 			// ルートスコープの場合
 			if (parentFacility == null) {
 				path = facility.getFacilityName() + SEPARATOR;
 			}
 		} else {
 			// 再帰的にスコープのパス名を生成する
-			for (FacilityRelationLocal relation : (Collection<FacilityRelationLocal>)facility.getFacilityRelationAsChild()) {
+			for (FacilityRelationLocal relation : list) {
 				if (parentFacility == null) {
 					// 絶対パス名を取得する場合
 					path = getNodeScopePathRecursive(relation.getParentFacility(), parentFacility) + facility.getFacilityName() + SEPARATOR;
-				} else if (facility.getFacilityId().compareTo(parentFacility.getFacilityId()) != 0) {
+				} else if (!facilityId.equals(parentFacilityId)) {
 					// 相対パス名を取得する場合
 					path = getNodeScopePathRecursive(relation.getParentFacility(), parentFacility) + facility.getFacilityName() + SEPARATOR;
 				}
-
 				// スコープ-スコープ間の関連は単一であるため、ループを抜ける
 				break;
 			}
@@ -1058,6 +1070,7 @@ public class FacilitySelector {
 		if (rootTree != null) {
 			return rootTree;
 		}
+		long startTime = System.currentTimeMillis();
 
 		// 木構造最上位インスタンスの生成
 		rootInfo = new FacilityInfo();
@@ -1097,6 +1110,8 @@ public class FacilitySelector {
 			}
 		}
 
+		long endTime = System.currentTimeMillis();
+		m_log.info("refresh FacilityTree(Cache). " + (endTime - startTime) + "ms.");
 		m_log.debug("successful in getting tree data of facilities.");
 		return rootTree;
 	}
@@ -1364,6 +1379,7 @@ public class FacilitySelector {
 		synchronized (nodenameFacilityIdMapLock) {
 			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
 			if(nodenameFacilityIdMap == null){
+				long startTime = System.currentTimeMillis();
 				try {
 					Collection<NodeLocal> allNodes = NodeUtil.getLocalHome().findAll();
 
@@ -1393,6 +1409,8 @@ public class FacilitySelector {
 				} catch (NamingException e) {
 					m_log.error("initCacheFacilityTree()", e);
 				}
+				long endTime = System.currentTimeMillis();
+				m_log.info("refresh nodenameFacilityIdMap(Cache). " + (endTime - startTime) + "ms.");
 			}
 
 			return nodenameFacilityIdMap.get(nodename.toLowerCase());
@@ -1412,6 +1430,7 @@ public class FacilitySelector {
 		synchronized (inetAddressFacilityIdMapLock) {
 			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
 			if(inetAddressFacilityIdMap == null){
+				long startTime = System.currentTimeMillis();
 				try {
 					Collection<NodeLocal> allNodes = NodeUtil.getLocalHome().findAll();
 
@@ -1444,6 +1463,8 @@ public class FacilitySelector {
 							inetAddressFacilityIdSet.add(facilityId);
 						}
 					}
+					long endTime = System.currentTimeMillis();
+					m_log.info("refresh inetAddressFacilityIdMap(Cache). " + (endTime - startTime) + "ms.");
 				} catch (FinderException e) {
 					m_log.error("initCacheFacilityTree()", e);
 				} catch (NamingException e) {
@@ -1470,6 +1491,7 @@ public class FacilitySelector {
 		synchronized (hostnameFacilityIdMapLock) {
 			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
 			if(hostnameFacilityIdMap == null){
+				long startTime = System.currentTimeMillis();
 				try {
 					Collection<NodeHostnameLocal> allNodes = NodeHostnameUtil.getLocalHome().findAll();
 
@@ -1498,6 +1520,8 @@ public class FacilitySelector {
 				} catch (NamingException e) {
 					m_log.error("initCacheFacilityTree()", e);
 				}
+				long endTime = System.currentTimeMillis();
+				m_log.info("refresh hostnameFacilityIdMap(Cache). " + (endTime - startTime) + "ms.");
 			}
 
 			return hostnameFacilityIdMap.get(hostname);
@@ -1511,6 +1535,19 @@ public class FacilitySelector {
 	 * @return 含まれる場合はtrueを返す
 	 */
 	public static boolean containsFaciliyId(String scopeFacilityId, String nodeFacilityId){
-		return getNodeFacilityIdList(scopeFacilityId, RepositoryControllerBean.ALL, false, true).contains(nodeFacilityId);
+		Boolean ret = null; 
+		String key = scopeFacilityId + "," + nodeFacilityId;
+		synchronized (containsFacilityIdMapLock) {
+			if (containsFacilityIdMap == null) {
+				containsFacilityIdMap = new ConcurrentHashMap<String, Boolean>();
+			}
+			ret = containsFacilityIdMap.get(key);
+			if (ret == null) {
+				ret = getNodeFacilityIdList(scopeFacilityId, RepositoryControllerBean.ALL, false, true).contains(nodeFacilityId);
+				m_log.info("containsFacilityId key=" + key + ", ret=" + ret);
+				containsFacilityIdMap.put(key, ret);
+			}
+		}
+		return ret;
 	}
 }
