@@ -120,7 +120,8 @@ public class SearchNodeBySNMP {
 				retries,
 				timeout,
 				oidList,
-				false);
+				false,
+				true);
 		m_log.debug("searchNode() polling stop");
 
 		// 取得したデータを詰め替える
@@ -511,9 +512,9 @@ public class SearchNodeBySNMP {
 				NodeFilesystemInfo filesystem = new NodeFilesystemInfo();
 
 				//表示名
-				filesystem.setDeviceName(convStringFilessystem(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue())));
-				//デバイス名
 				filesystem.setDeviceDisplayName(convStringFilessystem(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue())));
+				//デバイス名
+				filesystem.setDeviceName(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue()));
 				//デバイスINDEX
 				filesystem.setDeviceIndex(((Long)ret.getValue(getEntryKey(OID_FILESYSTEM_INDEX+"."+i)).getValue()).intValue());
 				//デバイス種別
@@ -581,57 +582,45 @@ public class SearchNodeBySNMP {
 	}
 
 	/**
-	 * SNMPで取得できるファイルシステム名(マウント場所)から表示名に変換するメソッド。
-	 * 例：
-	 * C:\ Label: Serial Number 9058dd61
-	 * ↓
-	 * C:\
+	 * SNMPで取得したファイルシステム名が16進数だった場合に文字列に変換する
 	 */
 	private static String convStringFilessystem(String str){
-
-		if(str.matches("/.*")){
-			//UNIX系OSの場合
-			return str;
-		}
-		else if(str.matches("[A-Z]:\\\\.*")){
-			//Winodws系OSの場合
-			return str;
-		}
-		else{
-			//strはなぜかASCIIが16進で入っている。
-			//文字が化けて入力された場合には、変換を行う。
-			char[] chars;
-			short  first;
-			short second;
-			chars=str.toCharArray();
-			StringBuffer ret = new StringBuffer();
-
-			int j=0;
-
-			for(int i = 0; i<chars.length;){
-
-
-				first  = (short) (chars[i] - 48); //48は"0"なので、"1"→1の変換
-				second = (short)(chars[i+1]- 48);
-
-				if(second >10){
-					//16進でA-Fの場合には、さらに7を引く
-					//10 ⇔ A(16進)なので("A"→65)を10にする、 10 = "A"(65) - "0"(48) - 7
-					second -=7;
+		if (str.matches("([0-9A-Fa-f]{2}\\s{0,1})+")){
+			try{
+				//strはなぜかASCIIが16進で入っている。
+				//文字が化けて入力された場合には、変換を行う。
+				char[] chars;
+				short  first;
+				short second;
+				chars=str.toCharArray();
+				StringBuffer ret = new StringBuffer();
+				
+				for(int i = 0; i<chars.length;){
+					
+					first  = (short) (chars[i] - 48); //48は"0"なので、"1"→1の変換
+					second = (short)(chars[i+1]- 48);
+					
+					if(second >10){
+						//16進でA-Fの場合には、さらに7を引く
+						//10 ⇔ A(16進)なので("A"→65)を10にする、 10 = "A"(65) - "0"(48) - 7
+						second -=7;
+					}
+					
+					ret.append((char) (first*16+second));
+					
+					i+=3;//1文字は"56 "とかで構成するので、配列2つを読んで" "をスキップ
 				}
-
-
-				//				ret[j] = (char) (first*16+second);
-				ret.append((char) (first*16+second));
-
-				i+=3;//1文字は"56 "とかで構成するので、配列2つを読んで" "をスキップ
-				j++;//リターンも文字もインクリメント
+				
+				m_log.info("Find By SNMP : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
+				return ret.substring(0,3);
+			} catch(Exception e){
+				m_log.warn("Find By SNMP : " + e.getMessage());
+				return str;
 			}
-
-			m_log.info("Find By SNMP : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
-			return ret.substring(0,3);
 		}
-
+		else {
+			return str;
+		}
 	}
 
 
