@@ -87,9 +87,6 @@ public class ScopeListView extends ScopeListBaseView {
 		this.composite.getTableViewer().addSelectionChangedListener(
 				new ScopeListSelectionChangedListener(composite));
 
-
-		this.update();
-
 		return this.composite;
 	}
 
@@ -169,8 +166,6 @@ public class ScopeListView extends ScopeListBaseView {
 	@Override
 	public void update() {
 		FacilityTree.reflesh();
-		FacilityTreeItem item = this.getScopeTreeComposite().getSelectItem();
-		this.composite.update(item);
 	}
 
 	/**
