@@ -117,6 +117,17 @@ public class SelfCheckTaskSubmitter implements Runnable {
 							)
 					)
 			);
+			
+			_executorService.submit(
+					new SelfCheckTask(
+							new QuartzMonitor(
+									SelfCheckConfig.getJndiRAMScheduler(),
+									SelfCheckConfig.getTriggerNameRAM(),
+									SelfCheckConfig.getTriggerGroupRAM(),
+									SelfCheckConfig.getSchedulerDelayThresholdSec()
+							)
+					)
+			);
 		}
 
 		// swap-out
