@@ -496,6 +496,26 @@ public class OidListComposite extends Composite {
 		this.monitorId = monitorId;
 	}
 
+	/**
+	 * コンポジットを有効/無効化します。
+	 * 
+	 */
+	@Override
+	public void setEnabled(boolean enabled){
+		super.setEnabled(enabled);
+		comboMib.setEnabled(enabled);
+		textFilter.setEnabled(enabled);
+		buttonClearFilter.setEnabled(enabled);
+		buttonShowOidTable.setEnabled(enabled);
+		buttonAdd.setEnabled(enabled);
+		buttonModify.setEnabled(enabled);
+		buttonDelete.setEnabled(enabled);
+		table.setEnabled(enabled);
+		radioSpecific.setEnabled(enabled);
+		radioAll.setEnabled(enabled);
+		radioUnregistered.setEnabled(enabled);
+	}
+	
 	/**
 	 * コンポジットを更新します。
 	 * <p>
