@@ -43,6 +43,7 @@ import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
+import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
@@ -75,21 +76,6 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	// ----- instance フィールド ----- //
 
-	/** 入力値を保持するオブジェクト */
-	private MonitorInfo inputData = null;
-
-	/** 入力値の正当性を保持するオブジェクト */
-	private ValidateResult validateResult = null;
-
-	/** 変更対象の監視項目ID */
-	private String monitorId = null;
-
-	/** 監視基本情報 */
-	private MonitorBasicScopeComposite monitorBasicComposite = null;
-
-	/** カレンダ設定 */
-	CalendarIdListComposite calendarComposite = null;
-
 	/** コミュニティチェックボタン **/
 	private Button buttonCommunityCheckOff = null;
 	private Button buttonCommunityCheckOn = null;
@@ -107,17 +93,6 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	/** OIDテーブル */
 	private OidListComposite oidListComposite = null;
 
-	/** テーブルビューア */
-	private CommonTableViewer tableViewer = null;
-
-	/** 通知情報 */
-	private NotifyInfoComposite notifyInfoComposite = null;
-
-
-	/** この設定を有効にする */
-	private Button confirmValid = null;
-
-
 	/****/
 
 	// ----- コンストラクタ ----- //
@@ -187,28 +162,80 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		// 監視基本情報
 		//SNMPトラップでは未登録ノードからのトラップを受け付けるようにするので、
 		//第３引数をtrueとする。
-		monitorBasicComposite = new MonitorBasicScopeComposite(parent, SWT.NONE ,true);
+		m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE ,true);
 		gridData = new GridData();
-		gridData.horizontalSpan =MAX_COLUMN_SMALL;
+		gridData.horizontalSpan =MAX_COLUMN;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		monitorBasicComposite.setLayoutData(gridData);
-
+		m_monitorBasic.setLayoutData(gridData);
+		
 		/*
-		 * カレンダ
+		 * 条件グループ
 		 */
-		calendarComposite = new CalendarIdListComposite(parent, SWT.NONE, true);
+		groupRule = new Group(parent, SWT.NONE);
+		layout = new GridLayout(1, true);
+		layout.marginWidth = 5;
+		layout.marginHeight = 5;
+		layout.numColumns = MAX_COLUMN;
+		groupRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN_SMALL;
+		gridData.horizontalSpan = MAX_COLUMN;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		calendarComposite.setLayoutData(gridData);
+		groupRule.setLayoutData(gridData);
+		groupRule.setText(Messages.getString("monitor.rule"));
 
+		m_monitorRule = new MonitorRuleComposite(groupRule, SWT.NONE);
+		gridData = new GridData();
+		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		m_monitorRule.setLayoutData(gridData);
+		
+		// 監視間隔の設定を利用不可とする
+		this.m_monitorRule.setRunIntervalEnabled(false);
+		
+		/*
+		 * 監視グループ
+		 */
+		groupMonitor = new Group(parent, SWT.NONE);
+		layout = new GridLayout(1, true);
+		layout.marginWidth = 5;
+		layout.marginHeight = 5;
+		layout.numColumns = MAX_COLUMN;
+		groupMonitor.setLayout(layout);
+		gridData = new GridData();
+		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		groupMonitor.setLayoutData(gridData);
+		groupMonitor.setText(Messages.getString("monitor.run"));
+
+		// 監視（有効／無効）
+		this.confirmMonitorValid = new Button(groupMonitor, SWT.CHECK);
+		gridData = new GridData();
+		gridData.horizontalSpan = MAX_COLUMN;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.confirmMonitorValid.setLayoutData(gridData);
+		this.confirmMonitorValid.setText(Messages.getString("monitor.run"));
+		this.confirmMonitorValid.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				// 判定、通知部分を有効/無効化
+				if(confirmMonitorValid.getSelection()){
+					setMonitorEnabled(true);
+				}else{
+					setMonitorEnabled(false);
+				}
+			}
+		});
+		
 		/*
 		 * トラップ定義グループ
 		 */
 		// グループ
-		Group groupCheckRule = new Group(parent, SWT.NONE);
+		Group groupCheckRule = new Group(groupMonitor, SWT.NONE);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -392,40 +419,26 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		this.oidListComposite.setLayoutData(gridData);
 
 		/*
-		 * 通知情報の属性グループ
+		 * 通知グループ（監視グループの子グループ）
 		 */
-		// グループ
-		Group groupNotifyAttribute = new Group(parent, SWT.NONE);
+		groupNotifyAttribute = new Group(groupMonitor, SWT.NONE);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
 		layout.numColumns = 1;
 		groupNotifyAttribute.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN_SMALL;
+		gridData.horizontalSpan = MAX_COLUMN;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupNotifyAttribute.setLayoutData(gridData);
 		groupNotifyAttribute.setText(Messages.getString("notify.attribute"));
-		
-		// 通知情報（通知ID，アプリケーションID，実行）
-		this.notifyInfoComposite = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
+		this.m_notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.HORIZONTAL_ALIGN_CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		notifyInfoComposite.setLayoutData(gridData);
-
-		/*
-		 * 有効／無効
-		 */
-		this.confirmValid = new Button(parent, SWT.CHECK);
-		gridData = new GridData();
-		gridData.horizontalSpan = MAX_COLUMN_SMALL;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		this.confirmValid.setLayoutData(gridData);
-		this.confirmValid.setText(Messages.getString("setting.valid.confirmed"));
+		this.m_notifyInfo.setLayoutData(gridData);
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
@@ -478,16 +491,6 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 
 	}
 
-	/**
-	 * 入力内容を返します。
-	 * 
-	 * @return 入力内容を保持した通知情報
-	 */
-	@Override
-	public MonitorInfo getInputData() {
-		return this.inputData;
-	}
-
 	/**
 	 * 各項目に入力値を設定します。
 	 * 
@@ -498,7 +501,9 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	protected void setInputData(MonitorInfo monitor) {
 
 		// 監視基本情報
-		monitorBasicComposite.setInputData(monitor);
+		super.setInputData(monitor);
+		this.inputData = monitor;
+		
 		TrapCheckInfo checkInfo = monitor.getTrapCheckInfo();
 		if (checkInfo == null) {
 			checkInfo = new TrapCheckInfo();
@@ -511,11 +516,6 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 			monitorTrapValueInfoList = new ArrayList<MonitorTrapValueInfo>();
 		}
 
-		// カレンダID
-		if (monitor.getCalendarId() != null) {
-			calendarComposite.setText(monitor.getCalendarId());
-		}
-
 		// コミュニティ名
 		if(checkInfo.getCommunityName() != null){
 			textCommunityName.setText(checkInfo.getCommunityName());
@@ -549,22 +549,6 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		oidListComposite.setMonitorId(monitor.getMonitorId());
 		oidListComposite.setOidList(monitor.getTrapValueInfo());
 		oidListComposite.update();
-
-		//通知情報の設定
-		if(monitor.getNotifyId() != null)
-			this.notifyInfoComposite.setNotify(monitor.getNotifyId());
-
-		//アプリケーション
-		if (monitor.getApplication() != null) {
-			this.notifyInfoComposite.setApplication(monitor.getApplication());
-		}
-
-
-		// 有効／無効
-		//if (monitor.getValid() == ValidConstant.TYPE_VALID) {
-		if (monitor.getMonitorFlg() == ValidConstant.TYPE_VALID) {
-			this.confirmValid.setSelection(true);
-		}
 	}
 
 	/**
@@ -574,78 +558,70 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 	 */
 	@Override
 	protected MonitorInfo createInputData() {
-
-		// 初期化
-		MonitorInfo info = new MonitorInfo();
-		info.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMPTRAP);
-		info.setMonitorType(MonitorTypeConstant.TYPE_TRAP);
-
-		// 監視基本情報
-		validateResult = monitorBasicComposite.createInputData(info);
+		super.createInputData();
 		if(validateResult != null){
 			return null;
 		}
 
+		//SNMPTRAP監視固有情報を設定
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMPTRAP);
+		monitorInfo.setMonitorType(MonitorTypeConstant.TYPE_TRAP);
+
+		// 監視条件 SNMPTRAP監視情報
 		TrapCheckInfo trapInfo = new TrapCheckInfo();
 		trapInfo.setCheckMode(0);
 		trapInfo.setCommunityCheck(0);
 		trapInfo.setCharsetConvert(0);
-		trapInfo.setMonitorId(info.getMonitorId());
+		trapInfo.setMonitorId(monitorInfo.getMonitorId());
 		trapInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMPTRAP);
-		info.setTrapCheckInfo(trapInfo);
-		List<MonitorTrapValueInfo> monitorTrapValueInfoList = info.getTrapValueInfo();
+		monitorInfo.setTrapCheckInfo(trapInfo);
+		List<MonitorTrapValueInfo> monitorTrapValueInfoList = monitorInfo.getTrapValueInfo();
 		monitorTrapValueInfoList = new ArrayList<MonitorTrapValueInfo>();
 
-		// カレンダID
-		if (calendarComposite.getText() != null
-				&& !"".equals((calendarComposite.getText()).trim())) {
-			info.setCalendarId(calendarComposite.getText());
-		}
-
 		// コミュニティ名
 		if (this.buttonCommunityCheckOn.getSelection()) {
-			(info.getTrapCheckInfo()).setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_ON);
+			(monitorInfo.getTrapCheckInfo()).setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_ON);
 		} else {
-			(info.getTrapCheckInfo()).setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_OFF);
+			(monitorInfo.getTrapCheckInfo()).setCommunityCheck(MonitorTrapConstant.COMMUNITY_CHECK_OFF);
 		}
 		if (this.textCommunityName.getText() != null
 				&& !"".equals((this.textCommunityName.getText()).trim())) {
-			(info.getTrapCheckInfo()).setCommunityName(textCommunityName.getText());
+			(monitorInfo.getTrapCheckInfo()).setCommunityName(textCommunityName.getText());
 		}
 
 		// 文字コード
 		if (this.buttonCharsetConvertOn.getSelection()) {
-			(info.getTrapCheckInfo()).setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_ON);
+			(monitorInfo.getTrapCheckInfo()).setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_ON);
 		} else {
-			(info.getTrapCheckInfo()).setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_OFF);
+			(monitorInfo.getTrapCheckInfo()).setCharsetConvert(MonitorTrapConstant.CHARSET_CONVERT_OFF);
 		}
 		if (this.textCharsetName.getText() != null
 				&& !"".equals((this.textCharsetName.getText()).trim())) {
-			(info.getTrapCheckInfo()).setCharsetName(textCharsetName.getText());
+			(monitorInfo.getTrapCheckInfo()).setCharsetName(textCharsetName.getText());
 		}
 
 		//OIDのチェック方法を設定します。
 
-		(info.getTrapCheckInfo()).setCheckMode(oidListComposite.getCheckMode());
+		(monitorInfo.getTrapCheckInfo()).setCheckMode(oidListComposite.getCheckMode());
 
 		//OID情報
-		List<MonitorTrapValueInfo> monitorTrapValueInfoList_old = info.getTrapValueInfo();
+		List<MonitorTrapValueInfo> monitorTrapValueInfoList_old = monitorInfo.getTrapValueInfo();
 		monitorTrapValueInfoList_old.clear();
 		if (oidListComposite.getOidList() != null) {
 			monitorTrapValueInfoList_old.addAll(oidListComposite.getOidList());
 		}
-		for(int i = 0; i < info.getTrapValueInfo().size(); i++){
-			MonitorTrapValueInfo oidInfo = info.getTrapValueInfo().get(i);
+		for(int i = 0; i < monitorInfo.getTrapValueInfo().size(); i++){
+			MonitorTrapValueInfo oidInfo = monitorInfo.getTrapValueInfo().get(i);
 			if(oidInfo.getMonitorId() == null ||
-					oidInfo.getMonitorId().equals(info.getMonitorId())){
-				oidInfo.setMonitorId(info.getMonitorId());
+					oidInfo.getMonitorId().equals(monitorInfo.getMonitorId())){
+				oidInfo.setMonitorId(monitorInfo.getMonitorId());
 			}
 		}
 
 		// 通知関連情報とアプリケーションの設定
 		// 通知グループIDの設定
-		info.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMPTRAP, info.getMonitorId()));
-		validateResult = this.notifyInfoComposite.createInputData(info);
+		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMPTRAP, monitorInfo.getMonitorId()));
+		validateResult = this.m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
 				if(!displayQuestion(validateResult)){
@@ -658,34 +634,17 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 			}
 		}
 
-		// 監視感覚
-		info.setRunInterval(0);
+		// 監視間隔
+		monitorInfo.setRunInterval(0);
 
 		// 有効/無効
-		if (this.confirmValid.getSelection()) {
-			info.setMonitorFlg(ValidConstant.TYPE_VALID);
+		if (this.confirmMonitorValid.getSelection()) {
+			monitorInfo.setMonitorFlg(ValidConstant.TYPE_VALID);
 		} else {
-			info.setMonitorFlg(ValidConstant.TYPE_INVALID);
+			monitorInfo.setMonitorFlg(ValidConstant.TYPE_INVALID);
 		}
 
-		return info;
-	}
-
-	/**
-	 * 入力値チェックをします。
-	 * 
-	 * @return 検証結果
-	 */
-	@Override
-	protected ValidateResult validate() {
-		// 入力値生成
-		this.inputData = this.createInputData();
-
-		if (this.inputData != null) { //&& this.validateResult == null) {
-			return super.validate();
-		} else {
-			return validateResult;
-		}
+		return monitorInfo;
 	}
 
 	/**
@@ -773,34 +732,21 @@ public class SnmpTrapCreateDialog extends CommonMonitorDialog {
 		}
 		return result;
 	}
-
+	
 	/**
-	 * ＯＫボタンのテキストを返します。
+	 * 監視エリアを有効/無効化します。
 	 * 
-	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
-	protected String getOkButtonText() {
-		return Messages.getString("ok");
-	}
-
-	/**
-	 * キャンセルボタンのテキストを返します。
-	 * 
-	 * @return キャンセルボタンのテキスト
-	 */
-	@Override
-	protected String getCancelButtonText() {
-		return Messages.getString("cancel");
-	}
-
-	/**
-	 * tableViewerを返します。
-	 * 
-	 * @return tableViewer
-	 */
-	public CommonTableViewer getTableViewer() {
-		return this.tableViewer;
+	protected void setMonitorEnabled(boolean enabled){
+		super.setMonitorEnabled(enabled);
+		buttonCommunityCheckOff.setEnabled(enabled);
+		buttonCommunityCheckOn.setEnabled(enabled);
+		textCommunityName.setEnabled(enabled);
+		buttonCharsetConvertOff.setEnabled(enabled);
+		buttonCharsetConvertOn.setEnabled(enabled);
+		textCharsetName.setEnabled(enabled);
+		oidListComposite.setEnabled(enabled);
 	}
 
 	/**
