@@ -26,7 +26,9 @@ import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.opennms.protocols.snmp.SnmpIPAddress;
 import org.opennms.protocols.snmp.SnmpOctetString;
+import org.opennms.protocols.snmp.SnmpOpaque;
 import org.opennms.protocols.snmp.SnmpSyntax;
 
 import com.clustercontrol.bean.PriorityConstant;
@@ -473,7 +475,7 @@ public class SnmpTrapFilter {
 			return "";
 		}
 
-		if (! (value instanceof SnmpOctetString)) {
+		if (! (value instanceof SnmpOctetString) || value instanceof SnmpIPAddress || value instanceof SnmpOpaque) {
 			if (_log.isDebugEnabled()) {
 				_log.debug("not octet string, skip decoding : " + value.toString());
 			}
