@@ -1,22 +1,23 @@
 /*
- 
+
 Copyright (C) 2009 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.vm;
 
 import java.util.List;
 
+import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.sharedtable.DataTable;
 
 /**
@@ -28,13 +29,13 @@ import com.clustercontrol.sharedtable.DataTable;
  * @since 3.1.0
  */
 public interface VmPollerImplInterface {
-	
+
 	/**
 	 * インスタンス生成後に呼ぶこと！
 	 * @param pollerProtocol
 	 */
 	public void init(String pollerProtocol);
-	
+
 	/**
 	 * @param ipAddress
 	 * @param vmNodeType
@@ -45,13 +46,5 @@ public interface VmPollerImplInterface {
 	 * @param protocol
 	 * @param params
 	 */
-	public DataTable polling(
-			String ipAddress,
-			String vmNodeType,
-			String vmManagementIp,
-			String vmName,
-			String user,
-			String password,
-			String protocol,
-			List<String> params);
+	public DataTable polling(NodeInfo guestInfo, NodeInfo hostInfo, List<String> params);
 }
\ No newline at end of file
