@@ -1,6 +1,6 @@
-/*
+﻿/*
  
-Copyright (C) 2007, 2008 NTT DATA Corporation
+Copyright (C) 2012 NTT DATA Corporation
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -14,14 +14,15 @@ PURPOSE.  See the GNU General Public License for more details.
 */
 
 //
-// Hinemos SNMP gG[WFgDLL for Hinemos ver. 2.4.0
+// Hinemos SNMP 拡張エージェントDLL for Hinemos ver. 4.0
 //
 
 // -------------------------------------------------------------
-//    CN[ht@C
+//    インクルードファイル
 // -------------------------------------------------------------
 #include <windows.h>
 #include <stdio.h>
+#include <tchar.h>
 #include <snmp.h>
 #include <winbase.h>
 #include "HinemosSNMPExtAgent.h"
@@ -32,15 +33,22 @@ PURPOSE.  See the GNU General Public License for more details.
 #include <vector>
 #include <iostream>
 
+#define SNMPEXTAGT_REGISTRY_KEY "SOFTWARE\\HinemosAgent\\SNMPExtAgent"
+
 using namespace std;
 
 // -------------------------------------------------------------
-//    ֐錾
+//    関数宣言
 // -------------------------------------------------------------
 UINT ResolveVarBind( SnmpVarBind *, UINT );
 UINT OperateVarBind( UINT, int, SnmpVarBind * );
 
-VOID PostEvtLog(WORD, LPTSTR, char *, DWORD );
+VOID PostEvtLog(WORD, LPTSTR, char *, long );
+VOID PostEvtLogDouble( WORD logType, LPTSTR ModuleName, char *SendMsg, double val );
+VOID PostEvtLogDWORDLONG(WORD, LPTSTR, char *, DWORDLONG );
+VOID PostEvtLogChar( WORD logType, LPTSTR ModuleName, char *SendMsg, char c, long val);
+VOID PostEvtLogString( WORD logType, LPTSTR ModuleName, char *SendMsg, char *str, long val);
+
 VOID GetMibData(MIB_ENTRY *);
 
 AsnCounter GetCpuRawUser(void);
@@ -71,7 +79,7 @@ AsnInteger GetLaLoadInt1(void);
 AsnInteger GetLaLoadInt2(void);
 AsnInteger GetLaLoadInt3(void);
 
-AsnCounter GetDiskIOIndex(char *);
+AsnInteger GetDiskIOIndex(int);
 char *	   GetDiskIODevice(char *);
 AsnCounter GetDiskIORead(char *);
 AsnCounter GetDiskIOWrite(char *);
@@ -82,14 +90,28 @@ VOID CreateDataStructure(void);
 VOID SetEntry(UINT, UINT *, AsnInteger32 *, UINT, UINT, int);
 VOID SetEntry(UINT, UINT *, AsnCounter32 *, UINT, UINT, int);
 
+long __ReadRegDword(HKEY hReg, const char *szKey);
+int __ReadRegMultiSz(HKEY hReg, const char *szKey, long* values, int valuesSize);
+
 int writeLog(char *	);
 
 // for debug
 char *g_szAbout = NULL;
 //
 
+// 各取得値を出力するかを示すフラグ（0:出力しない / 1:出力する）
+int verbose = 0;
 
-/* DLL̏ */
+// APIエラー時に出力するイベントログのイベントレベル
+WORD errorEventLevel = EVENTLOG_ERROR_TYPE;
+
+
+// 無視するエラーコードの配列
+long ignoreErrorCode[1024];
+int ignoreErrorCodeSize;
+
+
+/* DLLの初期化 */
 BOOL WINAPI DllMain(HANDLE hDll, DWORD  dwReason, LPVOID lpReserved )
 {
 
@@ -105,58 +127,102 @@ BOOL WINAPI DllMain(HANDLE hDll, DWORD  dwReason, LPVOID lpReserved )
     return TRUE;
 }
 
-/* DLL[hꂽۂɁASNMP ServiceďoAsB */
+// 設定をレジストリから取得する
+void GetRegistrySettings(){
+	HKEY	hReg;
+	long	rc = 0;
+
+	rc = RegOpenKeyEx(HKEY_LOCAL_MACHINE, SNMPEXTAGT_REGISTRY_KEY, 0, KEY_READ, &hReg);
+	if( rc == ERROR_SUCCESS ){
+		// 無視すべきエラーコード
+		ignoreErrorCodeSize = __ReadRegMultiSz(hReg, "IgnoreErrorCode", ignoreErrorCode, 1024) ;
+
+		// 詳細ロギング
+		verbose = __ReadRegDword(hReg, "Verbose") ;
+
+		// APIエラー時イベントレベル
+		long errorLevel = __ReadRegDword(hReg, "ErrorEventLevel");
+		errorEventLevel = (errorLevel == -1) ? EVENTLOG_ERROR_TYPE : (WORD)errorLevel;
+	}
+	RegCloseKey(hReg);
+}
+
+// エラーコードに対してイベントを出力する必要があるか否かを判定する
+bool CheckErrorCode(long code){
+	// 成功ならfalse
+	if(code == ERROR_SUCCESS || code == ERROR_IO_PENDING){
+		return false;
+	}
+
+	for(int i=0; i<ignoreErrorCodeSize; i++){
+		// 無視すべきエラーコードならfalse (-1の場合は何もチェックせずfalse)
+		if(ignoreErrorCode[i] == code || ignoreErrorCode[i] == -1){
+			return false;
+		}
+	}
+	
+	return true;
+}
+
+/* DLLがロードされた際に、SNMP Serviceから呼出され、初期化処理を行う。 */
 BOOL WINAPI SnmpExtensionInit(IN  DWORD dwTimeZeroReference,
 							    OUT HANDLE *hPollForTrapEvent,
 								OUT AsnObjectIdentifier *supportedView )
 {
 
-	// VXeCxg쐬p̃p[^
+	// システムイベント作成用のパラメータ
 	SECURITY_ATTRIBUTES	sa;
 	SECURITY_DESCRIPTOR	sd;
 	sa.nLength = sizeof( SECURITY_ATTRIBUTES );
 	sa.bInheritHandle = TRUE;
 	sa.lpSecurityDescriptor = &sd;
 
-    // ZLeB񏉊
+	// "初期化開始"のEventLogを書出す
+	PostEvtLog( EVENTLOG_INFORMATION_TYPE, "ExtensionInit", "Initialization Start", 0 );
+
+    // セキュリティ情報初期化
 	if( !InitializeSecurityDescriptor( &sd, SECURITY_DESCRIPTOR_REVISION )){
-		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "ZLeBG[", 0 );
+		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "Security Initialization Error", 0 );
 		return FALSE;
 	}
-    // ZLeBݒ
+    // セキュリティ情報設定
 	if( !SetSecurityDescriptorDacl( &sd,TRUE, (PACL)NULL, FALSE )){
-		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "ZLeBݒG[", 0 );
+		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "Security Settings Error", 0 );
 		return FALSE;
 	}
-    // Trap֐N邽߂̃VXeCxg쐬
+    // Trap関数を起動するためのシステムイベントを作成
 	*hPollForTrapEvent = CreateEvent(&sa, FALSE, FALSE, TRAP_EVENT_NAME );
 	if((*hPollForTrapEvent) == NULL ){
-		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "CxgG[", 0 );
+		PostEvtLog( EVENTLOG_ERROR_TYPE, "ExtensionInit", "Event Generation Error", 0 );
 		return FALSE;
     }
-    // Ăьw̎p[^ۑ
+    // 呼び元指定の時刻調整パラメータを保存
     dwTimeZero = dwTimeZeroReference;
 
-    // {DLL̏ΏۂƂȂMIBOIDݒ
+    // 本DLLの処理対象となるMIBのOIDを設定
     *supportedView = MIB_OidPrefix;
 
-	// Trap֐N邽߂̃VXeCxgۑ
+	// Trap関数を起動するためのシステムイベントを保存
 
-//	TrapɂĂ͎Ȃ
+//	Trapについては実装しない
 //	hSimulateTrap = *hPollForTrapEvent;
 
-	//Kvȃf[^\쐬
+	// 設定をレジストリから取得する
+	GetRegistrySettings();
+
+	//必要なデータ構造を作成する
 	CreateDataStructure();
 
-	// ""EventLogo
-	PostEvtLog( EVENTLOG_INFORMATION_TYPE, "ExtensionInit", "", 0 );
+	// "初期化完了"のEventLogを書出す
+	PostEvtLog( EVENTLOG_INFORMATION_TYPE, "ExtensionInit", "Initialization Completed", 0 );
+
     return TRUE;
 }
 
 
 /*
- * {DLL̏ΏۂƂȂMIBɑ΂ASNMP}l[WGet/GetNext/SetvꂽۂɁA
- * SNMP ServiceďovɉsB
+ * 本DLLの処理対象となるMIBに対し、SNMPマネージャからのGet/GetNext/Setが要求された際に、
+ * SNMP Serviceから呼出され要求に応じた処理を行う。
  */
 BOOL WINAPI SnmpExtensionQuery(IN BYTE requestType, IN OUT SnmpVarBindList *variableBindings,
 							   OUT AsnInteger32 *errorStatus, OUT AsnInteger32 *errorIndex )
@@ -164,13 +230,13 @@ BOOL WINAPI SnmpExtensionQuery(IN BYTE requestType, IN OUT SnmpVarBindList *vari
     static ULONG requestCount = 0;
     UINT    i;
 
-    // ϐ̐JԂ
+    // 変数の数分処理を繰り返す
     for( i=0; i<(variableBindings->len); i++ ){
 
-        // NGXgƕϐɑ΂鏈
+        // リクエストと変数に対する処理
         *errorStatus = ResolveVarBind( &variableBindings->list[i], requestType );
 
-        // G[̏ꍇ̏
+        // エラーの場合の処理
         if( *errorStatus != SNMP_ERRORSTATUS_NOERROR ){
             *errorIndex = i + 1;
             break;
@@ -180,7 +246,7 @@ BOOL WINAPI SnmpExtensionQuery(IN BYTE requestType, IN OUT SnmpVarBindList *vari
 }
 
 /*
- * NGXĝOIDɑ΂āAX|XԂOIDݒ肷
+ * リクエストのあったOIDに対して、レスポンスを返すOIDを設定する
  */
 UINT ResolveVarBind(IN OUT SnmpVarBind *VarBind, IN UINT PduAction )
 {
@@ -191,16 +257,16 @@ UINT ResolveVarBind(IN OUT SnmpVarBind *VarBind, IN UINT PduAction )
 
 	UINT size = mib_entries.size();
 
-	//GETNEXTł̖₢킹ł́A
-	//VarBindɁAԂlƁAɎQƂOIDZbgreturnB
+	//GETNEXTでの問い合わせでは、
+	//VarBindに、返り値と、次に参照するOIDをセットしてreturnする。
 	if (PduAction == SNMP_PDU_GETNEXT) {
 		
-		//o^ĂMIB̈ꗗƁAOIDr
+		//登録されているMIBの一覧と、順にOIDを比較する
 		for (UINT i = 0; i < size ; i++) {
 			int compResult = SnmpUtilOidCmp(&VarBind->name, &mib_entries[i].Oid);
 
-			// ₢킹̂OIDƃXg}b`Ȃꍇ́A
-			// [DTŁA₢킹OID < XgOIDƂȂŏOIDɂāA\l擾B
+			// 問い合わせのあったOIDとリストがマッチしない場合は、
+			// 深さ優先探索で、問い合わせOID < リストのOIDとなる最初のOIDについて、性能値を取得する。
 			if (compResult < 0) {
 
 				if( PduAction != SNMP_PDU_GETNEXT ){
@@ -209,26 +275,26 @@ UINT ResolveVarBind(IN OUT SnmpVarBind *VarBind, IN UINT PduAction )
 
 				noSuchName = false;
 
-				// ̌ʁAl擾OID
+				// 検索の結果、値を取得するOID
 				PduAction = SNMP_PDU_GET;
 				index = i;
 
-				// ϐUAOIDݒ
+				// 変数を一旦解放し、OIDを設定
 				SnmpUtilOidFree( &VarBind->name );
 				SnmpUtilOidCpy( &VarBind->name, &mib_entries[i].Oid );
 
 				break;
 
-			// ₢킹̂OID݂ꍇ
+			// 問い合わせのあったOIDが存在した場合
 			} else if (compResult == 0) {
 				PduAction = SNMP_PDU_GET;
 				index = i;
 				noSuchName = false;
 				SnmpUtilOidFree( &VarBind->name );
 				
-				// Xg̖ł΁AOIDNULLƂĕԂ
+				// リストの末尾であれば、次のOIDはNULLとして返す
 				if (i != size - 1){
-					//OID݂ꍇ͂ݒ肷
+					//次のOIDが存在する場合はそれを設定する
 					index++;
 					SnmpUtilOidCpy( &VarBind->name, &mib_entries[index].Oid );
 					break;
@@ -236,14 +302,14 @@ UINT ResolveVarBind(IN OUT SnmpVarBind *VarBind, IN UINT PduAction )
 			}
 		}
 
-	// GETł̖₢킹ł́AXgāA݂琫\l擾B
+	// GETでの問い合わせでは、リストを検索して、存在したら性能値を取得する。
 	} else if (PduAction == SNMP_PDU_GET) {
 
-		//mapoRŏ擾
+		//map経由で情報を取得
 		string requestOid(SnmpUtilOidToA(&VarBind->name));
 		map<string, int>::iterator itr = oid_index_map.find(requestOid);
 
-		//݂tO؂ւ
+		//存在したらフラグを切り替える
 		if (itr != oid_index_map.end()) {
 			noSuchName = false;
 			index = (*itr).second;
@@ -254,14 +320,14 @@ UINT ResolveVarBind(IN OUT SnmpVarBind *VarBind, IN UINT PduAction )
         return( SNMP_ERRORSTATUS_NOSUCHNAME );
     }
 
-    // ֐Ăяo
+    // 処理関数を呼び出す
     nResult = OperateVarBind( PduAction, index, VarBind );
 
     return( nResult );
 }
 
 /*
- * NGXgɑ΂Ԃlݒ肷B
+ * リクエストに対する返り値を設定する。
  */
 UINT OperateVarBind(IN UINT Action, IN int index, IN SnmpVarBind *VarBind )
 {
@@ -275,24 +341,24 @@ UINT OperateVarBind(IN UINT Action, IN int index, IN SnmpVarBind *VarBind )
 /*
 	case SNMP_PDU_GETNEXT:
 		
-		//OIDZbg
+		//次のOIDをセットする
 		if (index < oid_index_map.size() - 1) {
 			 NextMibPtr = &mib_entries[next_index];
 
-		//XgŌOIDꍇ
+		//リスト最後尾のOIDだった場合
 		} else if (index == oid_index_map.size() - 1) {
 			 NextMibPtr = NULL;
 
-		// YOIDȂꍇAreturn
+		// 該当するOIDが見つからなかった場合、returnする
 		} else {
 			return( SNMP_ERRORSTATUS_NOSUCHNAME );
 		}
 
-		//ɌׂOIDZbg
+		//次に見るべきOIDをセットする
         SnmpUtilOidFree( &VarBind->name );
 		SnmpUtilOidCpy( &VarBind->name, &NextMibPtr->Oid );
 
-	    // ֐Ăяo (3.2) ċAďo
+	    // 処理関数を呼び出す (3.2) ※再帰呼出
         ErrStat = OperateVarBind( SNMP_PDU_GET, index, VarBind );
         return( ErrStat );
 */
@@ -302,7 +368,7 @@ UINT OperateVarBind(IN UINT Action, IN int index, IN SnmpVarBind *VarBind )
             return( SNMP_ERRORSTATUS_NOSUCHNAME );
 	    }
 
-		//\[X擾
+		//リソース情報を取得
 		GetMibData(MibPtr);
 
         VarBind->value.asnType = MibPtr->Type;
@@ -315,19 +381,19 @@ UINT OperateVarBind(IN UINT Action, IN int index, IN SnmpVarBind *VarBind )
 
             case ASN_OCTETSTRING:
 				
-				// octetZbg
+				// octet数をセット
 				//VarBind->value.asnValue.string.length = ((AsnOctetString *)(LPSTR)MibPtr->Storage)->length;
 				//VarBind->value.asnValue.string.length = strlen((LPSTR)MibPtr->Storage);
 				VarBind->value.asnValue.string.length = 1;
 
-				// m
+				// メモリ確保
 				VarBind->value.asnValue.string.stream = (unsigned char *)SnmpUtilMemAlloc( VarBind->value.asnValue.string.length * sizeof(char) );
 
 				if( VarBind->value.asnValue.string.stream == NULL ){
 					return( SNMP_ERRORSTATUS_GENERR );
 				}
 
-				// |C^̏Rs[
+				// ポインタの情報をコピーする
 				memcpy( VarBind->value.asnValue.string.stream, (LPSTR)MibPtr->Storage, VarBind->value.asnValue.string.length);
 
 				VarBind->value.asnValue.string.dynamic = TRUE;
@@ -380,22 +446,77 @@ UINT OperateVarBind(IN UINT Action, IN int index, IN SnmpVarBind *VarBind )
     return( SNMP_ERRORSTATUS_NOERROR );
 }
 
-/* WindowsCxgo͗p֐ */
-VOID PostEvtLog( WORD logType, LPTSTR ModuleName, char *SendMsg, DWORD val )
+/* レジストリ参照用関数 */
+long __ReadRegDword(HKEY hReg, const char *szKey)
 {
-    CHAR    Msg[512];			// bZ[W
-    HANDLE  hEventLog;          // CxgEÕnh
-	LPCSTR  Strings[2];         // CxgEOւ̋Lڕ
-    WORD    EventCat = 0;       // CxgEJeS
-    DWORD   EventID = 1000;     // Cxgʎq
+    LONG    rc;
+    DWORD   val, typ;
+    DWORD   size = sizeof(val);
+
+    rc = RegQueryValueEx(hReg, szKey, NULL, &typ, (BYTE*)&val, &size) ;
+    if( (rc == ERROR_SUCCESS) && (typ == REG_DWORD) ){
+        return  (long)val ;
+	}
+
+	// Failure: Type or Value does not exist!
+    return  -1L;
+}
+
+/* レジストリ参照用関数 */
+int __ReadRegMultiSz(HKEY hReg, const char *szKey, long* values, int valuesSize)
+{
+    LONG  rc = 0;
+    DWORD typ;
+    DWORD size = 0;
+	LPTSTR lpValues = NULL;
+	LPTSTR lpValue = NULL;
+	int i=0;
+
+	// Get size of the buffer for the values
+    rc = RegQueryValueEx(hReg, szKey, NULL, NULL, NULL, &size) ;
+    if(rc == ERROR_SUCCESS){
+		// Allocate the buffer
+		lpValues = (LPTSTR)malloc(size);
+		if (lpValues == NULL) {
+			return 0;
+		}
+
+		// Get the values
+		rc = RegQueryValueEx(hReg, szKey, NULL, &typ, (LPBYTE)lpValues, &size);
+		if( (rc == ERROR_SUCCESS) && (typ == REG_MULTI_SZ) ){
+			lpValue = lpValues;
+
+			for (i=0; '\0' != *lpValue && i < valuesSize; lpValue += _tcslen(lpValue) + 1)
+			{
+				// 10進数または16進数表記の文字列をlong形に変換する
+				// （意図的にunsignedとすることでオーバーフローによる丸め誤差の発生を防ぎ、PDH_STATUSとの整合性を合わせている）
+				values[i] = _tcstoul(lpValue, NULL, 0);
+				i++;
+			}
+		}
+		free(lpValues);
+		return i;
+	}
+
+	return 0;
+}
+
+/* Windowsイベント出力用関数(long/DWORD用) */
+VOID PostEvtLog( WORD logType, LPTSTR ModuleName, char *SendMsg, long val )
+{
+    CHAR    Msg[512];			// メッセージ
+    HANDLE  hEventLog;          // イベント・ログのハンドル
+	LPCSTR  Strings[2];         // イベント・ログへの記載文字列
+    WORD    EventCat = 0;       // イベント・カテゴリ
+    DWORD   EventID = 1000;     // イベント識別子
     char    tmpbf[256];
-  
-    // CxgEOɏL^
+
+    // イベント・ログに情報を記録
 	hEventLog = RegisterEventSource(NULL, "Hinemos SNMP Ext Agent");
 
     if( hEventLog != NULL ){
 		strcpy( Msg, "Hinemos SNMP Ext Agent : ");
-        sprintf( tmpbf,"%s %s(%d)", ModuleName, SendMsg, val );
+		sprintf_s( tmpbf, _countof(tmpbf), "%s %s %ld(0x%lx)", ModuleName, SendMsg, val, val );
 	    strcat( Msg, tmpbf );
 		Strings[0] = Msg;
 
@@ -405,20 +526,120 @@ VOID PostEvtLog( WORD logType, LPTSTR ModuleName, char *SendMsg, DWORD val )
 	return;
 }
 
+/* Windowsイベント出力用関数(double用) */
+VOID PostEvtLogDouble( WORD logType, LPTSTR ModuleName, char *SendMsg, double val )
+{
+    CHAR    Msg[512];			// メッセージ
+    HANDLE  hEventLog;          // イベント・ログのハンドル
+	LPCSTR  Strings[2];         // イベント・ログへの記載文字列
+    WORD    EventCat = 0;       // イベント・カテゴリ
+    DWORD   EventID = 1000;     // イベント識別子
+    char    tmpbf[256];
+  
+    // イベント・ログに情報を記録
+	hEventLog = RegisterEventSource(NULL, "Hinemos SNMP Ext Agent");
 
+    if( hEventLog != NULL ){
+		strcpy( Msg, "Hinemos SNMP Ext Agent : ");
+        sprintf_s( tmpbf, _countof(tmpbf), "%s %s %lf", ModuleName, SendMsg, val );
+	    strcat( Msg, tmpbf );
+		Strings[0] = Msg;
+
+		ReportEvent( hEventLog, logType, EventCat, EventID, NULL, 1, 0, Strings, NULL );
+		DeregisterEventSource( hEventLog );
+    }
+	return;
+}
+
+/* Windowsイベント出力用関数(DWORDLONG用) */
+VOID PostEvtLogDWORDLONG( WORD logType, LPTSTR ModuleName, char *SendMsg, DWORDLONG val )
+{
+    CHAR    Msg[512];			// メッセージ
+    HANDLE  hEventLog;          // イベント・ログのハンドル
+	LPCSTR  Strings[2];         // イベント・ログへの記載文字列
+    WORD    EventCat = 0;       // イベント・カテゴリ
+    DWORD   EventID = 1000;     // イベント識別子
+    char    tmpbf[256];
+  
+    // イベント・ログに情報を記録
+	hEventLog = RegisterEventSource(NULL, "Hinemos SNMP Ext Agent");
+
+    if( hEventLog != NULL ){
+		strcpy( Msg, "Hinemos SNMP Ext Agent : ");
+        sprintf_s( tmpbf, _countof(tmpbf), "%s %s %llu", ModuleName, SendMsg, val );
+	    strcat( Msg, tmpbf );
+		Strings[0] = Msg;
+
+		ReportEvent( hEventLog, logType, EventCat, EventID, NULL, 1, 0, Strings, NULL );
+		DeregisterEventSource( hEventLog );
+    }
+	return;
+}
+
+/* Windowsイベント出力用関数(char用) */
+VOID PostEvtLogChar( WORD logType, LPTSTR ModuleName, char *SendMsg, char c, long val)
+{
+    CHAR    Msg[512];			// メッセージ
+    HANDLE  hEventLog;          // イベント・ログのハンドル
+	LPCSTR  Strings[2];         // イベント・ログへの記載文字列
+    WORD    EventCat = 0;       // イベント・カテゴリ
+    DWORD   EventID = 1000;     // イベント識別子
+    char    tmpbf[256];
+
+    // イベント・ログに情報を記録
+	hEventLog = RegisterEventSource(NULL, "Hinemos SNMP Ext Agent");
+
+    if( hEventLog != NULL ){
+		strcpy( Msg, "Hinemos SNMP Ext Agent : ");
+		sprintf_s( tmpbf, _countof(tmpbf), "%s %s(%c) %ld(0x%lx)", ModuleName, SendMsg, c, val, val );
+	    strcat( Msg, tmpbf );
+		Strings[0] = Msg;
+
+		ReportEvent( hEventLog, logType, EventCat, EventID, NULL, 1, 0, Strings, NULL );
+		DeregisterEventSource( hEventLog );
+    }
+	return;
+}
+
+/* Windowsイベント出力用関数(string用) */
+VOID PostEvtLogString( WORD logType, LPTSTR ModuleName, char *SendMsg, char *str, long val)
+{
+    CHAR    Msg[512];			// メッセージ
+    HANDLE  hEventLog;          // イベント・ログのハンドル
+	LPCSTR  Strings[2];         // イベント・ログへの記載文字列
+    WORD    EventCat = 0;       // イベント・カテゴリ
+    DWORD   EventID = 1000;     // イベント識別子
+    char    tmpbf[256];
+
+    // イベント・ログに情報を記録
+	hEventLog = RegisterEventSource(NULL, "Hinemos SNMP Ext Agent");
+
+    if( hEventLog != NULL ){
+		strcpy( Msg, "Hinemos SNMP Ext Agent : ");
+		sprintf_s( tmpbf, _countof(tmpbf), "%s %s(%s) %ld(0x%lx)", ModuleName, SendMsg, str, val, val );
+	    strcat( Msg, tmpbf );
+		Strings[0] = Msg;
+
+		ReportEvent( hEventLog, logType, EventCat, EventID, NULL, 1, 0, Strings, NULL );
+		DeregisterEventSource( hEventLog );
+    }
+	return;
+}
 
 /*
- * Cuւ̃ANZX֐
- * OIDɊÂēK؂Ȋ֐ĂтAZbg
+ * ライブラリへのアクセス関数
+ * OIDに基づいて適切な関数を呼びだし、情報をセットする
  */
 void GetMibData(IN OUT MIB_ENTRY *mib)
 {
 
-	//U蕪WbN
+	//振り分けロジックを実装
 	int id = mib->ResourceId;
 
-	//diskIOp
+	//diskIO用
 	char drive;
+	int driveIndex;
+
 	string oid_string(SnmpUtilOidToA(&mib->Oid));
 	AsnCounter value;
 	char *device;
@@ -426,12 +647,22 @@ void GetMibData(IN OUT MIB_ENTRY *mib)
 	map<string, char>::iterator itr1;
 	map<string, AsnCounter>::iterator itr2;
 	map<string, char>::iterator itr3;
+	map<string, int>::iterator itr4;
+	map<string, AsnInteger>::iterator itr5;
+
 
 	switch(id){
+		case MIB_DISK_IO_INDEX:
+			//ドライブINDEXの取得
+			itr4 = oid_driveindex.find(oid_string);
+			if (&itr4 != NULL) {
+				driveIndex = (*itr4).second;
+			}
+			break;
 		case MIB_DISK_IO_DEVICE:
-			//hCu̎擾
+			//ドライブ文字の取得
 			itr1 = oid_drivestring.find(oid_string);
-			//݂tO؂ւ
+			//存在したらフラグを切り替える
 			if (&itr1 != NULL) {
 				drive = (*itr1).second;
 			}
@@ -440,24 +671,20 @@ void GetMibData(IN OUT MIB_ENTRY *mib)
 				device = &(*itr3).second;
 			}
 			break;
-	}
-
-
-	switch(id){
 		case MIB_DISK_IO_READ:
 		case MIB_DISK_IO_WRITE:
 		case MIB_DISK_IO_READS:
 		case MIB_DISK_IO_WRITES:
-			//hCu̎擾
+			//ドライブ文字の取得
 			itr1 = oid_drivestring.find(oid_string);
-			//݂tO؂ւ
+			//存在したらフラグを切り替える
 			if (&itr1 != NULL) {
 				drive = (*itr1).second;
 			}
 
-			//WlZbgϐ擾
+			//収集値をセットする変数を取得
 			itr2 = MIB_dat_diskIO.find(oid_string);
-			//݂tO؂ւ
+			//存在したらフラグを切り替える
 			if (&itr2 != NULL) {
 				value = (*itr2).second;
 			}
@@ -466,9 +693,9 @@ void GetMibData(IN OUT MIB_ENTRY *mib)
 
 	
 	switch(id){
-		//Ԃlɂ͒lւ̃|C^ݒ肷邽߁A
-		//l̕ێϐ̓O[oϐłKv
-		//߂lāA|C^mibɃZbg
+		//返り値には値へのポインタを設定するため、
+		//値の保持する変数はグローバル変数である必要がある
+		//戻り値を代入して、ポインタをmibにセットする
 
 		case MIB_CPU_RAW_USER:
 			MIB_dat_ssCpuRawUser = GetCpuRawUser();
@@ -476,6 +703,8 @@ void GetMibData(IN OUT MIB_ENTRY *mib)
 			break;
 
 		case MIB_CPU_RAW_NICE:
+			MIB_dat_ssCpuRawNice = GetCpuRawNice();
+			mib->Storage = &MIB_dat_ssCpuRawNice;
 			break;
 
 		case MIB_CPU_RAW_SYSTEM:
@@ -559,7 +788,7 @@ void GetMibData(IN OUT MIB_ENTRY *mib)
 			break;
 
 		case MIB_DISK_IO_INDEX:
-			value = GetDiskIOIndex(&drive);
+			value = GetDiskIOIndex(driveIndex);
 			mib->Storage = &value;
 			break;
 
@@ -605,12 +834,11 @@ void SetEntry(UINT idLength, UINT *ids, AsnInteger32 *storage, UINT access, UINT
 	entry.Access = access;
 	entry.ResourceId = resourceId;
 
-	SnmpUtilOidFree( &TempOid );
 	SnmpUtilOidCpy( &TempOid, &entry.Oid );
 	string oidstring(SnmpUtilOidToA(&TempOid));
 	oid_index_map.insert(map<string, int>::value_type(oidstring, index));
 	mib_entries.push_back(entry);
-
+	SnmpUtilOidFree( &TempOid );
 }
 
 void SetEntry(UINT idLength, UINT *ids, AsnCounter32 *storage, UINT access, UINT resourceId, int index) {
@@ -625,11 +853,11 @@ void SetEntry(UINT idLength, UINT *ids, AsnCounter32 *storage, UINT access, UINT
 	entry.Access = access;
 	entry.ResourceId = resourceId;
 
-	SnmpUtilOidFree( &TempOid );
 	SnmpUtilOidCpy( &TempOid, &entry.Oid );
 	string oidstring(SnmpUtilOidToA(&TempOid));
 	oid_index_map.insert(map<string, int>::value_type(oidstring, index));
 	mib_entries.push_back(entry);
+	SnmpUtilOidFree( &TempOid );
 
 }
 
@@ -645,26 +873,25 @@ void SetEntry(UINT idLength, UINT *ids, char *storage, UINT access, UINT resourc
 	entry.Access = access;
 	entry.ResourceId = resourceId;
 
-	SnmpUtilOidFree( &TempOid );
 	SnmpUtilOidCpy( &TempOid, &entry.Oid );
 	string oidstring(SnmpUtilOidToA(&TempOid));
 	oid_index_map.insert(map<string, int>::value_type(oidstring, index));
 	mib_entries.push_back(entry);
-
+	SnmpUtilOidFree( &TempOid );
 }
 
 
 /*
- * ɃR[Af[^\邽߂̊֐B
+ * 初期化時にコールされる、データ構造を作るための関数。
  */
 void CreateDataStructure()
 {
 	int index = 0;
 	string oidstring;
 
-	//OID̑召֌WlāAmibentry}邱
+	//OIDの大小関係を考慮して、mibentryを挿入すること
 	
-	/**  **/
+	/** メモリ **/
 	SetEntry(OID_SIZEOF(MIB_memTotalSwap), MIB_memTotalSwap, &MIB_dat_memTotalSwap,
 			MIB_ACCESS_READONLY, MIB_MEM_TOTAL_SWAP, index++);
 
@@ -687,24 +914,34 @@ void CreateDataStructure()
 	SetEntry(OID_SIZEOF(MIB_memCached), MIB_memCached, &MIB_dat_memCached,
 			MIB_ACCESS_READONLY, MIB_MEM_CACHED, index++);
 
-	/** [hAx[W **/
+	// "初期化完了"のEventLogを書出す
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Memory Initialization Completed", 0 );
+	}
+
+	/** ロードアベレージ **/
 
 	/******************************/
 
 	/******************************/
 
 
-	/** XbvC^AEg **/
+	/** スワップイン／アウト **/
 	/******************************/
 	SetEntry(OID_SIZEOF(MIB_ssSwapIn), MIB_ssSwapIn, &MIB_dat_ssSwapIn,
 			MIB_ACCESS_READONLY, MIB_SS_SWAP_IN, index++);
 
 	SetEntry(OID_SIZEOF(MIB_ssSwapOut), MIB_ssSwapOut, &MIB_dat_ssSwapOut,
 			MIB_ACCESS_READONLY, MIB_SS_SWAP_OUT, index++);
+	// "初期化完了"のEventLogを書出す
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Swap In/Out Initialization Completed", 0 );
+	}
+
 	/******************************/
 
 	
-	/** CPUgp **/
+	/** CPU使用率 **/
 	SetEntry(OID_SIZEOF(MIB_ssCpuRawUser), MIB_ssCpuRawUser, &MIB_dat_ssCpuRawUser,
 			MIB_ACCESS_READONLY, MIB_CPU_RAW_USER, index++);
 
@@ -733,43 +970,76 @@ void CreateDataStructure()
 
 	SetEntry(OID_SIZEOF(MIB_ssRawContexts), MIB_ssRawContexts, &MIB_dat_ssRawContexts,
 			MIB_ACCESS_READONLY, MIB_RAW_CONTEXTS, index++);
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Cpu Initialization Completed", 0 );
+	}
 
+	/** ディスク **/
 
-	/** fBXN **/
-
-	//LȃhCuꗗ擾iAt@xbgPƂj
+	//有効なドライブ一覧を取得する（アルファベット１文字とする）
 	char buf[1000] = {0};
 	vector<char> drives;
 	DWORD buf_size = 1000;
 	DWORD cnt= 0;
 	int drive_num = 0;
 
-	// 26̃rbgŃhCu擾
+	// 26桁のビット列でドライブ文字を取得
 	const int MAX_DRIVE_NUM = 26;
-	DWORD mask = GetLogicalDrives();
+	int mask = (int)GetLogicalDrives();
 	bitset<MAX_DRIVE_NUM> bit_drives(mask);
 
 	AsnObjectIdentifier temp_oid;
 	string key;
 	AsnCounter *MIB_dat;
 	char *MIB_dat_String;
+	AsnInteger *MIB_dat_Integer;
 	map<string, AsnCounter>::iterator itr;
 	map<string, char>::iterator itr_diskIODevice;
+	map<string, AsnInteger>::iterator itr_diskIOIndex;
 
+	//diskIOIndex
+	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
+		if (bit_drives.at(i)) {
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
+			char drive_char = 'A' + i;
+
+			//OIDとドライブ文字のマップ
+			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
+			temp_oid.ids = &MIB_diskIOIndexPtr[MIB_DISK_IO_OID_LENGTH * i];
+			key = (string)(SnmpUtilOidToA(&temp_oid));
+			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
+
+			//OIDとデバイスINDEXのマップ
+			oid_driveindex.insert(map<string, int>::value_type(key, (i+1)));
+
+			//OIDと収集値格納用の変数
+			MIB_dat_diskIOIndex.insert(map<string, AsnInteger>::value_type(key, 0));
+			itr_diskIOIndex = MIB_dat_diskIOIndex.find(key);
+			if (itr_diskIOIndex != MIB_dat_diskIOIndex.end()) {
+				MIB_dat_Integer = &(*itr_diskIOIndex).second;
+			}
+			//エントリの作成
+			SetEntry(MIB_DISK_IO_OID_LENGTH, &MIB_diskIOIndexPtr[MIB_DISK_IO_OID_LENGTH * i], MIB_dat_Integer,
+					MIB_ACCESS_READONLY, MIB_DISK_IO_INDEX, index++);
+		}
+	}
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Index Initialization Completed", 0 );
+	}
 
 	//diskIODevice
 	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
 		if (bit_drives.at(i)) {
-			//hCuɊÂāAOID̖ݒ肷B
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
 			char drive_char = 'A' + i;
 
-			//OIDƃhCũ}bv
+			//OIDとドライブ文字のマップ
 			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
 			temp_oid.ids = &MIB_diskIODevicePtr[MIB_DISK_IO_OID_LENGTH * i];
 			key = (string)(SnmpUtilOidToA(&temp_oid));
 			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
 
-			//OIDƎWli[p̕ϐ
+			//OIDと収集値格納用の変数
 			MIB_dat_diskIODevice.insert(map<string, char>::value_type(key, 0));
 			itr_diskIODevice = MIB_dat_diskIODevice.find(key);
 			if (itr_diskIODevice != MIB_dat_diskIODevice.end()) {
@@ -780,100 +1050,113 @@ void CreateDataStructure()
 					MIB_ACCESS_READONLY, MIB_DISK_IO_DEVICE, index++);
 		}
 	}
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Device Initialization Completed", 0 );
+	}
 
 	//diskIORead
 	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
 		if (bit_drives.at(i)) {
-			//hCuɊÂāAOID̖ݒ肷B
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
 			char drive_char = 'A' + i;
 
-			//OIDƃhCũ}bv
+			//OIDとドライブ文字のマップ
 			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
 			temp_oid.ids = &MIB_diskIOReadPtr[MIB_DISK_IO_OID_LENGTH * i];
 			key = (string)(SnmpUtilOidToA(&temp_oid));
 			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
-			//OIDƎWli[p̕ϐ
+			//OIDと収集値格納用の変数
 			MIB_dat_diskIO.insert(map<string, AsnCounter>::value_type(key, 0));
 			itr = MIB_dat_diskIO.find(key);
 			if (itr != MIB_dat_diskIO.end()) {
 				MIB_dat = &(*itr).second;
 			}
-			//Gg̍쐬a
+			//エントリの作成
 			SetEntry(MIB_DISK_IO_OID_LENGTH, &MIB_diskIOReadPtr[MIB_DISK_IO_OID_LENGTH * i], MIB_dat,
 					MIB_ACCESS_READONLY, MIB_DISK_IO_READ, index++);
 		}
 	}
-
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Read Initialization Completed", 0 );
+	}
 
 	//diskIOWrite
 	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
 		if (bit_drives.at(i)) {
-			//hCuɊÂāAOID̖ݒ肷B
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
 			char drive_char = 'A' + i;
 
-			//OIDƃhCũ}bv
+			//OIDとドライブ文字のマップ
 			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
 			temp_oid.ids = &MIB_diskIOWritePtr[MIB_DISK_IO_OID_LENGTH * i];
 			key = (string)(SnmpUtilOidToA(&temp_oid));
 			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
-			//OIDƎWli[p̕ϐ
+			//OIDと収集値格納用の変数
 			MIB_dat_diskIO.insert(map<string, AsnCounter>::value_type(key, 0));
 			itr = MIB_dat_diskIO.find(key);
 			if (itr != MIB_dat_diskIO.end()) {
 				MIB_dat = &(*itr).second;
 			}
-			//Gg̍쐬a
+			//エントリの作成
 			SetEntry(MIB_DISK_IO_OID_LENGTH, &MIB_diskIOWritePtr[MIB_DISK_IO_OID_LENGTH * i], MIB_dat,
 					MIB_ACCESS_READONLY, MIB_DISK_IO_WRITE, index++);
 		}
 	}
-
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Write Initialization Completed", 0 );
+	}
 
 	//diskIOReads
 	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
 		if (bit_drives.at(i)) {
-			//hCuɊÂāAOID̖ݒ肷B
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
 			char drive_char = 'A' + i;
 
-			//OIDƃhCũ}bv
+			//OIDとドライブ文字のマップ
 			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
 			temp_oid.ids = &MIB_diskIOReadsPtr[MIB_DISK_IO_OID_LENGTH * i];
 			key = (string)(SnmpUtilOidToA(&temp_oid));
 			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
-			//OIDƎWli[p̕ϐ
+			//OIDと収集値格納用の変数
 			MIB_dat_diskIO.insert(map<string, AsnCounter>::value_type(key, 0));
 			itr = MIB_dat_diskIO.find(key);
 			if (itr != MIB_dat_diskIO.end()) {
 				MIB_dat = &(*itr).second;
 			}
-			//Gg̍쐬a
+			//エントリの作成
 			SetEntry(MIB_DISK_IO_OID_LENGTH, &MIB_diskIOReadsPtr[MIB_DISK_IO_OID_LENGTH * i], MIB_dat,
 					MIB_ACCESS_READONLY, MIB_DISK_IO_READS, index++);
 		}
 	}
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Reads Initialization Completed", 0 );
+	}
 
 	//diskIOWrites
 	for (int i = 0; i < MAX_DRIVE_NUM; i++) {
 		if (bit_drives.at(i)) {
-			//hCuɊÂāAOID̖ݒ肷B
+			//ドライブ文字に基づいて、OIDの末尾を設定する。
 			char drive_char = 'A' + i;
 
-			//OIDƃhCũ}bv
+			//OIDとドライブ文字のマップ
 			temp_oid.idLength = MIB_DISK_IO_OID_LENGTH;
 			temp_oid.ids = &MIB_diskIOWritesPtr[MIB_DISK_IO_OID_LENGTH * i];
 			key = (string)(SnmpUtilOidToA(&temp_oid));
 			oid_drivestring.insert(map<string, char>::value_type(key, drive_char));
-			//OIDƎWli[p̕ϐ
+			//OIDと収集値格納用の変数
 			MIB_dat_diskIO.insert(map<string, AsnCounter>::value_type(key, 0));
 			itr = MIB_dat_diskIO.find(key);
 			if (itr != MIB_dat_diskIO.end()) {
 				MIB_dat = &(*itr).second;
 			}
-			//Gg̍쐬a
+			//エントリの作成
 			SetEntry(MIB_DISK_IO_OID_LENGTH, &MIB_diskIOWritesPtr[MIB_DISK_IO_OID_LENGTH * i], MIB_dat,
 					MIB_ACCESS_READONLY, MIB_DISK_IO_WRITES, index++);
 		}
 	}
+	if(verbose == 1){
+		PostEvtLog( EVENTLOG_INFORMATION_TYPE, "CreateDataStructure", "Disk IO Writes Initialization Completed", 0 );
+	}
 
 	/**********/
 
@@ -897,4 +1180,3 @@ int writeLog(char *ptr) {
 	return 0;
 
 }
-
