@@ -52,6 +52,7 @@ import com.clustercontrol.jobmanagement.bean.NodeOperationInfo;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.jobmanagement.ejb.session.JobControllerLocal;
 import com.clustercontrol.jobmanagement.ejb.session.JobControllerLocalHome;
+import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 
 /**
@@ -393,6 +394,19 @@ public class JobEndpoint {
 				+ HttpAuthenticator.getUserAccountString(wsctx)
 				+ msg.toString());
 
+		// 実行可能かのチェック(参照可能なジョブユニットは以下のみ実行可能)
+		String account = HttpAuthenticator.getAccount(wsctx);
+		String loginUser = "";
+		if(account != null)
+			loginUser = account.split(":")[0];
+		if(!JobUtil.isReferableJobunit(jobunitId, loginUser)){
+			m_log.warn("runJob() : InvalidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is invisible by loginUser = " + loginUser);
+			throw new HinemosUnknown("runJob() : InvalidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is invisible by loginUser = " + loginUser);
+		}
+		else{
+			m_log.debug("runJob() : ValidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is visible by loginUser = " + loginUser);
+		}
+		
 		JobControllerLocal job = getJobControllerLocal();
 		return job.runJob(jobunitId, jobId, info, triggerInfo);
 	}
@@ -769,6 +783,7 @@ public class JobEndpoint {
 		m_log.debug("getCalendarIdList :");
 		ArrayList<String> roleList = new ArrayList<String>();
 		roleList.add(RoleConstant.JOBMANAGEMENT_READ);
+		roleList.add(RoleConstant.CALENDAR_READ);
 		HttpAuthenticator.authCheck(wsctx, roleList);
 
 		// 認証済み操作ログ
